# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/certificate/certificate.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/certificate/certificate.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/certificate/certificate.proto\x12\x16yeying.api.certificate\x1a\x1fyeying/api/common/message.proto"v\n\x0bSignRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.certificate.SignRequestBody".\n\x0fSignRequestBody\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0b\n\x03\x63sr\x18\x02 \x01(\t"x\n\x0cSignResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.certificate.SignResponseBody".\n\x13\x43\x65rtificateMetadata\x12\x0b\n\x03\x63rt\x18\x01 \x01(\t\x12\n\n\x02\x63\x61\x18\x02 \x01(\t"\x87\x01\n\x10SignResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12@\n\x0b\x63\x65rtificate\x18\x02 \x01(\x0b\x32+.yeying.api.certificate.CertificateMetadata">\n\nGetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"v\n\x0bGetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.certificate.GetResponseBody"\x86\x01\n\x0fGetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12@\n\x0b\x63\x65rtificate\x18\x02 \x01(\x0b\x32+.yeying.api.certificate.CertificateMetadata2\xb4\x01\n\x0b\x43\x65rtificate\x12S\n\x04Sign\x12#.yeying.api.certificate.SignRequest\x1a$.yeying.api.certificate.SignResponse"\x00\x12P\n\x03Get\x12".yeying.api.certificate.GetRequest\x1a#.yeying.api.certificate.GetResponse"\x00\x42\x18Z\x16yeying/api/certificateb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.certificate.certificate_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\026yeying/api/certificate"
    _globals["_SIGNREQUEST"]._serialized_start = 101
    _globals["_SIGNREQUEST"]._serialized_end = 219
    _globals["_SIGNREQUESTBODY"]._serialized_start = 221
    _globals["_SIGNREQUESTBODY"]._serialized_end = 267
    _globals["_SIGNRESPONSE"]._serialized_start = 269
    _globals["_SIGNRESPONSE"]._serialized_end = 389
    _globals["_CERTIFICATEMETADATA"]._serialized_start = 391
    _globals["_CERTIFICATEMETADATA"]._serialized_end = 437
    _globals["_SIGNRESPONSEBODY"]._serialized_start = 440
    _globals["_SIGNRESPONSEBODY"]._serialized_end = 575
    _globals["_GETREQUEST"]._serialized_start = 577
    _globals["_GETREQUEST"]._serialized_end = 639
    _globals["_GETRESPONSE"]._serialized_start = 641
    _globals["_GETRESPONSE"]._serialized_end = 759
    _globals["_GETRESPONSEBODY"]._serialized_start = 762
    _globals["_GETRESPONSEBODY"]._serialized_end = 896
    _globals["_CERTIFICATE"]._serialized_start = 899
    _globals["_CERTIFICATE"]._serialized_end = 1079
# @@protoc_insertion_point(module_scope)
