# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/common/message.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/common/message.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fyeying/api/common/message.proto\x12\x11yeying.api.common\x1a\x1cyeying/api/common/code.proto"\x9f\x01\n\rMessageHeader\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x39\n\x08\x61uthType\x18\x02 \x01(\x0e\x32\'.yeying.api.common.AuthenticateTypeEnum\x12\x13\n\x0b\x61uthContent\x18\x03 \x01(\t\x12\r\n\x05nonce\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\r"T\n\x0eResponseStatus\x12\x31\n\x04\x63ode\x18\x01 \x01(\x0e\x32#.yeying.api.common.ResponseCodeEnum\x12\x0f\n\x07message\x18\x02 \x01(\t"=\n\x0cResponsePage\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04page\x18\x03 \x01(\r\x12\x10\n\x08pageSize\x18\x04 \x01(\r"-\n\x0bRequestPage\x12\x0c\n\x04page\x18\x01 \x01(\r\x12\x10\n\x08pageSize\x18\x02 \x01(\rB\x13Z\x11yeying/api/commonb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.common.message_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/common"
    _globals["_MESSAGEHEADER"]._serialized_start = 85
    _globals["_MESSAGEHEADER"]._serialized_end = 244
    _globals["_RESPONSESTATUS"]._serialized_start = 246
    _globals["_RESPONSESTATUS"]._serialized_end = 330
    _globals["_RESPONSEPAGE"]._serialized_start = 332
    _globals["_RESPONSEPAGE"]._serialized_end = 393
    _globals["_REQUESTPAGE"]._serialized_start = 395
    _globals["_REQUESTPAGE"]._serialized_end = 440
# @@protoc_insertion_point(module_scope)
