# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/task.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/task.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import imagecontent_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_imagecontent__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%yeying/api/apps/zuoyepigai/task.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yeying/api/apps/zuoyepigai/imagecontent.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x80\x01\n\x0e\x41\x64\x64TaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12<\n\x04\x62ody\x18\x02 \x01(\x0b\x32..yeying.api.apps.zuoyepigai.AddTaskRequestBody"L\n\x12\x41\x64\x64TaskRequestBody\x12\x36\n\x04meta\x18\x01 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x82\x01\n\x0f\x41\x64\x64TaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.apps.zuoyepigai.AddTaskResponseBody"\x80\x01\n\x13\x41\x64\x64TaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x86\x01\n\x11\x44\x65tailTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.DetailTaskRequestBody"$\n\x15\x44\x65tailTaskRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x12\x44\x65tailTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DetailTaskResponseBody"\xc3\x01\n\x16\x44\x65tailTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata\x12>\n\x0bstudentList\x18\x03 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x82\x01\n\x0fListTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.apps.zuoyepigai.ListTaskRequestBody"\xec\x01\n\x13ListTaskRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0e\n\x06tagUid\x18\x02 \x01(\t\x12\x10\n\x08taskName\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12.\n\tpageIndex\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x0e\n\x06status\x18\x07 \x01(\x05\x12\x11\n\tstartTime\x18\x08 \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\t \x01(\x03"\x84\x01\n\x10ListTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.apps.zuoyepigai.ListTaskResponseBody"\x90\x01\n\x14ListTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04list\x18\x02 \x03(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata\x12\r\n\x05total\x18\x03 \x01(\x04"\x8a\x01\n\x13TagCountTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.TagCountTaskRequestBody"&\n\x17TagCountTaskRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8c\x01\n\x14TagCountTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.TagCountTaskResponseBody"\x85\x01\n\x18TagCountTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x03(\x0b\x32(.yeying.api.apps.zuoyepigai.TagCountMeta"\x86\x01\n\x11UpdateTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.UpdateTaskRequestBody"O\n\x15UpdateTaskRequestBody\x12\x36\n\x04meta\x18\x01 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x88\x01\n\x12UpdateTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.UpdateTaskResponseBody"\x83\x01\n\x16UpdateTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata"\x86\x01\n\x11\x44\x65leteTaskRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.DeleteTaskRequestBody"$\n\x15\x44\x65leteTaskRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x12\x44\x65leteTaskResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DeleteTaskResponseBody"\x83\x01\n\x16\x44\x65leteTaskResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x04meta\x18\x02 \x01(\x0b\x32(.yeying.api.apps.zuoyepigai.TaskMetadata2\xff\x04\n\x04Task\x12`\n\x03\x41\x64\x64\x12*.yeying.api.apps.zuoyepigai.AddTaskRequest\x1a+.yeying.api.apps.zuoyepigai.AddTaskResponse"\x00\x12i\n\x06\x44\x65tail\x12-.yeying.api.apps.zuoyepigai.DetailTaskRequest\x1a..yeying.api.apps.zuoyepigai.DetailTaskResponse"\x00\x12\x63\n\x04List\x12+.yeying.api.apps.zuoyepigai.ListTaskRequest\x1a,.yeying.api.apps.zuoyepigai.ListTaskResponse"\x00\x12o\n\x08TagCount\x12/.yeying.api.apps.zuoyepigai.TagCountTaskRequest\x1a\x30.yeying.api.apps.zuoyepigai.TagCountTaskResponse"\x00\x12i\n\x06Update\x12-.yeying.api.apps.zuoyepigai.UpdateTaskRequest\x1a..yeying.api.apps.zuoyepigai.UpdateTaskResponse"\x00\x12i\n\x06\x44\x65lete\x12-.yeying.api.apps.zuoyepigai.DeleteTaskRequest\x1a..yeying.api.apps.zuoyepigai.DeleteTaskResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.task_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ADDTASKREQUEST"]._serialized_start = 221
    _globals["_ADDTASKREQUEST"]._serialized_end = 349
    _globals["_ADDTASKREQUESTBODY"]._serialized_start = 351
    _globals["_ADDTASKREQUESTBODY"]._serialized_end = 427
    _globals["_ADDTASKRESPONSE"]._serialized_start = 430
    _globals["_ADDTASKRESPONSE"]._serialized_end = 560
    _globals["_ADDTASKRESPONSEBODY"]._serialized_start = 563
    _globals["_ADDTASKRESPONSEBODY"]._serialized_end = 691
    _globals["_DETAILTASKREQUEST"]._serialized_start = 694
    _globals["_DETAILTASKREQUEST"]._serialized_end = 828
    _globals["_DETAILTASKREQUESTBODY"]._serialized_start = 830
    _globals["_DETAILTASKREQUESTBODY"]._serialized_end = 866
    _globals["_DETAILTASKRESPONSE"]._serialized_start = 869
    _globals["_DETAILTASKRESPONSE"]._serialized_end = 1005
    _globals["_DETAILTASKRESPONSEBODY"]._serialized_start = 1008
    _globals["_DETAILTASKRESPONSEBODY"]._serialized_end = 1203
    _globals["_LISTTASKREQUEST"]._serialized_start = 1206
    _globals["_LISTTASKREQUEST"]._serialized_end = 1336
    _globals["_LISTTASKREQUESTBODY"]._serialized_start = 1339
    _globals["_LISTTASKREQUESTBODY"]._serialized_end = 1575
    _globals["_LISTTASKRESPONSE"]._serialized_start = 1578
    _globals["_LISTTASKRESPONSE"]._serialized_end = 1710
    _globals["_LISTTASKRESPONSEBODY"]._serialized_start = 1713
    _globals["_LISTTASKRESPONSEBODY"]._serialized_end = 1857
    _globals["_TAGCOUNTTASKREQUEST"]._serialized_start = 1860
    _globals["_TAGCOUNTTASKREQUEST"]._serialized_end = 1998
    _globals["_TAGCOUNTTASKREQUESTBODY"]._serialized_start = 2000
    _globals["_TAGCOUNTTASKREQUESTBODY"]._serialized_end = 2038
    _globals["_TAGCOUNTTASKRESPONSE"]._serialized_start = 2041
    _globals["_TAGCOUNTTASKRESPONSE"]._serialized_end = 2181
    _globals["_TAGCOUNTTASKRESPONSEBODY"]._serialized_start = 2184
    _globals["_TAGCOUNTTASKRESPONSEBODY"]._serialized_end = 2317
    _globals["_UPDATETASKREQUEST"]._serialized_start = 2320
    _globals["_UPDATETASKREQUEST"]._serialized_end = 2454
    _globals["_UPDATETASKREQUESTBODY"]._serialized_start = 2456
    _globals["_UPDATETASKREQUESTBODY"]._serialized_end = 2535
    _globals["_UPDATETASKRESPONSE"]._serialized_start = 2538
    _globals["_UPDATETASKRESPONSE"]._serialized_end = 2674
    _globals["_UPDATETASKRESPONSEBODY"]._serialized_start = 2677
    _globals["_UPDATETASKRESPONSEBODY"]._serialized_end = 2808
    _globals["_DELETETASKREQUEST"]._serialized_start = 2811
    _globals["_DELETETASKREQUEST"]._serialized_end = 2945
    _globals["_DELETETASKREQUESTBODY"]._serialized_start = 2947
    _globals["_DELETETASKREQUESTBODY"]._serialized_end = 2983
    _globals["_DELETETASKRESPONSE"]._serialized_start = 2986
    _globals["_DELETETASKRESPONSE"]._serialized_end = 3122
    _globals["_DELETETASKRESPONSEBODY"]._serialized_start = 3125
    _globals["_DELETETASKRESPONSEBODY"]._serialized_end = 3256
    _globals["_TASK"]._serialized_start = 3259
    _globals["_TASK"]._serialized_end = 3898
# @@protoc_insertion_point(module_scope)
