# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.rag import rag_pb2 as yeying_dot_api_dot_rag_dot_rag__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yeying/api/rag/rag_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class RAGStub(object):
    """*
    记忆模块
    对应的 DB 表：rag.memory
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSession = channel.unary_unary(
                '/yeying.api.rag.RAG/CreateSession',
                request_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionResponse.FromString,
                _registered_method=True)
        self.AddMessage = channel.unary_unary(
                '/yeying.api.rag.RAG/AddMessage',
                request_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageResponse.FromString,
                _registered_method=True)
        self.DeleteMessage = channel.unary_unary(
                '/yeying.api.rag.RAG/DeleteMessage',
                request_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageResponse.FromString,
                _registered_method=True)


class RAGServicer(object):
    """*
    记忆模块
    对应的 DB 表：rag.memory
    """

    def CreateSession(self, request, context):
        """创建会话
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddMessage(self, request, context):
        """添加消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMessage(self, request, context):
        """删除消息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RAGServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionResponse.SerializeToString,
            ),
            'AddMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.AddMessage,
                    request_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageResponse.SerializeToString,
            ),
            'DeleteMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMessage,
                    request_deserializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yeying.api.rag.RAG', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yeying.api.rag.RAG', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class RAG(object):
    """*
    记忆模块
    对应的 DB 表：rag.memory
    """

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.RAG/CreateSession',
            yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_rag__pb2.CreateSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.RAG/AddMessage',
            yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_rag__pb2.AddMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.RAG/DeleteMessage',
            yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_rag__pb2.DeleteMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
