# Generated by protobuf_init. Do not edit manually.
from .contract_pb2 import CreateAddressRequest
from .contract_pb2 import CreateAddressResponse
from .contract_pb2 import TransactionRequest
from .contract_pb2 import TransactionResponse
from .contract_pb2 import BalanceRequest
from .contract_pb2 import BalanceResponse
from .contract_pb2 import WalletInfoRequest
from .contract_pb2 import WalletInfoResponse
from .contract_pb2 import Transaction
from .contract_pb2_grpc import WalletServicer
from .contract_pb2_grpc import WalletStub
from .contract_pb2_grpc import add_WalletServicer_to_server
from .contract_pb2_grpc import Wallet
