# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/llm/provider.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/llm/provider.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dyeying/api/llm/provider.proto\x12\x0eyeying.api.llm\x1a\x1fyeying/api/common/message.proto"O\n\x1bProviderDescriptionsRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\x90\x01\n\x1cProviderDescriptionsResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.llm.ProviderDescriptionsResponseBody"\x90\x01\n ProviderDescriptionsResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32#.yeying.api.llm.ProviderDescription"\x82\x01\n\x15ProviderModelsRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.ProviderModelsRequestBody"}\n\x19ProviderModelsRequestBody\x12.\n\x04\x63ode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12\x30\n\tmodelType\x18\x02 \x01(\x0e\x32\x1d.yeying.api.llm.ModelTypeEnum"\x84\x01\n\x16ProviderModelsResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.ProviderModelsResponseBody"~\n\x1aProviderModelsResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x06models\x18\x02 \x03(\x0b\x32\x1d.yeying.api.llm.ModelMetadata"\x82\x01\n\x15\x44\x65leteProviderRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.DeleteProviderRequestBody"(\n\x19\x44\x65leteProviderRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x84\x01\n\x16\x44\x65leteProviderResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.DeleteProviderResponseBody"O\n\x1a\x44\x65leteProviderResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x82\x01\n\x15SearchProviderRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.SearchProviderRequestBody"\x85\x01\n\x19SearchProviderRequestBody\x12,\n\x04page\x18\x01 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage\x12:\n\tcondition\x18\x02 \x01(\x0b\x32\'.yeying.api.llm.SearchProviderCondition"\x84\x01\n\x16SearchProviderResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.SearchProviderResponseBody"\x84\x01\n\x1aSearchProviderResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\tproviders\x18\x02 \x03(\x0b\x32 .yeying.api.llm.ProviderMetadata"|\n\x12\x41\x64\x64ProviderRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.llm.AddProviderRequestBody"L\n\x16\x41\x64\x64ProviderRequestBody\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .yeying.api.llm.ProviderMetadata"~\n\x13\x41\x64\x64ProviderResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.llm.AddProviderResponseBody"\x80\x01\n\x17\x41\x64\x64ProviderResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x32\n\x08provider\x18\x02 \x01(\x0b\x32 .yeying.api.llm.ProviderMetadata"\x82\x01\n\x15ProviderDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.llm.ProviderDetailRequestBody"(\n\x19ProviderDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x84\x01\n\x16ProviderDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.llm.ProviderDetailResponseBody"\x7f\n\x1aProviderDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1e.yeying.api.llm.ProviderDetail"r\n\x0eProviderDetail\x12\x32\n\x08provider\x18\x01 \x01(\x0b\x32 .yeying.api.llm.ProviderMetadata\x12,\n\x05state\x18\x02 \x01(\x0b\x32\x1d.yeying.api.llm.ProviderState"\xb4\x01\n\x13ProviderDescription\x12.\n\x04\x63ode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12:\n\x13supportedModelTypes\x18\x04 \x03(\x0e\x32\x1d.yeying.api.llm.ModelTypeEnum\x12\x0e\n\x06\x61vatar\x18\x05 \x01(\t"I\n\x17SearchProviderCondition\x12.\n\x04\x63ode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum"\xfb\x01\n\x10ProviderMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12.\n\x04\x63ode\x18\x04 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x30\n\tquotaType\x18\x06 \x01(\x0e\x32\x1d.yeying.api.llm.QuotaTypeEnum\x12\x12\n\nquotaLimit\x18\x07 \x01(\x04\x12\x11\n\tcreatedAt\x18\x08 \x01(\t\x12\x11\n\tupdatedAt\x18\t \x01(\t\x12\x11\n\tsignature\x18\n \x01(\t"\xb6\x01\n\rModelMetadata\x12\x36\n\x0cproviderCode\x18\x01 \x01(\x0e\x32 .yeying.api.llm.ProviderCodeEnum\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.yeying.api.llm.ModelTypeEnum\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x32\n\x08\x66\x65\x61tures\x18\x04 \x03(\x0e\x32 .yeying.api.llm.ModelFeatureEnum"\xb0\x01\n\rProviderState\x12\x12\n\nserviceDid\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32".yeying.api.llm.ProviderStatusEnum\x12\x11\n\tquotaUsed\x18\x04 \x01(\x04\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t*\xd7\x01\n\rModelTypeEnum\x12\x16\n\x12MODEL_TYPE_UNKNOWN\x10\x00\x12\x12\n\x0eMODEL_TYPE_LLM\x10\x01\x12\x1d\n\x19MODEL_TYPE_TEXT_EMBEDDING\x10\x02\x12\x15\n\x11MODEL_TYPE_RERANK\x10\x03\x12\x1a\n\x16MODEL_TYPE_SPEECH2TEXT\x10\x04\x12\x12\n\x0eMODEL_TYPE_TTS\x10\x05\x12\x19\n\x15MODEL_TYPE_MODERATION\x10\x06\x12\x19\n\x15MODEL_TYPE_TEXT2IMAGE\x10\x07*\xff\x01\n\x10ModelFeatureEnum\x12\x1f\n\x1bMODEL_FEATURE_AGENT_THOUGHT\x10\x00\x12\x18\n\x14MODEL_FEATURE_VISION\x10\x02\x12\x1b\n\x17MODEL_FEATURE_TOOL_CALL\x10\x03\x12!\n\x1dMODEL_FEATURE_MULTI_TOOL_CALL\x10\x04\x12"\n\x1eMODEL_FEATURE_STREAM_TOOL_CALL\x10\x05\x12\x1a\n\x16MODEL_FEATURE_DOCUMENT\x10\x06\x12\x17\n\x13MODEL_FEATURE_VIDEO\x10\x07\x12\x17\n\x13MODEL_FEATURE_AUDIO\x10\x08*\xb0\x01\n\x10ProviderCodeEnum\x12\x19\n\x15PROVIDER_CODE_UNKNOWN\x10\x00\x12\x18\n\x14PROVIDER_CODE_OPENAI\x10\x01\x12\x18\n\x14PROVIDER_CODE_TONGYI\x10\x02\x12\x19\n\x15PROVIDER_CODE_ZHIPUAI\x10\x03\x12\x16\n\x12PROVIDER_CODE_GROK\x10\x04\x12\x1a\n\x16PROVIDER_CODE_DEEPSEEK\x10\x05*q\n\x12ProviderStatusEnum\x12\x1b\n\x17PROVIDER_STATUS_UNKNOWN\x10\x00\x12\x1f\n\x1bPROVIDER_STATUS_UNAVAILABLE\x10\x01\x12\x1d\n\x19PROVIDER_STATUS_AVAILABLE\x10\x02*g\n\rQuotaTypeEnum\x12\x16\n\x12QUOTA_TYPE_UNKNOWN\x10\x00\x12\x13\n\x0fQUOTA_TYPE_PAID\x10\x01\x12\x13\n\x0fQUOTA_TYPE_FREE\x10\x02\x12\x14\n\x10QUOTA_TYPE_TRIAL\x10\x03\x32\xb5\x04\n\x08Provider\x12k\n\x0c\x44\x65scriptions\x12+.yeying.api.llm.ProviderDescriptionsRequest\x1a,.yeying.api.llm.ProviderDescriptionsResponse"\x00\x12Y\n\x06Models\x12%.yeying.api.llm.ProviderModelsRequest\x1a&.yeying.api.llm.ProviderModelsResponse"\x00\x12Y\n\x06Search\x12%.yeying.api.llm.SearchProviderRequest\x1a&.yeying.api.llm.SearchProviderResponse"\x00\x12Y\n\x06\x44\x65tail\x12%.yeying.api.llm.ProviderDetailRequest\x1a&.yeying.api.llm.ProviderDetailResponse"\x00\x12P\n\x03\x41\x64\x64\x12".yeying.api.llm.AddProviderRequest\x1a#.yeying.api.llm.AddProviderResponse"\x00\x12Y\n\x06\x44\x65lete\x12%.yeying.api.llm.DeleteProviderRequest\x1a&.yeying.api.llm.DeleteProviderResponse"\x00\x42\x10Z\x0eyeying/api/llmb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.llm.provider_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\016yeying/api/llm"
    _globals["_MODELTYPEENUM"]._serialized_start = 3805
    _globals["_MODELTYPEENUM"]._serialized_end = 4020
    _globals["_MODELFEATUREENUM"]._serialized_start = 4023
    _globals["_MODELFEATUREENUM"]._serialized_end = 4278
    _globals["_PROVIDERCODEENUM"]._serialized_start = 4281
    _globals["_PROVIDERCODEENUM"]._serialized_end = 4457
    _globals["_PROVIDERSTATUSENUM"]._serialized_start = 4459
    _globals["_PROVIDERSTATUSENUM"]._serialized_end = 4572
    _globals["_QUOTATYPEENUM"]._serialized_start = 4574
    _globals["_QUOTATYPEENUM"]._serialized_end = 4677
    _globals["_PROVIDERDESCRIPTIONSREQUEST"]._serialized_start = 82
    _globals["_PROVIDERDESCRIPTIONSREQUEST"]._serialized_end = 161
    _globals["_PROVIDERDESCRIPTIONSRESPONSE"]._serialized_start = 164
    _globals["_PROVIDERDESCRIPTIONSRESPONSE"]._serialized_end = 308
    _globals["_PROVIDERDESCRIPTIONSRESPONSEBODY"]._serialized_start = 311
    _globals["_PROVIDERDESCRIPTIONSRESPONSEBODY"]._serialized_end = 455
    _globals["_PROVIDERMODELSREQUEST"]._serialized_start = 458
    _globals["_PROVIDERMODELSREQUEST"]._serialized_end = 588
    _globals["_PROVIDERMODELSREQUESTBODY"]._serialized_start = 590
    _globals["_PROVIDERMODELSREQUESTBODY"]._serialized_end = 715
    _globals["_PROVIDERMODELSRESPONSE"]._serialized_start = 718
    _globals["_PROVIDERMODELSRESPONSE"]._serialized_end = 850
    _globals["_PROVIDERMODELSRESPONSEBODY"]._serialized_start = 852
    _globals["_PROVIDERMODELSRESPONSEBODY"]._serialized_end = 978
    _globals["_DELETEPROVIDERREQUEST"]._serialized_start = 981
    _globals["_DELETEPROVIDERREQUEST"]._serialized_end = 1111
    _globals["_DELETEPROVIDERREQUESTBODY"]._serialized_start = 1113
    _globals["_DELETEPROVIDERREQUESTBODY"]._serialized_end = 1153
    _globals["_DELETEPROVIDERRESPONSE"]._serialized_start = 1156
    _globals["_DELETEPROVIDERRESPONSE"]._serialized_end = 1288
    _globals["_DELETEPROVIDERRESPONSEBODY"]._serialized_start = 1290
    _globals["_DELETEPROVIDERRESPONSEBODY"]._serialized_end = 1369
    _globals["_SEARCHPROVIDERREQUEST"]._serialized_start = 1372
    _globals["_SEARCHPROVIDERREQUEST"]._serialized_end = 1502
    _globals["_SEARCHPROVIDERREQUESTBODY"]._serialized_start = 1505
    _globals["_SEARCHPROVIDERREQUESTBODY"]._serialized_end = 1638
    _globals["_SEARCHPROVIDERRESPONSE"]._serialized_start = 1641
    _globals["_SEARCHPROVIDERRESPONSE"]._serialized_end = 1773
    _globals["_SEARCHPROVIDERRESPONSEBODY"]._serialized_start = 1776
    _globals["_SEARCHPROVIDERRESPONSEBODY"]._serialized_end = 1908
    _globals["_ADDPROVIDERREQUEST"]._serialized_start = 1910
    _globals["_ADDPROVIDERREQUEST"]._serialized_end = 2034
    _globals["_ADDPROVIDERREQUESTBODY"]._serialized_start = 2036
    _globals["_ADDPROVIDERREQUESTBODY"]._serialized_end = 2112
    _globals["_ADDPROVIDERRESPONSE"]._serialized_start = 2114
    _globals["_ADDPROVIDERRESPONSE"]._serialized_end = 2240
    _globals["_ADDPROVIDERRESPONSEBODY"]._serialized_start = 2243
    _globals["_ADDPROVIDERRESPONSEBODY"]._serialized_end = 2371
    _globals["_PROVIDERDETAILREQUEST"]._serialized_start = 2374
    _globals["_PROVIDERDETAILREQUEST"]._serialized_end = 2504
    _globals["_PROVIDERDETAILREQUESTBODY"]._serialized_start = 2506
    _globals["_PROVIDERDETAILREQUESTBODY"]._serialized_end = 2546
    _globals["_PROVIDERDETAILRESPONSE"]._serialized_start = 2549
    _globals["_PROVIDERDETAILRESPONSE"]._serialized_end = 2681
    _globals["_PROVIDERDETAILRESPONSEBODY"]._serialized_start = 2683
    _globals["_PROVIDERDETAILRESPONSEBODY"]._serialized_end = 2810
    _globals["_PROVIDERDETAIL"]._serialized_start = 2812
    _globals["_PROVIDERDETAIL"]._serialized_end = 2926
    _globals["_PROVIDERDESCRIPTION"]._serialized_start = 2929
    _globals["_PROVIDERDESCRIPTION"]._serialized_end = 3109
    _globals["_SEARCHPROVIDERCONDITION"]._serialized_start = 3111
    _globals["_SEARCHPROVIDERCONDITION"]._serialized_end = 3184
    _globals["_PROVIDERMETADATA"]._serialized_start = 3187
    _globals["_PROVIDERMETADATA"]._serialized_end = 3438
    _globals["_MODELMETADATA"]._serialized_start = 3441
    _globals["_MODELMETADATA"]._serialized_end = 3623
    _globals["_PROVIDERSTATE"]._serialized_start = 3626
    _globals["_PROVIDERSTATE"]._serialized_end = 3802
    _globals["_PROVIDER"]._serialized_start = 4680
    _globals["_PROVIDER"]._serialized_end = 5245
# @@protoc_insertion_point(module_scope)
