# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/group.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/group.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&yeying/api/apps/zuoyepigai/group.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x82\x01\n\x0f\x41\x64\x64GroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.apps.zuoyepigai.AddGroupRequestBody"N\n\x13\x41\x64\x64GroupRequestBody\x12\x37\n\x04meta\x18\x01 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x84\x01\n\x10\x41\x64\x64GroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.apps.zuoyepigai.AddGroupResponseBody"\x82\x01\n\x14\x41\x64\x64GroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x88\x01\n\x12\x44\x65tailGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DetailGroupRequestBody"%\n\x16\x44\x65tailGroupRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8a\x01\n\x13\x44\x65tailGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.DetailGroupResponseBody"\xc5\x01\n\x17\x44\x65tailGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData\x12>\n\x0bstudentList\x18\x03 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x84\x01\n\x10ListGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.apps.zuoyepigai.ListGroupRequestBody"\x89\x01\n\x14ListGroupRequestBody\x12\x12\n\nteacherDid\x18\x01 \x01(\t\x12.\n\tpageIndex\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x86\x01\n\x11ListGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.ListGroupResponseBody"\x92\x01\n\x15ListGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04list\x18\x02 \x03(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData\x12\r\n\x05total\x18\x03 \x01(\x04"\x88\x01\n\x12UpdateGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.UpdateGroupRequestBody"Q\n\x16UpdateGroupRequestBody\x12\x37\n\x04meta\x18\x01 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x8a\x01\n\x13UpdateGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.UpdateGroupResponseBody"\x85\x01\n\x17UpdateGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData"\x88\x01\n\x12\x44\x65leteGroupRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.DeleteGroupRequestBody"%\n\x16\x44\x65leteGroupRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8a\x01\n\x13\x44\x65leteGroupResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.DeleteGroupResponseBody"\x85\x01\n\x17\x44\x65leteGroupResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\x04meta\x18\x02 \x01(\x0b\x32).yeying.api.apps.zuoyepigai.GroupMetaData2\x99\x04\n\x05Group\x12\x62\n\x03\x41\x64\x64\x12+.yeying.api.apps.zuoyepigai.AddGroupRequest\x1a,.yeying.api.apps.zuoyepigai.AddGroupResponse"\x00\x12k\n\x06\x44\x65tail\x12..yeying.api.apps.zuoyepigai.DetailGroupRequest\x1a/.yeying.api.apps.zuoyepigai.DetailGroupResponse"\x00\x12\x65\n\x04List\x12,.yeying.api.apps.zuoyepigai.ListGroupRequest\x1a-.yeying.api.apps.zuoyepigai.ListGroupResponse"\x00\x12k\n\x06Update\x12..yeying.api.apps.zuoyepigai.UpdateGroupRequest\x1a/.yeying.api.apps.zuoyepigai.UpdateGroupResponse"\x00\x12k\n\x06\x44\x65lete\x12..yeying.api.apps.zuoyepigai.DeleteGroupRequest\x1a/.yeying.api.apps.zuoyepigai.DeleteGroupResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.group_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ADDGROUPREQUEST"]._serialized_start = 175
    _globals["_ADDGROUPREQUEST"]._serialized_end = 305
    _globals["_ADDGROUPREQUESTBODY"]._serialized_start = 307
    _globals["_ADDGROUPREQUESTBODY"]._serialized_end = 385
    _globals["_ADDGROUPRESPONSE"]._serialized_start = 388
    _globals["_ADDGROUPRESPONSE"]._serialized_end = 520
    _globals["_ADDGROUPRESPONSEBODY"]._serialized_start = 523
    _globals["_ADDGROUPRESPONSEBODY"]._serialized_end = 653
    _globals["_DETAILGROUPREQUEST"]._serialized_start = 656
    _globals["_DETAILGROUPREQUEST"]._serialized_end = 792
    _globals["_DETAILGROUPREQUESTBODY"]._serialized_start = 794
    _globals["_DETAILGROUPREQUESTBODY"]._serialized_end = 831
    _globals["_DETAILGROUPRESPONSE"]._serialized_start = 834
    _globals["_DETAILGROUPRESPONSE"]._serialized_end = 972
    _globals["_DETAILGROUPRESPONSEBODY"]._serialized_start = 975
    _globals["_DETAILGROUPRESPONSEBODY"]._serialized_end = 1172
    _globals["_LISTGROUPREQUEST"]._serialized_start = 1175
    _globals["_LISTGROUPREQUEST"]._serialized_end = 1307
    _globals["_LISTGROUPREQUESTBODY"]._serialized_start = 1310
    _globals["_LISTGROUPREQUESTBODY"]._serialized_end = 1447
    _globals["_LISTGROUPRESPONSE"]._serialized_start = 1450
    _globals["_LISTGROUPRESPONSE"]._serialized_end = 1584
    _globals["_LISTGROUPRESPONSEBODY"]._serialized_start = 1587
    _globals["_LISTGROUPRESPONSEBODY"]._serialized_end = 1733
    _globals["_UPDATEGROUPREQUEST"]._serialized_start = 1736
    _globals["_UPDATEGROUPREQUEST"]._serialized_end = 1872
    _globals["_UPDATEGROUPREQUESTBODY"]._serialized_start = 1874
    _globals["_UPDATEGROUPREQUESTBODY"]._serialized_end = 1955
    _globals["_UPDATEGROUPRESPONSE"]._serialized_start = 1958
    _globals["_UPDATEGROUPRESPONSE"]._serialized_end = 2096
    _globals["_UPDATEGROUPRESPONSEBODY"]._serialized_start = 2099
    _globals["_UPDATEGROUPRESPONSEBODY"]._serialized_end = 2232
    _globals["_DELETEGROUPREQUEST"]._serialized_start = 2235
    _globals["_DELETEGROUPREQUEST"]._serialized_end = 2371
    _globals["_DELETEGROUPREQUESTBODY"]._serialized_start = 2373
    _globals["_DELETEGROUPREQUESTBODY"]._serialized_end = 2410
    _globals["_DELETEGROUPRESPONSE"]._serialized_start = 2413
    _globals["_DELETEGROUPRESPONSE"]._serialized_end = 2551
    _globals["_DELETEGROUPRESPONSEBODY"]._serialized_start = 2554
    _globals["_DELETEGROUPRESPONSEBODY"]._serialized_end = 2687
    _globals["_GROUP"]._serialized_start = 2690
    _globals["_GROUP"]._serialized_end = 3227
# @@protoc_insertion_point(module_scope)
