# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/node/node.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/node/node.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/node/node.proto\x12\x0fyeying.api.node\x1a\x1fyeying/api/common/message.proto\x1a\x1dyeying/api/common/model.proto"F\n\x12HealthCheckRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\x7f\n\x13HealthCheckResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.node.HealthCheckResponseBody"L\n\x17HealthCheckResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"A\n\rWhoamiRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"u\n\x0eWhoamiResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.node.WhoamiResponseBody"|\n\x12WhoamiResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x33\n\x07service\x18\x02 \x01(\x0b\x32".yeying.api.common.ServiceMetadata2\xaf\x01\n\x04Node\x12Z\n\x0bHealthCheck\x12#.yeying.api.node.HealthCheckRequest\x1a$.yeying.api.node.HealthCheckResponse"\x00\x12K\n\x06Whoami\x12\x1e.yeying.api.node.WhoamiRequest\x1a\x1f.yeying.api.node.WhoamiResponse"\x00\x42\x11Z\x0fyeying/api/nodeb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.node.node_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/node"
    _globals["_HEALTHCHECKREQUEST"]._serialized_start = 111
    _globals["_HEALTHCHECKREQUEST"]._serialized_end = 181
    _globals["_HEALTHCHECKRESPONSE"]._serialized_start = 183
    _globals["_HEALTHCHECKRESPONSE"]._serialized_end = 310
    _globals["_HEALTHCHECKRESPONSEBODY"]._serialized_start = 312
    _globals["_HEALTHCHECKRESPONSEBODY"]._serialized_end = 388
    _globals["_WHOAMIREQUEST"]._serialized_start = 390
    _globals["_WHOAMIREQUEST"]._serialized_end = 455
    _globals["_WHOAMIRESPONSE"]._serialized_start = 457
    _globals["_WHOAMIRESPONSE"]._serialized_end = 574
    _globals["_WHOAMIRESPONSEBODY"]._serialized_start = 576
    _globals["_WHOAMIRESPONSEBODY"]._serialized_end = 700
    _globals["_NODE"]._serialized_start = 703
    _globals["_NODE"]._serialized_end = 878
# @@protoc_insertion_point(module_scope)
