# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/config/config.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/config/config.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/config/config.proto\x12\x11yeying.api.config\x1a\x1fyeying/api/common/message.proto"{\n\x10GetConfigRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.config.GetConfigRequestBody"T\n\x14GetConfigRequestBody\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.yeying.api.config.ConfigTypeEnum"}\n\x11GetConfigResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.config.GetConfigResponseBody"}\n\x15GetConfigResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.yeying.api.config.ConfigMetadata"{\n\x10SetConfigRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.config.SetConfigRequestBody"I\n\x14SetConfigRequestBody\x12\x31\n\x06\x63onfig\x18\x01 \x01(\x0b\x32!.yeying.api.config.ConfigMetadata"}\n\x11SetConfigResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.config.SetConfigResponseBody"}\n\x15SetConfigResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.yeying.api.config.ConfigMetadata"t\n\x0e\x43onfigMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\t\x12\x11\n\tupdatedAt\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\t*W\n\x0e\x43onfigTypeEnum\x12\x17\n\x13\x43ONFIG_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12\x43ONFIG_TYPE_SYSTEM\x10\x01\x12\x14\n\x10\x43ONFIG_TYPE_USER\x10\x02\x32\xb0\x01\n\x06\x43onfig\x12R\n\x03Set\x12#.yeying.api.config.SetConfigRequest\x1a$.yeying.api.config.SetConfigResponse"\x00\x12R\n\x03Get\x12#.yeying.api.config.GetConfigRequest\x1a$.yeying.api.config.GetConfigResponse"\x00\x42\x13Z\x11yeying/api/configb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.config.config_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/config"
    _globals["_CONFIGTYPEENUM"]._serialized_start = 1123
    _globals["_CONFIGTYPEENUM"]._serialized_end = 1210
    _globals["_GETCONFIGREQUEST"]._serialized_start = 86
    _globals["_GETCONFIGREQUEST"]._serialized_end = 209
    _globals["_GETCONFIGREQUESTBODY"]._serialized_start = 211
    _globals["_GETCONFIGREQUESTBODY"]._serialized_end = 295
    _globals["_GETCONFIGRESPONSE"]._serialized_start = 297
    _globals["_GETCONFIGRESPONSE"]._serialized_end = 422
    _globals["_GETCONFIGRESPONSEBODY"]._serialized_start = 424
    _globals["_GETCONFIGRESPONSEBODY"]._serialized_end = 549
    _globals["_SETCONFIGREQUEST"]._serialized_start = 551
    _globals["_SETCONFIGREQUEST"]._serialized_end = 674
    _globals["_SETCONFIGREQUESTBODY"]._serialized_start = 676
    _globals["_SETCONFIGREQUESTBODY"]._serialized_end = 749
    _globals["_SETCONFIGRESPONSE"]._serialized_start = 751
    _globals["_SETCONFIGRESPONSE"]._serialized_end = 876
    _globals["_SETCONFIGRESPONSEBODY"]._serialized_start = 878
    _globals["_SETCONFIGRESPONSEBODY"]._serialized_end = 1003
    _globals["_CONFIGMETADATA"]._serialized_start = 1005
    _globals["_CONFIGMETADATA"]._serialized_end = 1121
    _globals["_CONFIG"]._serialized_start = 1213
    _globals["_CONFIG"]._serialized_end = 1389
# @@protoc_insertion_point(module_scope)
