# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/rag/memory.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'yeying/api/rag/memory.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1byeying/api/rag/memory.proto\x12\x0eyeying.api.rag\x1a\x1fyeying/api/common/message.proto\"~\n\x13\x43reateMemoryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.rag.CreateMemoryRequestBody\")\n\x17\x43reateMemoryRequestBody\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\"\x80\x01\n\x14\x43reateMemoryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.rag.CreateMemoryResponseBody\"`\n\x18\x43reateMemoryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x11\n\tmemory_id\x18\x02 \x01(\t\"x\n\x10\x41\x64\x64MemoryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.rag.AddMemoryRequestBody\"6\n\x14\x41\x64\x64MemoryRequestBody\x12\x11\n\tmemory_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"z\n\x11\x41\x64\x64MemoryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.rag.AddMemoryResponseBody\"J\n\x15\x41\x64\x64MemoryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\"~\n\x13\x44\x65leteMemoryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.rag.DeleteMemoryRequestBody\"9\n\x17\x44\x65leteMemoryRequestBody\x12\x11\n\tmemory_id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x80\x01\n\x14\x44\x65leteMemoryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.rag.DeleteMemoryResponseBody\"M\n\x18\x44\x65leteMemoryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\x84\x02\n\x06Memory\x12U\n\x06\x43reate\x12#.yeying.api.rag.CreateMemoryRequest\x1a$.yeying.api.rag.CreateMemoryResponse\"\x00\x12L\n\x03\x41\x64\x64\x12 .yeying.api.rag.AddMemoryRequest\x1a!.yeying.api.rag.AddMemoryResponse\"\x00\x12U\n\x06\x44\x65lete\x12#.yeying.api.rag.DeleteMemoryRequest\x1a$.yeying.api.rag.DeleteMemoryResponse\"\x00\x42\x11Z\x0fyeying/api/rag/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yeying.api.rag.memory_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\017yeying/api/rag/'
  _globals['_CREATEMEMORYREQUEST']._serialized_start=80
  _globals['_CREATEMEMORYREQUEST']._serialized_end=206
  _globals['_CREATEMEMORYREQUESTBODY']._serialized_start=208
  _globals['_CREATEMEMORYREQUESTBODY']._serialized_end=249
  _globals['_CREATEMEMORYRESPONSE']._serialized_start=252
  _globals['_CREATEMEMORYRESPONSE']._serialized_end=380
  _globals['_CREATEMEMORYRESPONSEBODY']._serialized_start=382
  _globals['_CREATEMEMORYRESPONSEBODY']._serialized_end=478
  _globals['_ADDMEMORYREQUEST']._serialized_start=480
  _globals['_ADDMEMORYREQUEST']._serialized_end=600
  _globals['_ADDMEMORYREQUESTBODY']._serialized_start=602
  _globals['_ADDMEMORYREQUESTBODY']._serialized_end=656
  _globals['_ADDMEMORYRESPONSE']._serialized_start=658
  _globals['_ADDMEMORYRESPONSE']._serialized_end=780
  _globals['_ADDMEMORYRESPONSEBODY']._serialized_start=782
  _globals['_ADDMEMORYRESPONSEBODY']._serialized_end=856
  _globals['_DELETEMEMORYREQUEST']._serialized_start=858
  _globals['_DELETEMEMORYREQUEST']._serialized_end=984
  _globals['_DELETEMEMORYREQUESTBODY']._serialized_start=986
  _globals['_DELETEMEMORYREQUESTBODY']._serialized_end=1043
  _globals['_DELETEMEMORYRESPONSE']._serialized_start=1046
  _globals['_DELETEMEMORYRESPONSE']._serialized_end=1174
  _globals['_DELETEMEMORYRESPONSEBODY']._serialized_start=1176
  _globals['_DELETEMEMORYRESPONSEBODY']._serialized_end=1253
  _globals['_MEMORY']._serialized_start=1256
  _globals['_MEMORY']._serialized_end=1516
# @@protoc_insertion_point(module_scope)
