# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/session/session.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/session/session.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/session/session.proto\x12\x12yeying.api.session\x1a\x1fyeying/api/common/message.proto"\x84\x01\n\x14\x43reateSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.CreateSessionRequestBody"P\n\x18\x43reateSessionRequestBody\x12\x34\n\x07session\x18\x01 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x86\x01\n\x15\x43reateSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.CreateSessionResponseBody"\x84\x01\n\x19\x43reateSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x34\n\x07session\x18\x02 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x84\x01\n\x14SessionDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.SessionDetailRequestBody"\'\n\x18SessionDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x86\x01\n\x15SessionDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.SessionDetailResponseBody"\x81\x01\n\x19SessionDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x31\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32!.yeying.api.session.SessionDetail"E\n\rSessionDetail\x12\x34\n\x07session\x18\x01 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x84\x01\n\x14\x44\x65leteSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.DeleteSessionRequestBody"\'\n\x18\x44\x65leteSessionRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x86\x01\n\x15\x44\x65leteSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.DeleteSessionResponseBody"N\n\x19\x44\x65leteSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x84\x01\n\x14SearchSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.SearchSessionRequestBody"\x87\x01\n\x18SearchSessionRequestBody\x12=\n\tcondition\x18\x01 \x01(\x0b\x32*.yeying.api.session.SearchSessionCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"3\n\x16SearchSessionCondition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t"\x86\x01\n\x15SearchSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.SearchSessionResponseBody"\x85\x01\n\x19SearchSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x35\n\x08sessions\x18\x02 \x03(\x0b\x32#.yeying.api.session.SessionMetadata"\x84\x01\n\x14UpdateSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.session.UpdateSessionRequestBody"P\n\x18UpdateSessionRequestBody\x12\x34\n\x07session\x18\x01 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x86\x01\n\x15UpdateSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.session.UpdateSessionResponseBody"\x84\x01\n\x19UpdateSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x34\n\x07session\x18\x02 \x01(\x0b\x32#.yeying.api.session.SessionMetadata"\x99\x01\n\x0fSessionMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tupdatedAt\x18\x07 \x01(\t\x12\x11\n\tsignature\x18\x08 \x01(\t2\xee\x03\n\x07Session\x12_\n\x06\x43reate\x12(.yeying.api.session.CreateSessionRequest\x1a).yeying.api.session.CreateSessionResponse"\x00\x12_\n\x06\x44\x65lete\x12(.yeying.api.session.DeleteSessionRequest\x1a).yeying.api.session.DeleteSessionResponse"\x00\x12_\n\x06\x44\x65tail\x12(.yeying.api.session.SessionDetailRequest\x1a).yeying.api.session.SessionDetailResponse"\x00\x12_\n\x06Search\x12(.yeying.api.session.SearchSessionRequest\x1a).yeying.api.session.SearchSessionResponse"\x00\x12_\n\x06Update\x12(.yeying.api.session.UpdateSessionRequest\x1a).yeying.api.session.UpdateSessionResponse"\x00\x42\x14Z\x12yeying/api/sessionb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.session.session_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/session"
    _globals["_CREATESESSIONREQUEST"]._serialized_start = 90
    _globals["_CREATESESSIONREQUEST"]._serialized_end = 222
    _globals["_CREATESESSIONREQUESTBODY"]._serialized_start = 224
    _globals["_CREATESESSIONREQUESTBODY"]._serialized_end = 304
    _globals["_CREATESESSIONRESPONSE"]._serialized_start = 307
    _globals["_CREATESESSIONRESPONSE"]._serialized_end = 441
    _globals["_CREATESESSIONRESPONSEBODY"]._serialized_start = 444
    _globals["_CREATESESSIONRESPONSEBODY"]._serialized_end = 576
    _globals["_SESSIONDETAILREQUEST"]._serialized_start = 579
    _globals["_SESSIONDETAILREQUEST"]._serialized_end = 711
    _globals["_SESSIONDETAILREQUESTBODY"]._serialized_start = 713
    _globals["_SESSIONDETAILREQUESTBODY"]._serialized_end = 752
    _globals["_SESSIONDETAILRESPONSE"]._serialized_start = 755
    _globals["_SESSIONDETAILRESPONSE"]._serialized_end = 889
    _globals["_SESSIONDETAILRESPONSEBODY"]._serialized_start = 892
    _globals["_SESSIONDETAILRESPONSEBODY"]._serialized_end = 1021
    _globals["_SESSIONDETAIL"]._serialized_start = 1023
    _globals["_SESSIONDETAIL"]._serialized_end = 1092
    _globals["_DELETESESSIONREQUEST"]._serialized_start = 1095
    _globals["_DELETESESSIONREQUEST"]._serialized_end = 1227
    _globals["_DELETESESSIONREQUESTBODY"]._serialized_start = 1229
    _globals["_DELETESESSIONREQUESTBODY"]._serialized_end = 1268
    _globals["_DELETESESSIONRESPONSE"]._serialized_start = 1271
    _globals["_DELETESESSIONRESPONSE"]._serialized_end = 1405
    _globals["_DELETESESSIONRESPONSEBODY"]._serialized_start = 1407
    _globals["_DELETESESSIONRESPONSEBODY"]._serialized_end = 1485
    _globals["_SEARCHSESSIONREQUEST"]._serialized_start = 1488
    _globals["_SEARCHSESSIONREQUEST"]._serialized_end = 1620
    _globals["_SEARCHSESSIONREQUESTBODY"]._serialized_start = 1623
    _globals["_SEARCHSESSIONREQUESTBODY"]._serialized_end = 1758
    _globals["_SEARCHSESSIONCONDITION"]._serialized_start = 1760
    _globals["_SEARCHSESSIONCONDITION"]._serialized_end = 1811
    _globals["_SEARCHSESSIONRESPONSE"]._serialized_start = 1814
    _globals["_SEARCHSESSIONRESPONSE"]._serialized_end = 1948
    _globals["_SEARCHSESSIONRESPONSEBODY"]._serialized_start = 1951
    _globals["_SEARCHSESSIONRESPONSEBODY"]._serialized_end = 2084
    _globals["_UPDATESESSIONREQUEST"]._serialized_start = 2087
    _globals["_UPDATESESSIONREQUEST"]._serialized_end = 2219
    _globals["_UPDATESESSIONREQUESTBODY"]._serialized_start = 2221
    _globals["_UPDATESESSIONREQUESTBODY"]._serialized_end = 2301
    _globals["_UPDATESESSIONRESPONSE"]._serialized_start = 2304
    _globals["_UPDATESESSIONRESPONSE"]._serialized_end = 2438
    _globals["_UPDATESESSIONRESPONSEBODY"]._serialized_start = 2441
    _globals["_UPDATESESSIONRESPONSEBODY"]._serialized_end = 2573
    _globals["_SESSIONMETADATA"]._serialized_start = 2576
    _globals["_SESSIONMETADATA"]._serialized_end = 2729
    _globals["_SESSION"]._serialized_start = 2732
    _globals["_SESSION"]._serialized_end = 3226
# @@protoc_insertion_point(module_scope)
