# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/bulletin/bulletin.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/bulletin/bulletin.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"yeying/api/bulletin/bulletin.proto\x12\x13yeying.api.bulletin\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"\x83\x01\n\x13\x42ulletinListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.bulletin.BulletinListRequestBody"\xb3\x01\n\x17\x42ulletinListRequestBody\x12\x33\n\x04\x63ode\x18\x01 \x01(\x0e\x32%.yeying.api.bulletin.BulletinCodeEnum\x12\x35\n\x08language\x18\x02 \x01(\x0e\x32#.yeying.api.common.LanguageCodeEnum\x12,\n\x04page\x18\x03 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x85\x01\n\x14\x42ulletinListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.bulletin.BulletinListResponseBody"\xb6\x01\n\x18\x42ulletinListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x38\n\tsolutions\x18\x02 \x03(\x0b\x32%.yeying.api.bulletin.SolutionMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\xe4\x01\n\x10SolutionMetadata\x12\x11\n\tpublisher\x18\x01 \x01(\t\x12\x35\n\x08language\x18\x02 \x01(\x0e\x32#.yeying.api.common.LanguageCodeEnum\x12\x0b\n\x03uid\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x30\n\x05\x63\x61rds\x18\x07 \x03(\x0b\x32!.yeying.api.bulletin.SolutionCard\x12\x11\n\tsignature\x18\x08 \x01(\t">\n\x0cSolutionCard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\t\x12\x11\n\tvariables\x18\x03 \x01(\t*.\n\x10\x42ulletinCodeEnum\x12\x1a\n\x16\x42ULLETIN_CODE_SOLUTION\x10\x00\x32i\n\x08\x42ulletin\x12]\n\x04List\x12(.yeying.api.bulletin.BulletinListRequest\x1a).yeying.api.bulletin.BulletinListResponse"\x00\x42\x15Z\x13yeying/api/bulletinb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.bulletin.bulletin_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\023yeying/api/bulletin"
    _globals["_BULLETINCODEENUM"]._serialized_start = 1054
    _globals["_BULLETINCODEENUM"]._serialized_end = 1100
    _globals["_BULLETINLISTREQUEST"]._serialized_start = 123
    _globals["_BULLETINLISTREQUEST"]._serialized_end = 254
    _globals["_BULLETINLISTREQUESTBODY"]._serialized_start = 257
    _globals["_BULLETINLISTREQUESTBODY"]._serialized_end = 436
    _globals["_BULLETINLISTRESPONSE"]._serialized_start = 439
    _globals["_BULLETINLISTRESPONSE"]._serialized_end = 572
    _globals["_BULLETINLISTRESPONSEBODY"]._serialized_start = 575
    _globals["_BULLETINLISTRESPONSEBODY"]._serialized_end = 757
    _globals["_SOLUTIONMETADATA"]._serialized_start = 760
    _globals["_SOLUTIONMETADATA"]._serialized_end = 988
    _globals["_SOLUTIONCARD"]._serialized_start = 990
    _globals["_SOLUTIONCARD"]._serialized_end = 1052
    _globals["_BULLETIN"]._serialized_start = 1102
    _globals["_BULLETIN"]._serialized_end = 1207
# @@protoc_insertion_point(module_scope)
