# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/link.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/link.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1byeying/api/asset/link.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto"|\n\x11\x43reateLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.CreateLinkRequestBody"E\n\x15\x43reateLinkRequestBody\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12\x43reateLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.CreateLinkResponseBody"y\n\x16\x43reateLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12,\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1c.yeying.api.asset.LinkDetail"|\n\x11SearchLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.SearchLinkRequestBody"\x7f\n\x15SearchLinkRequestBody\x12,\n\x04page\x18\x01 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage\x12\x38\n\tcondition\x18\x02 \x01(\x0b\x32%.yeying.api.asset.SearchLinkCondition"#\n\x13SearchLinkCondition\x12\x0c\n\x04hash\x18\x01 \x01(\t"~\n\x12SearchLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.SearchLinkResponseBody"\xa9\x01\n\x16SearchLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04page\x18\x02 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage\x12-\n\x05links\x18\x03 \x03(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12\x44isableLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.DisableLinkRequestBody"(\n\x16\x44isableLinkRequestBody\x12\x0e\n\x06linkId\x18\x01 \x01(\t"\x80\x01\n\x13\x44isableLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.DisableLinkResponseBody"L\n\x17\x44isableLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"|\n\x11UpdateLinkRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.UpdateLinkRequestBody"E\n\x15UpdateLinkRequestBody\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12UpdateLinkResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.UpdateLinkResponseBody"y\n\x16UpdateLinkResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12,\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1c.yeying.api.asset.LinkDetail"|\n\x11LinkDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.LinkDetailRequestBody"$\n\x15LinkDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"~\n\x12LinkDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.LinkDetailResponseBody"y\n\x16LinkDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12,\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1c.yeying.api.asset.LinkDetail"f\n\nLinkDetail\x12*\n\x03url\x18\x01 \x01(\x0b\x32\x1d.yeying.api.asset.UrlMetadata\x12,\n\x04link\x18\x02 \x01(\x0b\x32\x1e.yeying.api.asset.LinkMetadata"~\n\x12LinkVisitorRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.LinkVisitorRequestBody"S\n\x16LinkVisitorRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x80\x01\n\x13LinkVisitorResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.LinkVisitorResponseBody"\xb0\x01\n\x17LinkVisitorResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04page\x18\x02 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage\x12\x33\n\x08visitors\x18\x03 \x03(\x0b\x32!.yeying.api.asset.VisitorMetadata"\x8b\x02\n\x0cLinkMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12,\n\x04type\x18\x03 \x01(\x0e\x32\x1e.yeying.api.asset.LinkTypeEnum\x12\x10\n\x08visitors\x18\x04 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x0c\n\x04hash\x18\x08 \x01(\t\x12\r\n\x05token\x18\t \x01(\t\x12\x11\n\tstartedAt\x18\n \x01(\t\x12\x11\n\texpiredAt\x18\x0b \x01(\t\x12\x11\n\tcreatedAt\x18\x0c \x01(\t\x12\x11\n\tsignature\x18\r \x01(\t"\xb7\x01\n\x0bUrlMetadata\x12\x12\n\nserviceDid\x18\x01 \x01(\t\x12\x0e\n\x06linkId\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12/\n\x06status\x18\x05 \x01(\x0e\x32\x1f.yeying.api.asset.UrlStatusEnum\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tupdatedAt\x18\x07 \x01(\t\x12\x11\n\tsignature\x18\x08 \x01(\t"T\n\x0fVisitorMetadata\x12\x0e\n\x06linkId\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t*V\n\rUrlStatusEnum\x12\x16\n\x12URL_STATUS_UNKNOWN\x10\x00\x12\x15\n\x11URL_STATUS_ENABLE\x10\x01\x12\x16\n\x12URL_STATUS_DISABLE\x10\x02*X\n\x0cLinkTypeEnum\x12\x15\n\x11LINK_TYPE_UNKNOWN\x10\x00\x12\x14\n\x10LINK_TYPE_PUBLIC\x10\x01\x12\x1b\n\x17LINK_TYPE_AUTHENTICATED\x10\x02\x32\x96\x04\n\x04Link\x12U\n\x06\x43reate\x12#.yeying.api.asset.CreateLinkRequest\x1a$.yeying.api.asset.CreateLinkResponse"\x00\x12U\n\x06Search\x12#.yeying.api.asset.SearchLinkRequest\x1a$.yeying.api.asset.SearchLinkResponse"\x00\x12U\n\x06\x44\x65tail\x12#.yeying.api.asset.LinkDetailRequest\x1a$.yeying.api.asset.LinkDetailResponse"\x00\x12X\n\x07Visitor\x12$.yeying.api.asset.LinkVisitorRequest\x1a%.yeying.api.asset.LinkVisitorResponse"\x00\x12X\n\x07\x44isable\x12$.yeying.api.asset.DisableLinkRequest\x1a%.yeying.api.asset.DisableLinkResponse"\x00\x12U\n\x06Update\x12#.yeying.api.asset.UpdateLinkRequest\x1a$.yeying.api.asset.UpdateLinkResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.link_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_URLSTATUSENUM"]._serialized_start = 3533
    _globals["_URLSTATUSENUM"]._serialized_end = 3619
    _globals["_LINKTYPEENUM"]._serialized_start = 3621
    _globals["_LINKTYPEENUM"]._serialized_end = 3709
    _globals["_CREATELINKREQUEST"]._serialized_start = 82
    _globals["_CREATELINKREQUEST"]._serialized_end = 206
    _globals["_CREATELINKREQUESTBODY"]._serialized_start = 208
    _globals["_CREATELINKREQUESTBODY"]._serialized_end = 277
    _globals["_CREATELINKRESPONSE"]._serialized_start = 279
    _globals["_CREATELINKRESPONSE"]._serialized_end = 405
    _globals["_CREATELINKRESPONSEBODY"]._serialized_start = 407
    _globals["_CREATELINKRESPONSEBODY"]._serialized_end = 528
    _globals["_SEARCHLINKREQUEST"]._serialized_start = 530
    _globals["_SEARCHLINKREQUEST"]._serialized_end = 654
    _globals["_SEARCHLINKREQUESTBODY"]._serialized_start = 656
    _globals["_SEARCHLINKREQUESTBODY"]._serialized_end = 783
    _globals["_SEARCHLINKCONDITION"]._serialized_start = 785
    _globals["_SEARCHLINKCONDITION"]._serialized_end = 820
    _globals["_SEARCHLINKRESPONSE"]._serialized_start = 822
    _globals["_SEARCHLINKRESPONSE"]._serialized_end = 948
    _globals["_SEARCHLINKRESPONSEBODY"]._serialized_start = 951
    _globals["_SEARCHLINKRESPONSEBODY"]._serialized_end = 1120
    _globals["_DISABLELINKREQUEST"]._serialized_start = 1122
    _globals["_DISABLELINKREQUEST"]._serialized_end = 1248
    _globals["_DISABLELINKREQUESTBODY"]._serialized_start = 1250
    _globals["_DISABLELINKREQUESTBODY"]._serialized_end = 1290
    _globals["_DISABLELINKRESPONSE"]._serialized_start = 1293
    _globals["_DISABLELINKRESPONSE"]._serialized_end = 1421
    _globals["_DISABLELINKRESPONSEBODY"]._serialized_start = 1423
    _globals["_DISABLELINKRESPONSEBODY"]._serialized_end = 1499
    _globals["_UPDATELINKREQUEST"]._serialized_start = 1501
    _globals["_UPDATELINKREQUEST"]._serialized_end = 1625
    _globals["_UPDATELINKREQUESTBODY"]._serialized_start = 1627
    _globals["_UPDATELINKREQUESTBODY"]._serialized_end = 1696
    _globals["_UPDATELINKRESPONSE"]._serialized_start = 1698
    _globals["_UPDATELINKRESPONSE"]._serialized_end = 1824
    _globals["_UPDATELINKRESPONSEBODY"]._serialized_start = 1826
    _globals["_UPDATELINKRESPONSEBODY"]._serialized_end = 1947
    _globals["_LINKDETAILREQUEST"]._serialized_start = 1949
    _globals["_LINKDETAILREQUEST"]._serialized_end = 2073
    _globals["_LINKDETAILREQUESTBODY"]._serialized_start = 2075
    _globals["_LINKDETAILREQUESTBODY"]._serialized_end = 2111
    _globals["_LINKDETAILRESPONSE"]._serialized_start = 2113
    _globals["_LINKDETAILRESPONSE"]._serialized_end = 2239
    _globals["_LINKDETAILRESPONSEBODY"]._serialized_start = 2241
    _globals["_LINKDETAILRESPONSEBODY"]._serialized_end = 2362
    _globals["_LINKDETAIL"]._serialized_start = 2364
    _globals["_LINKDETAIL"]._serialized_end = 2466
    _globals["_LINKVISITORREQUEST"]._serialized_start = 2468
    _globals["_LINKVISITORREQUEST"]._serialized_end = 2594
    _globals["_LINKVISITORREQUESTBODY"]._serialized_start = 2596
    _globals["_LINKVISITORREQUESTBODY"]._serialized_end = 2679
    _globals["_LINKVISITORRESPONSE"]._serialized_start = 2682
    _globals["_LINKVISITORRESPONSE"]._serialized_end = 2810
    _globals["_LINKVISITORRESPONSEBODY"]._serialized_start = 2813
    _globals["_LINKVISITORRESPONSEBODY"]._serialized_end = 2989
    _globals["_LINKMETADATA"]._serialized_start = 2992
    _globals["_LINKMETADATA"]._serialized_end = 3259
    _globals["_URLMETADATA"]._serialized_start = 3262
    _globals["_URLMETADATA"]._serialized_end = 3445
    _globals["_VISITORMETADATA"]._serialized_start = 3447
    _globals["_VISITORMETADATA"]._serialized_end = 3531
    _globals["_LINK"]._serialized_start = 3712
    _globals["_LINK"]._serialized_end = 4246
# @@protoc_insertion_point(module_scope)
