# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/common/model.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/common/model.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dyeying/api/common/model.proto\x12\x11yeying.api.common\x1a\x1cyeying/api/common/code.proto"\xf9\x02\n\x13\x41pplicationMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x0b\n\x03\x64id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x0c\n\x04hash\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x34\n\x04\x63ode\x18\x08 \x01(\x0e\x32&.yeying.api.common.ApplicationCodeEnum\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x10\n\x08location\x18\n \x01(\t\x12\x38\n\x0cserviceCodes\x18\x0b \x03(\x0e\x32".yeying.api.common.ServiceCodeEnum\x12\x0e\n\x06\x61vatar\x18\x0c \x01(\t\x12\x11\n\tcreatedAt\x18\r \x01(\t\x12\x11\n\tupdatedAt\x18\x0e \x01(\t\x12\x11\n\tsignature\x18\x0f \x01(\t\x12\x17\n\x0f\x63odePackagePath\x18\x10 \x01(\t"\xe6\x02\n\x0fServiceMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x0b\n\x03\x64id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x30\n\x04\x63ode\x18\x08 \x01(\x0e\x32".yeying.api.common.ServiceCodeEnum\x12\x30\n\x08\x61piCodes\x18\t \x03(\x0e\x32\x1e.yeying.api.common.ApiCodeEnum\x12\r\n\x05proxy\x18\n \x01(\t\x12\x0c\n\x04grpc\x18\x0b \x01(\t\x12\x0e\n\x06\x61vatar\x18\x0c \x01(\t\x12\x11\n\tcreatedAt\x18\r \x01(\t\x12\x11\n\tupdatedAt\x18\x0e \x01(\t\x12\x11\n\tsignature\x18\x0f \x01(\t\x12\x17\n\x0f\x63odePackagePath\x18\x10 \x01(\t"\xd0\x01\n\rStateMetadata\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x38\n\x06status\x18\x03 \x01(\x0e\x32(.yeying.api.common.ApplicationStatusEnum\x12\x11\n\tsignature\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t\x12.\n\x04type\x18\x07 \x01(\x0e\x32 .yeying.api.common.AuditTypeEnumB\x13Z\x11yeying/api/commonb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.common.model_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/common"
    _globals["_APPLICATIONMETADATA"]._serialized_start = 83
    _globals["_APPLICATIONMETADATA"]._serialized_end = 460
    _globals["_SERVICEMETADATA"]._serialized_start = 463
    _globals["_SERVICEMETADATA"]._serialized_end = 821
    _globals["_STATEMETADATA"]._serialized_start = 824
    _globals["_STATEMETADATA"]._serialized_end = 1032
# @@protoc_insertion_point(module_scope)
