# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/tasktag.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/tasktag.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/apps/zuoyepigai/tasktag.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x86\x01\n\x11\x41\x64\x64TaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.AddTaskTagRequestBody"R\n\x15\x41\x64\x64TaskTagRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x88\x01\n\x12\x41\x64\x64TaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.AddTaskTagResponseBody"\x86\x01\n\x16\x41\x64\x64TaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8c\x01\n\x14\x44\x65tailTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.DetailTaskTagRequestBody"\'\n\x18\x44\x65tailTaskTagRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x44\x65tailTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.DetailTaskTagResponseBody"\x89\x01\n\x19\x44\x65tailTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x88\x01\n\x12ListTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.ListTaskTagRequestBody"%\n\x16ListTaskTagRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8a\x01\n\x13ListTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.ListTaskTagResponseBody"\x87\x01\n\x17ListTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04list\x18\x02 \x03(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8c\x01\n\x14UpdateTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.UpdateTaskTagRequestBody"U\n\x18UpdateTaskTagRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8e\x01\n\x15UpdateTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.UpdateTaskTagResponseBody"\x89\x01\n\x19UpdateTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata"\x8c\x01\n\x14\x44\x65leteTaskTagRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.DeleteTaskTagRequestBody"\'\n\x18\x44\x65leteTaskTagRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x44\x65leteTaskTagResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.DeleteTaskTagResponseBody"\x89\x01\n\x19\x44\x65leteTaskTagResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.TaskTagMetadata2\xaf\x04\n\x07TaskTag\x12\x66\n\x03\x41\x64\x64\x12-.yeying.api.apps.zuoyepigai.AddTaskTagRequest\x1a..yeying.api.apps.zuoyepigai.AddTaskTagResponse"\x00\x12o\n\x06\x44\x65tail\x12\x30.yeying.api.apps.zuoyepigai.DetailTaskTagRequest\x1a\x31.yeying.api.apps.zuoyepigai.DetailTaskTagResponse"\x00\x12i\n\x04List\x12..yeying.api.apps.zuoyepigai.ListTaskTagRequest\x1a/.yeying.api.apps.zuoyepigai.ListTaskTagResponse"\x00\x12o\n\x06Update\x12\x30.yeying.api.apps.zuoyepigai.UpdateTaskTagRequest\x1a\x31.yeying.api.apps.zuoyepigai.UpdateTaskTagResponse"\x00\x12o\n\x06\x44\x65lete\x12\x30.yeying.api.apps.zuoyepigai.DeleteTaskTagRequest\x1a\x31.yeying.api.apps.zuoyepigai.DeleteTaskTagResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.tasktag_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ADDTASKTAGREQUEST"]._serialized_start = 145
    _globals["_ADDTASKTAGREQUEST"]._serialized_end = 279
    _globals["_ADDTASKTAGREQUESTBODY"]._serialized_start = 281
    _globals["_ADDTASKTAGREQUESTBODY"]._serialized_end = 363
    _globals["_ADDTASKTAGRESPONSE"]._serialized_start = 366
    _globals["_ADDTASKTAGRESPONSE"]._serialized_end = 502
    _globals["_ADDTASKTAGRESPONSEBODY"]._serialized_start = 505
    _globals["_ADDTASKTAGRESPONSEBODY"]._serialized_end = 639
    _globals["_DETAILTASKTAGREQUEST"]._serialized_start = 642
    _globals["_DETAILTASKTAGREQUEST"]._serialized_end = 782
    _globals["_DETAILTASKTAGREQUESTBODY"]._serialized_start = 784
    _globals["_DETAILTASKTAGREQUESTBODY"]._serialized_end = 823
    _globals["_DETAILTASKTAGRESPONSE"]._serialized_start = 826
    _globals["_DETAILTASKTAGRESPONSE"]._serialized_end = 968
    _globals["_DETAILTASKTAGRESPONSEBODY"]._serialized_start = 971
    _globals["_DETAILTASKTAGRESPONSEBODY"]._serialized_end = 1108
    _globals["_LISTTASKTAGREQUEST"]._serialized_start = 1111
    _globals["_LISTTASKTAGREQUEST"]._serialized_end = 1247
    _globals["_LISTTASKTAGREQUESTBODY"]._serialized_start = 1249
    _globals["_LISTTASKTAGREQUESTBODY"]._serialized_end = 1286
    _globals["_LISTTASKTAGRESPONSE"]._serialized_start = 1289
    _globals["_LISTTASKTAGRESPONSE"]._serialized_end = 1427
    _globals["_LISTTASKTAGRESPONSEBODY"]._serialized_start = 1430
    _globals["_LISTTASKTAGRESPONSEBODY"]._serialized_end = 1565
    _globals["_UPDATETASKTAGREQUEST"]._serialized_start = 1568
    _globals["_UPDATETASKTAGREQUEST"]._serialized_end = 1708
    _globals["_UPDATETASKTAGREQUESTBODY"]._serialized_start = 1710
    _globals["_UPDATETASKTAGREQUESTBODY"]._serialized_end = 1795
    _globals["_UPDATETASKTAGRESPONSE"]._serialized_start = 1798
    _globals["_UPDATETASKTAGRESPONSE"]._serialized_end = 1940
    _globals["_UPDATETASKTAGRESPONSEBODY"]._serialized_start = 1943
    _globals["_UPDATETASKTAGRESPONSEBODY"]._serialized_end = 2080
    _globals["_DELETETASKTAGREQUEST"]._serialized_start = 2083
    _globals["_DELETETASKTAGREQUEST"]._serialized_end = 2223
    _globals["_DELETETASKTAGREQUESTBODY"]._serialized_start = 2225
    _globals["_DELETETASKTAGREQUESTBODY"]._serialized_end = 2264
    _globals["_DELETETASKTAGRESPONSE"]._serialized_start = 2267
    _globals["_DELETETASKTAGRESPONSE"]._serialized_end = 2409
    _globals["_DELETETASKTAGRESPONSEBODY"]._serialized_start = 2412
    _globals["_DELETETASKTAGRESPONSEBODY"]._serialized_end = 2549
    _globals["_TASKTAG"]._serialized_start = 2552
    _globals["_TASKTAG"]._serialized_end = 3111
# @@protoc_insertion_point(module_scope)
