# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/block.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/block.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/asset/block.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto"\x80\x01\n\x13\x43onfirmBlockRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.ConfirmBlockRequestBody"I\n\x17\x43onfirmBlockRequestBody\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\x82\x01\n\x14\x43onfirmBlockResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x38\n\x04\x62ody\x18\x02 \x01(\x0b\x32*.yeying.api.asset.ConfirmBlockResponseBody"}\n\x18\x43onfirmBlockResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\xd6\x01\n\x15StreamPutBlockRequest\x12;\n\x04head\x18\x02 \x01(\x0b\x32+.yeying.api.asset.StreamPutBlockRequestHeadH\x00\x12;\n\x04\x62ody\x18\x03 \x01(\x0b\x32+.yeying.api.asset.StreamPutBlockRequestBodyH\x00\x12;\n\x04Tail\x18\x04 \x01(\x0b\x32+.yeying.api.asset.StreamPutBlockRequestTailH\x00\x42\x06\n\x04\x64\x61ta"\x8c\x01\n\x19StreamPutBlockRequestHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.StreamPutBlockRequestHeadBody"O\n\x1dStreamPutBlockRequestHeadBody\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata")\n\x19StreamPutBlockRequestBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c"M\n\x19StreamPutBlockRequestTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\x9c\x01\n\x16StreamPutBlockResponse\x12<\n\x04head\x18\x01 \x01(\x0b\x32,.yeying.api.asset.StreamPutBlockResponseHeadH\x00\x12<\n\x04tail\x18\x02 \x01(\x0b\x32,.yeying.api.asset.StreamPutBlockResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x8e\x01\n\x1aStreamPutBlockResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamPutBlockResponseHeadBody"\x83\x01\n\x1eStreamPutBlockResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\x8e\x01\n\x1aStreamPutBlockResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamPutBlockResponseTailBody"S\n\x1eStreamPutBlockResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x86\x01\n\x0fPutBlockRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.asset.PutBlockRequestBody\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c"E\n\x13PutBlockRequestBody\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"z\n\x10PutBlockResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.asset.PutBlockResponseBody"y\n\x14PutBlockResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"x\n\x0fGetBlockRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.asset.GetBlockRequestBody"8\n\x13GetBlockRequestBody\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t"\x99\x01\n\x15StreamGetBlockRequest\x12;\n\x04head\x18\x02 \x01(\x0b\x32+.yeying.api.asset.StreamGetBlockRequestHeadH\x00\x12;\n\x04\x62ody\x18\x03 \x01(\x0b\x32+.yeying.api.asset.StreamGetBlockRequestBodyH\x00\x42\x06\n\x04\x64\x61ta"\x8c\x01\n\x19StreamGetBlockRequestHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.StreamGetBlockRequestHeadBody"B\n\x1dStreamGetBlockRequestHeadBody\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t"M\n\x19StreamGetBlockRequestBody\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"\xda\x01\n\x16StreamGetBlockResponse\x12<\n\x04head\x18\x02 \x01(\x0b\x32,.yeying.api.asset.StreamGetBlockResponseHeadH\x00\x12<\n\x04\x62ody\x18\x03 \x01(\x0b\x32,.yeying.api.asset.StreamGetBlockResponseBodyH\x00\x12<\n\x04tail\x18\x04 \x01(\x0b\x32,.yeying.api.asset.StreamGetBlockResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x8e\x01\n\x1aStreamGetBlockResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamGetBlockResponseHeadBody"\x83\x01\n\x1eStreamGetBlockResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"*\n\x1aStreamGetBlockResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c"\x8e\x01\n\x1aStreamGetBlockResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.StreamGetBlockResponseTailBody"S\n\x1eStreamGetBlockResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"y\n\x14GetBlockResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.BlockMetadata"\x88\x01\n\x10GetBlockResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.asset.GetBlockResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c"\x87\x01\n\rBlockMetadata\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\x10\n\x08uploader\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x04\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t2\xcf\x03\n\x05\x42lock\x12N\n\x03Put\x12!.yeying.api.asset.PutBlockRequest\x1a".yeying.api.asset.PutBlockResponse"\x00\x12\x64\n\tStreamPut\x12\'.yeying.api.asset.StreamPutBlockRequest\x1a(.yeying.api.asset.StreamPutBlockResponse"\x00(\x01\x30\x01\x12Z\n\x07\x43onfirm\x12%.yeying.api.asset.ConfirmBlockRequest\x1a&.yeying.api.asset.ConfirmBlockResponse"\x00\x12N\n\x03Get\x12!.yeying.api.asset.GetBlockRequest\x1a".yeying.api.asset.GetBlockResponse"\x00\x12\x64\n\tStreamGet\x12\'.yeying.api.asset.StreamGetBlockRequest\x1a(.yeying.api.asset.StreamGetBlockResponse"\x00(\x01\x30\x01\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.block_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_CONFIRMBLOCKREQUEST"]._serialized_start = 84
    _globals["_CONFIRMBLOCKREQUEST"]._serialized_end = 212
    _globals["_CONFIRMBLOCKREQUESTBODY"]._serialized_start = 214
    _globals["_CONFIRMBLOCKREQUESTBODY"]._serialized_end = 287
    _globals["_CONFIRMBLOCKRESPONSE"]._serialized_start = 290
    _globals["_CONFIRMBLOCKRESPONSE"]._serialized_end = 420
    _globals["_CONFIRMBLOCKRESPONSEBODY"]._serialized_start = 422
    _globals["_CONFIRMBLOCKRESPONSEBODY"]._serialized_end = 547
    _globals["_STREAMPUTBLOCKREQUEST"]._serialized_start = 550
    _globals["_STREAMPUTBLOCKREQUEST"]._serialized_end = 764
    _globals["_STREAMPUTBLOCKREQUESTHEAD"]._serialized_start = 767
    _globals["_STREAMPUTBLOCKREQUESTHEAD"]._serialized_end = 907
    _globals["_STREAMPUTBLOCKREQUESTHEADBODY"]._serialized_start = 909
    _globals["_STREAMPUTBLOCKREQUESTHEADBODY"]._serialized_end = 988
    _globals["_STREAMPUTBLOCKREQUESTBODY"]._serialized_start = 990
    _globals["_STREAMPUTBLOCKREQUESTBODY"]._serialized_end = 1031
    _globals["_STREAMPUTBLOCKREQUESTTAIL"]._serialized_start = 1033
    _globals["_STREAMPUTBLOCKREQUESTTAIL"]._serialized_end = 1110
    _globals["_STREAMPUTBLOCKRESPONSE"]._serialized_start = 1113
    _globals["_STREAMPUTBLOCKRESPONSE"]._serialized_end = 1269
    _globals["_STREAMPUTBLOCKRESPONSEHEAD"]._serialized_start = 1272
    _globals["_STREAMPUTBLOCKRESPONSEHEAD"]._serialized_end = 1414
    _globals["_STREAMPUTBLOCKRESPONSEHEADBODY"]._serialized_start = 1417
    _globals["_STREAMPUTBLOCKRESPONSEHEADBODY"]._serialized_end = 1548
    _globals["_STREAMPUTBLOCKRESPONSETAIL"]._serialized_start = 1551
    _globals["_STREAMPUTBLOCKRESPONSETAIL"]._serialized_end = 1693
    _globals["_STREAMPUTBLOCKRESPONSETAILBODY"]._serialized_start = 1695
    _globals["_STREAMPUTBLOCKRESPONSETAILBODY"]._serialized_end = 1778
    _globals["_PUTBLOCKREQUEST"]._serialized_start = 1781
    _globals["_PUTBLOCKREQUEST"]._serialized_end = 1915
    _globals["_PUTBLOCKREQUESTBODY"]._serialized_start = 1917
    _globals["_PUTBLOCKREQUESTBODY"]._serialized_end = 1986
    _globals["_PUTBLOCKRESPONSE"]._serialized_start = 1988
    _globals["_PUTBLOCKRESPONSE"]._serialized_end = 2110
    _globals["_PUTBLOCKRESPONSEBODY"]._serialized_start = 2112
    _globals["_PUTBLOCKRESPONSEBODY"]._serialized_end = 2233
    _globals["_GETBLOCKREQUEST"]._serialized_start = 2235
    _globals["_GETBLOCKREQUEST"]._serialized_end = 2355
    _globals["_GETBLOCKREQUESTBODY"]._serialized_start = 2357
    _globals["_GETBLOCKREQUESTBODY"]._serialized_end = 2413
    _globals["_STREAMGETBLOCKREQUEST"]._serialized_start = 2416
    _globals["_STREAMGETBLOCKREQUEST"]._serialized_end = 2569
    _globals["_STREAMGETBLOCKREQUESTHEAD"]._serialized_start = 2572
    _globals["_STREAMGETBLOCKREQUESTHEAD"]._serialized_end = 2712
    _globals["_STREAMGETBLOCKREQUESTHEADBODY"]._serialized_start = 2714
    _globals["_STREAMGETBLOCKREQUESTHEADBODY"]._serialized_end = 2780
    _globals["_STREAMGETBLOCKREQUESTBODY"]._serialized_start = 2782
    _globals["_STREAMGETBLOCKREQUESTBODY"]._serialized_end = 2859
    _globals["_STREAMGETBLOCKRESPONSE"]._serialized_start = 2862
    _globals["_STREAMGETBLOCKRESPONSE"]._serialized_end = 3080
    _globals["_STREAMGETBLOCKRESPONSEHEAD"]._serialized_start = 3083
    _globals["_STREAMGETBLOCKRESPONSEHEAD"]._serialized_end = 3225
    _globals["_STREAMGETBLOCKRESPONSEHEADBODY"]._serialized_start = 3228
    _globals["_STREAMGETBLOCKRESPONSEHEADBODY"]._serialized_end = 3359
    _globals["_STREAMGETBLOCKRESPONSEBODY"]._serialized_start = 3361
    _globals["_STREAMGETBLOCKRESPONSEBODY"]._serialized_end = 3403
    _globals["_STREAMGETBLOCKRESPONSETAIL"]._serialized_start = 3406
    _globals["_STREAMGETBLOCKRESPONSETAIL"]._serialized_end = 3548
    _globals["_STREAMGETBLOCKRESPONSETAILBODY"]._serialized_start = 3550
    _globals["_STREAMGETBLOCKRESPONSETAILBODY"]._serialized_end = 3633
    _globals["_GETBLOCKRESPONSEBODY"]._serialized_start = 3635
    _globals["_GETBLOCKRESPONSEBODY"]._serialized_end = 3756
    _globals["_GETBLOCKRESPONSE"]._serialized_start = 3759
    _globals["_GETBLOCKRESPONSE"]._serialized_end = 3895
    _globals["_BLOCKMETADATA"]._serialized_start = 3898
    _globals["_BLOCKMETADATA"]._serialized_end = 4033
    _globals["_BLOCK"]._serialized_start = 4036
    _globals["_BLOCK"]._serialized_end = 4499
# @@protoc_insertion_point(module_scope)
