from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class MakeFriendsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MakeFriendsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetFriendsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetFriendResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
