# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.rag import memory_pb2 as yeying_dot_api_dot_rag_dot_memory__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yeying/api/rag/memory_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MemoryStub(object):
    """*
    记忆管理模块
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yeying.api.rag.Memory/Create',
                request_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryResponse.FromString,
                _registered_method=True)
        self.Add = channel.unary_unary(
                '/yeying.api.rag.Memory/Add',
                request_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yeying.api.rag.Memory/Delete',
                request_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryRequest.SerializeToString,
                response_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryResponse.FromString,
                _registered_method=True)


class MemoryServicer(object):
    """*
    记忆管理模块
    """

    def Create(self, request, context):
        """创建记忆体
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Add(self, request, context):
        """添加内容到记忆体
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """删除记忆体中的内容
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MemoryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryResponse.SerializeToString,
            ),
            'Add': grpc.unary_unary_rpc_method_handler(
                    servicer.Add,
                    request_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryRequest.FromString,
                    response_serializer=yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yeying.api.rag.Memory', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yeying.api.rag.Memory', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Memory(object):
    """*
    记忆管理模块
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.Memory/Create',
            yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_memory__pb2.CreateMemoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.Memory/Add',
            yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_memory__pb2.AddMemoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yeying.api.rag.Memory/Delete',
            yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryRequest.SerializeToString,
            yeying_dot_api_dot_rag_dot_memory__pb2.DeleteMemoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
