# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/knowledge/knowledge.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/knowledge/knowledge.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$yeying/api/knowledge/knowledge.proto\x12\x12yeying.api.content\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"O\n\rSearchRequest\x12>\n\x0f\x61rticleMetadata\x18\x01 \x03(\x0b\x32%.yeying.api.content.KnowledgeMetadata"C\n\x0eSearchResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\xbf\x01\n\x11KnowledgeMetadata\x12\x34\n\x06\x66ormat\x18\x01 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x13\n\x0bpublishTime\x18\x05 \x01(\t\x12\x0f\n\x07keyword\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t"C\n\x0e\x41ppendMetadata\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\nsubscriber\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t"K\n\rAppendRequest\x12:\n\x0e\x61ppendMetadata\x18\x01 \x03(\x0b\x32".yeying.api.content.AppendMetadata"C\n\x0e\x41ppendResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*\x1a\n\x0b\x43ontentType\x12\x0b\n\x07\x41RTICLE\x10\x00\x32\xb1\x01\n\tKnowledge\x12Q\n\x06Search\x12!.yeying.api.content.SearchRequest\x1a".yeying.api.content.SearchResponse"\x00\x12Q\n\x06\x41ppend\x12!.yeying.api.content.AppendRequest\x1a".yeying.api.content.AppendResponse"\x00\x42\x14Z\x12yeying/api/contentb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.knowledge.knowledge_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/content"
    _globals["_CONTENTTYPE"]._serialized_start = 682
    _globals["_CONTENTTYPE"]._serialized_end = 708
    _globals["_SEARCHREQUEST"]._serialized_start = 123
    _globals["_SEARCHREQUEST"]._serialized_end = 202
    _globals["_SEARCHRESPONSE"]._serialized_start = 204
    _globals["_SEARCHRESPONSE"]._serialized_end = 271
    _globals["_KNOWLEDGEMETADATA"]._serialized_start = 274
    _globals["_KNOWLEDGEMETADATA"]._serialized_end = 465
    _globals["_APPENDMETADATA"]._serialized_start = 467
    _globals["_APPENDMETADATA"]._serialized_end = 534
    _globals["_APPENDREQUEST"]._serialized_start = 536
    _globals["_APPENDREQUEST"]._serialized_end = 611
    _globals["_APPENDRESPONSE"]._serialized_start = 613
    _globals["_APPENDRESPONSE"]._serialized_end = 680
    _globals["_KNOWLEDGE"]._serialized_start = 711
    _globals["_KNOWLEDGE"]._serialized_end = 888
# @@protoc_insertion_point(module_scope)
