# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/imagecontent.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/imagecontent.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n-yeying/api/apps/zuoyepigai/imagecontent.proto\x12\x1ayeying.api.apps.zuoyepigai*8\n\x14ImageContentTypeEnum\x12\x0c\n\x08QUESTION\x10\x00\x12\n\n\x06\x41NSWER\x10\x01\x12\x06\n\x02QA\x10\x02*\x80\x01\n\x0eTaskStatusEnum\x12\x0b\n\x07\x43REATED\x10\x00\x12\x10\n\x0cWAIT_MARKING\x10\x01\x12\x0b\n\x07MARKING\x10\x02\x12\x12\n\x0e\x46INISH_MARKING\x10\x03\x12\x0f\n\x0bWAIT_REVISE\x10\x04\x12\n\n\x06REVISE\x10\x05\x12\x11\n\rFINISH_REVISE\x10\x06\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.imagecontent_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_IMAGECONTENTTYPEENUM"]._serialized_start = 77
    _globals["_IMAGECONTENTTYPEENUM"]._serialized_end = 133
    _globals["_TASKSTATUSENUM"]._serialized_start = 136
    _globals["_TASKSTATUSENUM"]._serialized_end = 264
# @@protoc_insertion_point(module_scope)
