# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/spider/topic.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/spider/topic.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dyeying/api/spider/topic.proto\x12\x10yeying.api.topic\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"\x1e\n\rSearchRequest\x12\r\n\x05owner\x18\x01 \x01(\t"{\n\x0eSearchResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\rtopicMetadata\x18\x02 \x03(\x0b\x32\x1f.yeying.api.topic.TopicMetadata"1\n\x12UnsubscribeRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x03(\t"H\n\x13UnsubscribeResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x9e\x01\n\rTopicMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x06\x66ormat\x18\x02 \x03(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x12\n\nexpression\x18\x03 \x01(\t\x12\x35\n\x06status\x18\x04 \x01(\x0e\x32%.yeying.api.common.ContractStatusEnum"Y\n\x10SubscribeRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x36\n\rtopicMetadata\x18\x02 \x03(\x0b\x32\x1f.yeying.api.topic.TopicMetadata"F\n\x11SubscribeResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\x8c\x02\n\x05Topic\x12M\n\x06Search\x12\x1f.yeying.api.topic.SearchRequest\x1a .yeying.api.topic.SearchResponse"\x00\x12V\n\tSubscribe\x12".yeying.api.topic.SubscribeRequest\x1a#.yeying.api.topic.SubscribeResponse"\x00\x12\\\n\x0bUnsubscribe\x12$.yeying.api.topic.UnsubscribeRequest\x1a%.yeying.api.topic.UnsubscribeResponse"\x00\x42\x12Z\x10yeying/api/topicb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.spider.topic_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/topic"
    _globals["_SEARCHREQUEST"]._serialized_start = 114
    _globals["_SEARCHREQUEST"]._serialized_end = 144
    _globals["_SEARCHRESPONSE"]._serialized_start = 146
    _globals["_SEARCHRESPONSE"]._serialized_end = 269
    _globals["_UNSUBSCRIBEREQUEST"]._serialized_start = 271
    _globals["_UNSUBSCRIBEREQUEST"]._serialized_end = 320
    _globals["_UNSUBSCRIBERESPONSE"]._serialized_start = 322
    _globals["_UNSUBSCRIBERESPONSE"]._serialized_end = 394
    _globals["_TOPICMETADATA"]._serialized_start = 397
    _globals["_TOPICMETADATA"]._serialized_end = 555
    _globals["_SUBSCRIBEREQUEST"]._serialized_start = 557
    _globals["_SUBSCRIBEREQUEST"]._serialized_end = 646
    _globals["_SUBSCRIBERESPONSE"]._serialized_start = 648
    _globals["_SUBSCRIBERESPONSE"]._serialized_end = 718
    _globals["_TOPIC"]._serialized_start = 721
    _globals["_TOPIC"]._serialized_end = 989
# @@protoc_insertion_point(module_scope)
