# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/identity/identity.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/identity/identity.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"yeying/api/identity/identity.proto\x12\x13yeying.api.identity\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"y\n\x0e\x44\x65positRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.identity.DepositRequestBody"6\n\x12\x44\x65positRequestBody\x12\x0e\n\x06\x63ipher\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t"{\n\x0f\x44\x65positResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.identity.DepositResponseBody"H\n\x13\x44\x65positResponseBody\x12\x31\n\x06status\x18\x02 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"C\n\x0fRetrieveRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"D\n\x10RetrieveResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"@\n\x0cShareRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"A\n\rShareResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"u\n\x0cQueryRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.identity.QueryRequestBody"K\n\x10QueryRequestBody\x12\x37\n\x0bserviceCode\x18\x01 \x01(\x0e\x32".yeying.api.common.ServiceCodeEnum"w\n\rQueryResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.identity.QueryResponseBody"h\n\x11QueryResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x0e\n\x06\x63ipher\x18\x02 \x01(\t\x12\x10\n\x08protocol\x18\x03 \x01(\t"w\n\rCancelRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.identity.CancelRequestBody" \n\x11\x43\x61ncelRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"y\n\x0e\x43\x61ncelResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.identity.CancelResponseBody"G\n\x12\x43\x61ncelResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xb6\x03\n\x08Identity\x12V\n\x07\x44\x65posit\x12#.yeying.api.identity.DepositRequest\x1a$.yeying.api.identity.DepositResponse"\x00\x12Y\n\x08Retrieve\x12$.yeying.api.identity.RetrieveRequest\x1a%.yeying.api.identity.RetrieveResponse"\x00\x12P\n\x05Query\x12!.yeying.api.identity.QueryRequest\x1a".yeying.api.identity.QueryResponse"\x00\x12P\n\x05Share\x12!.yeying.api.identity.ShareRequest\x1a".yeying.api.identity.ShareResponse"\x00\x12S\n\x06\x43\x61ncel\x12".yeying.api.identity.CancelRequest\x1a#.yeying.api.identity.CancelResponse"\x00\x42\x15Z\x13yeying/api/identityb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.identity.identity_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\023yeying/api/identity"
    _globals["_DEPOSITREQUEST"]._serialized_start = 122
    _globals["_DEPOSITREQUEST"]._serialized_end = 243
    _globals["_DEPOSITREQUESTBODY"]._serialized_start = 245
    _globals["_DEPOSITREQUESTBODY"]._serialized_end = 299
    _globals["_DEPOSITRESPONSE"]._serialized_start = 301
    _globals["_DEPOSITRESPONSE"]._serialized_end = 424
    _globals["_DEPOSITRESPONSEBODY"]._serialized_start = 426
    _globals["_DEPOSITRESPONSEBODY"]._serialized_end = 498
    _globals["_RETRIEVEREQUEST"]._serialized_start = 500
    _globals["_RETRIEVEREQUEST"]._serialized_end = 567
    _globals["_RETRIEVERESPONSE"]._serialized_start = 569
    _globals["_RETRIEVERESPONSE"]._serialized_end = 637
    _globals["_SHAREREQUEST"]._serialized_start = 639
    _globals["_SHAREREQUEST"]._serialized_end = 703
    _globals["_SHARERESPONSE"]._serialized_start = 705
    _globals["_SHARERESPONSE"]._serialized_end = 770
    _globals["_QUERYREQUEST"]._serialized_start = 772
    _globals["_QUERYREQUEST"]._serialized_end = 889
    _globals["_QUERYREQUESTBODY"]._serialized_start = 891
    _globals["_QUERYREQUESTBODY"]._serialized_end = 966
    _globals["_QUERYRESPONSE"]._serialized_start = 968
    _globals["_QUERYRESPONSE"]._serialized_end = 1087
    _globals["_QUERYRESPONSEBODY"]._serialized_start = 1089
    _globals["_QUERYRESPONSEBODY"]._serialized_end = 1193
    _globals["_CANCELREQUEST"]._serialized_start = 1195
    _globals["_CANCELREQUEST"]._serialized_end = 1314
    _globals["_CANCELREQUESTBODY"]._serialized_start = 1316
    _globals["_CANCELREQUESTBODY"]._serialized_end = 1348
    _globals["_CANCELRESPONSE"]._serialized_start = 1350
    _globals["_CANCELRESPONSE"]._serialized_end = 1471
    _globals["_CANCELRESPONSEBODY"]._serialized_start = 1473
    _globals["_CANCELRESPONSEBODY"]._serialized_end = 1544
    _globals["_IDENTITY"]._serialized_start = 1547
    _globals["_IDENTITY"]._serialized_end = 1985
# @@protoc_insertion_point(module_scope)
