# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/audit/audit.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/audit/audit.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/audit/audit.proto\x12\x10yeying.api.audit\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto\x1a\x1dyeying/api/common/model.proto"\xe5\x01\n\x0b\x41uditStatus\x12\x32\n\x07pending\x18\x01 \x01(\x0b\x32\x1f.yeying.api.audit.PendingStatusH\x00\x12\x34\n\x08\x63\x61nceled\x18\x02 \x01(\x0b\x32 .yeying.api.audit.CanceledStatusH\x00\x12\x30\n\x06passed\x18\x03 \x01(\x0b\x32\x1e.yeying.api.audit.PassedStatusH\x00\x12\x30\n\x06reject\x18\x04 \x01(\x0b\x32\x1e.yeying.api.audit.RejectStatusH\x00\x42\x08\n\x06status"\x1d\n\rPendingStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"\x1e\n\x0e\x43\x61nceledStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"\x1c\n\x0cPassedStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"\x1c\n\x0cRejectStatus\x12\x0c\n\x04text\x18\x02 \x01(\t"t\n\rCreateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.CreateRequestBody"B\n\x11\x43reateRequestBody\x12-\n\x04meta\x18\x01 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"v\n\x0e\x43reateResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.CreateResponseBody"v\n\x12\x43reateResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"t\n\rDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.DetailRequestBody" \n\x11\x44\x65tailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"v\n\x0e\x44\x65tailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.DetailResponseBody"v\n\x12\x44\x65tailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"t\n\rCancelRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.CancelRequestBody" \n\x11\x43\x61ncelRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"v\n\x0e\x43\x61ncelResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.CancelResponseBody"v\n\x12\x43\x61ncelResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"t\n\rUnbindRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.UnbindRequestBody" \n\x11UnbindRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"v\n\x0eUnbindResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.audit.UnbindResponseBody"G\n\x12UnbindResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"r\n\x0c\x41uditRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x30\n\x04\x62ody\x18\x02 \x01(\x0b\x32".yeying.api.audit.AuditRequestBody"N\n\x10\x41uditRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12-\n\x06status\x18\x02 \x01(\x0b\x32\x1d.yeying.api.audit.AuditStatus"t\n\rAuditResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.audit.AuditResponseBody"u\n\x11\x41uditResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12-\n\x04meta\x18\x02 \x01(\x0b\x32\x1f.yeying.api.audit.AuditMetadata"\x86\x01\n\x16\x43reateAuditListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.audit.CreateAuditListRequestBody"\x85\x01\n\x1a\x43reateAuditListRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.audit.AuditSearchCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x88\x01\n\x17\x43reateAuditListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.audit.CreateAuditListResponseBody"\xb0\x01\n\x1b\x43reateAuditListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12/\n\x06\x61udits\x18\x02 \x03(\x0b\x32\x1f.yeying.api.audit.AuditMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"z\n\x10\x41uditListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.audit.AuditListRequestBody"\x7f\n\x14\x41uditListRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.audit.AuditSearchCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"|\n\x11\x41uditListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.audit.AuditListResponseBody"\xaa\x01\n\x15\x41uditListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12/\n\x06\x61udits\x18\x02 \x03(\x0b\x32\x1f.yeying.api.audit.AuditMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x9e\x01\n\x14\x41uditSearchCondition\x12\x11\n\tsourceDid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tstartTime\x18\x03 \x01(\t\x12\x0f\n\x07\x65ndTime\x18\x04 \x01(\t\x12.\n\x04type\x18\x05 \x01(\x0e\x32 .yeying.api.common.AuditTypeEnum\x12\x11\n\ttargetDid\x18\x06 \x01(\t"\x90\x02\n\rAuditMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0f\n\x07\x61ppName\x18\x02 \x01(\t\x12\x11\n\tsourceDid\x18\x03 \x01(\t\x12\x12\n\nsourceName\x18\x04 \x01(\t\x12\x11\n\ttargetDid\x18\x05 \x01(\t\x12\x12\n\ntargetName\x18\x06 \x01(\t\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12-\n\x06status\x18\x08 \x01(\x0b\x32\x1d.yeying.api.audit.AuditStatus\x12\x11\n\tcreatedAt\x18\t \x01(\t\x12\x11\n\tupdatedAt\x18\n \x01(\t\x12.\n\x04type\x18\x0b \x01(\x0e\x32 .yeying.api.common.AuditTypeEnum2\xcc\x04\n\x05\x41udit\x12M\n\x06\x43reate\x12\x1f.yeying.api.audit.CreateRequest\x1a .yeying.api.audit.CreateResponse"\x00\x12M\n\x06\x44\x65tail\x12\x1f.yeying.api.audit.DetailRequest\x1a .yeying.api.audit.DetailResponse"\x00\x12M\n\x06\x43\x61ncel\x12\x1f.yeying.api.audit.CancelRequest\x1a .yeying.api.audit.CancelResponse"\x00\x12M\n\x06Unbind\x12\x1f.yeying.api.audit.UnbindRequest\x1a .yeying.api.audit.UnbindResponse"\x00\x12J\n\x05\x41udit\x12\x1e.yeying.api.audit.AuditRequest\x1a\x1f.yeying.api.audit.AuditResponse"\x00\x12\x63\n\nCreateList\x12(.yeying.api.audit.CreateAuditListRequest\x1a).yeying.api.audit.CreateAuditListResponse"\x00\x12V\n\tAuditList\x12".yeying.api.audit.AuditListRequest\x1a#.yeying.api.audit.AuditListResponse"\x00\x42\x12Z\x10yeying/api/auditb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.audit.audit_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/audit"
    _globals["_AUDITSTATUS"]._serialized_start = 145
    _globals["_AUDITSTATUS"]._serialized_end = 374
    _globals["_PENDINGSTATUS"]._serialized_start = 376
    _globals["_PENDINGSTATUS"]._serialized_end = 405
    _globals["_CANCELEDSTATUS"]._serialized_start = 407
    _globals["_CANCELEDSTATUS"]._serialized_end = 437
    _globals["_PASSEDSTATUS"]._serialized_start = 439
    _globals["_PASSEDSTATUS"]._serialized_end = 467
    _globals["_REJECTSTATUS"]._serialized_start = 469
    _globals["_REJECTSTATUS"]._serialized_end = 497
    _globals["_CREATEREQUEST"]._serialized_start = 499
    _globals["_CREATEREQUEST"]._serialized_end = 615
    _globals["_CREATEREQUESTBODY"]._serialized_start = 617
    _globals["_CREATEREQUESTBODY"]._serialized_end = 683
    _globals["_CREATERESPONSE"]._serialized_start = 685
    _globals["_CREATERESPONSE"]._serialized_end = 803
    _globals["_CREATERESPONSEBODY"]._serialized_start = 805
    _globals["_CREATERESPONSEBODY"]._serialized_end = 923
    _globals["_DETAILREQUEST"]._serialized_start = 925
    _globals["_DETAILREQUEST"]._serialized_end = 1041
    _globals["_DETAILREQUESTBODY"]._serialized_start = 1043
    _globals["_DETAILREQUESTBODY"]._serialized_end = 1075
    _globals["_DETAILRESPONSE"]._serialized_start = 1077
    _globals["_DETAILRESPONSE"]._serialized_end = 1195
    _globals["_DETAILRESPONSEBODY"]._serialized_start = 1197
    _globals["_DETAILRESPONSEBODY"]._serialized_end = 1315
    _globals["_CANCELREQUEST"]._serialized_start = 1317
    _globals["_CANCELREQUEST"]._serialized_end = 1433
    _globals["_CANCELREQUESTBODY"]._serialized_start = 1435
    _globals["_CANCELREQUESTBODY"]._serialized_end = 1467
    _globals["_CANCELRESPONSE"]._serialized_start = 1469
    _globals["_CANCELRESPONSE"]._serialized_end = 1587
    _globals["_CANCELRESPONSEBODY"]._serialized_start = 1589
    _globals["_CANCELRESPONSEBODY"]._serialized_end = 1707
    _globals["_UNBINDREQUEST"]._serialized_start = 1709
    _globals["_UNBINDREQUEST"]._serialized_end = 1825
    _globals["_UNBINDREQUESTBODY"]._serialized_start = 1827
    _globals["_UNBINDREQUESTBODY"]._serialized_end = 1859
    _globals["_UNBINDRESPONSE"]._serialized_start = 1861
    _globals["_UNBINDRESPONSE"]._serialized_end = 1979
    _globals["_UNBINDRESPONSEBODY"]._serialized_start = 1981
    _globals["_UNBINDRESPONSEBODY"]._serialized_end = 2052
    _globals["_AUDITREQUEST"]._serialized_start = 2054
    _globals["_AUDITREQUEST"]._serialized_end = 2168
    _globals["_AUDITREQUESTBODY"]._serialized_start = 2170
    _globals["_AUDITREQUESTBODY"]._serialized_end = 2248
    _globals["_AUDITRESPONSE"]._serialized_start = 2250
    _globals["_AUDITRESPONSE"]._serialized_end = 2366
    _globals["_AUDITRESPONSEBODY"]._serialized_start = 2368
    _globals["_AUDITRESPONSEBODY"]._serialized_end = 2485
    _globals["_CREATEAUDITLISTREQUEST"]._serialized_start = 2488
    _globals["_CREATEAUDITLISTREQUEST"]._serialized_end = 2622
    _globals["_CREATEAUDITLISTREQUESTBODY"]._serialized_start = 2625
    _globals["_CREATEAUDITLISTREQUESTBODY"]._serialized_end = 2758
    _globals["_CREATEAUDITLISTRESPONSE"]._serialized_start = 2761
    _globals["_CREATEAUDITLISTRESPONSE"]._serialized_end = 2897
    _globals["_CREATEAUDITLISTRESPONSEBODY"]._serialized_start = 2900
    _globals["_CREATEAUDITLISTRESPONSEBODY"]._serialized_end = 3076
    _globals["_AUDITLISTREQUEST"]._serialized_start = 3078
    _globals["_AUDITLISTREQUEST"]._serialized_end = 3200
    _globals["_AUDITLISTREQUESTBODY"]._serialized_start = 3202
    _globals["_AUDITLISTREQUESTBODY"]._serialized_end = 3329
    _globals["_AUDITLISTRESPONSE"]._serialized_start = 3331
    _globals["_AUDITLISTRESPONSE"]._serialized_end = 3455
    _globals["_AUDITLISTRESPONSEBODY"]._serialized_start = 3458
    _globals["_AUDITLISTRESPONSEBODY"]._serialized_end = 3628
    _globals["_AUDITSEARCHCONDITION"]._serialized_start = 3631
    _globals["_AUDITSEARCHCONDITION"]._serialized_end = 3789
    _globals["_AUDITMETADATA"]._serialized_start = 3792
    _globals["_AUDITMETADATA"]._serialized_end = 4064
    _globals["_AUDIT"]._serialized_start = 4067
    _globals["_AUDIT"]._serialized_end = 4655
# @@protoc_insertion_point(module_scope)
