# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/warehouse.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/warehouse.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*yeying/api/apps/zuoyepigai/warehouse.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x90\x01\n\x16\x44\x65tailWarehouseRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.DetailWarehouseRequestBody")\n\x1a\x44\x65tailWarehouseRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x92\x01\n\x17\x44\x65tailWarehouseResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x45\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x37.yeying.api.apps.zuoyepigai.DetailWarehouseResponseBody"\x8d\x01\n\x1b\x44\x65tailWarehouseResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x04meta\x18\x02 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata"\x8a\x01\n\x13\x41\x64\x64WarehouseRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.AddWarehouseRequestBody"V\n\x17\x41\x64\x64WarehouseRequestBody\x12;\n\x04meta\x18\x01 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata"\x8c\x01\n\x14\x41\x64\x64WarehouseResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.AddWarehouseResponseBody"\x8a\x01\n\x18\x41\x64\x64WarehouseResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x04meta\x18\x02 \x01(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata"\x8c\x01\n\x14ListWarehouseRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ListWarehouseRequestBody"\x97\x01\n\x18ListWarehouseRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07taskUid\x18\x02 \x01(\t\x12.\n\tpageIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x8e\x01\n\x15ListWarehouseResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ListWarehouseResponseBody"\x9a\x01\n\x19ListWarehouseResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x04list\x18\x02 \x03(\x0b\x32-.yeying.api.apps.zuoyepigai.WarehouseMetadata\x12\r\n\x05total\x18\x03 \x01(\x04\x32\xdb\x02\n\tWarehouse\x12j\n\x03\x41\x64\x64\x12/.yeying.api.apps.zuoyepigai.AddWarehouseRequest\x1a\x30.yeying.api.apps.zuoyepigai.AddWarehouseResponse"\x00\x12m\n\x04List\x12\x30.yeying.api.apps.zuoyepigai.ListWarehouseRequest\x1a\x31.yeying.api.apps.zuoyepigai.ListWarehouseResponse"\x00\x12s\n\x06\x44\x65tail\x12\x32.yeying.api.apps.zuoyepigai.DetailWarehouseRequest\x1a\x33.yeying.api.apps.zuoyepigai.DetailWarehouseResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.warehouse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_DETAILWAREHOUSEREQUEST"]._serialized_start = 179
    _globals["_DETAILWAREHOUSEREQUEST"]._serialized_end = 323
    _globals["_DETAILWAREHOUSEREQUESTBODY"]._serialized_start = 325
    _globals["_DETAILWAREHOUSEREQUESTBODY"]._serialized_end = 366
    _globals["_DETAILWAREHOUSERESPONSE"]._serialized_start = 369
    _globals["_DETAILWAREHOUSERESPONSE"]._serialized_end = 515
    _globals["_DETAILWAREHOUSERESPONSEBODY"]._serialized_start = 518
    _globals["_DETAILWAREHOUSERESPONSEBODY"]._serialized_end = 659
    _globals["_ADDWAREHOUSEREQUEST"]._serialized_start = 662
    _globals["_ADDWAREHOUSEREQUEST"]._serialized_end = 800
    _globals["_ADDWAREHOUSEREQUESTBODY"]._serialized_start = 802
    _globals["_ADDWAREHOUSEREQUESTBODY"]._serialized_end = 888
    _globals["_ADDWAREHOUSERESPONSE"]._serialized_start = 891
    _globals["_ADDWAREHOUSERESPONSE"]._serialized_end = 1031
    _globals["_ADDWAREHOUSERESPONSEBODY"]._serialized_start = 1034
    _globals["_ADDWAREHOUSERESPONSEBODY"]._serialized_end = 1172
    _globals["_LISTWAREHOUSEREQUEST"]._serialized_start = 1175
    _globals["_LISTWAREHOUSEREQUEST"]._serialized_end = 1315
    _globals["_LISTWAREHOUSEREQUESTBODY"]._serialized_start = 1318
    _globals["_LISTWAREHOUSEREQUESTBODY"]._serialized_end = 1469
    _globals["_LISTWAREHOUSERESPONSE"]._serialized_start = 1472
    _globals["_LISTWAREHOUSERESPONSE"]._serialized_end = 1614
    _globals["_LISTWAREHOUSERESPONSEBODY"]._serialized_start = 1617
    _globals["_LISTWAREHOUSERESPONSEBODY"]._serialized_end = 1771
    _globals["_WAREHOUSE"]._serialized_start = 1774
    _globals["_WAREHOUSE"]._serialized_end = 2121
# @@protoc_insertion_point(module_scope)
