# Generated by protobuf_init. Do not edit manually.
from .social_pb2 import MakeFriendsRequest
from .social_pb2 import MakeFriendsResponse
from .social_pb2 import GetFriendsRequest
from .social_pb2 import GetFriendResponse
from .social_pb2_grpc import SocialServicer
from .social_pb2_grpc import SocialStub
from .social_pb2_grpc import add_SocialServicer_to_server
from .social_pb2_grpc import Social
