# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/meta.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/meta.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.apps.zuoyepigai import imagecontent_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_imagecontent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%yeying/api/apps/zuoyepigai/meta.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a-yeying/api/apps/zuoyepigai/imagecontent.proto"\x9e\x01\n\rGroupMetaData\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x11\n\tgroupName\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08\x12\x12\n\nteacherDid\x18\x07 \x01(\t\x12\x13\n\x0bstudentName\x18\x08 \x01(\t"\xd0\x01\n\x0f\x41rchiveMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nstudentDid\x18\x03 \x01(\t\x12\x12\n\nteacherDid\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\x03\x12\x11\n\tupdatedAt\x18\x07 \x01(\x03\x12\x11\n\tisDeleted\x18\x08 \x01(\x08\x12\x11\n\ttelephone\x18\t \x01(\t\x12\r\n\x05\x65mail\x18\n \x01(\t\x12\x0e\n\x06status\x18\x0b \x01(\t"\x8c\x01\n\x10HomeworkMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x14\n\x0ctestPaperUid\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\x03\x12\x11\n\tupdatedAt\x18\x06 \x01(\x03\x12\x11\n\tisDeleted\x18\x07 \x01(\x08"z\n\x10MistakesMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x10\n\x08question\x18\x02 \x01(\t\x12\x0e\n\x06\x61nswer\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08"\x85\x01\n\x0fMessageMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\x03\x12\x11\n\tupdatedAt\x18\x06 \x01(\x03\x12\x11\n\tisDeleted\x18\x07 \x01(\x08"\x8c\x02\n\x0cTaskMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06tagUid\x18\x04 \x01(\t\x12\x0b\n\x03\x64id\x18\x05 \x01(\t\x12\x16\n\x0estudentDidList\x18\x06 \x01(\t\x12\x11\n\tcreatedAt\x18\x07 \x01(\x03\x12\x11\n\tupdatedAt\x18\x08 \x01(\x03\x12\x11\n\tstartTime\x18\t \x01(\x03\x12\x0f\n\x07\x65ndTime\x18\n \x01(\x03\x12\x11\n\tisDeleted\x18\x0b \x01(\x08\x12:\n\x06status\x18\x0c \x01(\x0e\x32*.yeying.api.apps.zuoyepigai.TaskStatusEnum">\n\x0cTagCountMeta\x12\x0e\n\x06tagUid\x18\x01 \x01(\t\x12\x0f\n\x07tagName\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04"r\n\x0fTaskTagMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64id\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03\x12\x11\n\tisDeleted\x18\x06 \x01(\x08"\x94\x02\n\x11WarehouseMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12<\n\x0burlMetaData\x18\x04 \x03(\x0b\x32\'.yeying.api.apps.zuoyepigai.UrlMetaData\x12\x0f\n\x07taskUid\x18\x05 \x01(\t\x12>\n\x04type\x18\x06 \x01(\x0e\x32\x30.yeying.api.apps.zuoyepigai.ImageContentTypeEnum\x12\x11\n\tcreatedAt\x18\x07 \x01(\x03\x12\x11\n\tupdatedAt\x18\x08 \x01(\x03\x12\x11\n\tisDeleted\x18\t \x01(\x08\x12\x10\n\x08urlIndex\x18\n \x01(\r")\n\x0bUrlMetaData\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0b\n\x03url\x18\x02 \x01(\tB\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.meta_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_GROUPMETADATA"]._serialized_start = 117
    _globals["_GROUPMETADATA"]._serialized_end = 275
    _globals["_ARCHIVEMETADATA"]._serialized_start = 278
    _globals["_ARCHIVEMETADATA"]._serialized_end = 486
    _globals["_HOMEWORKMETADATA"]._serialized_start = 489
    _globals["_HOMEWORKMETADATA"]._serialized_end = 629
    _globals["_MISTAKESMETADATA"]._serialized_start = 631
    _globals["_MISTAKESMETADATA"]._serialized_end = 753
    _globals["_MESSAGEMETADATA"]._serialized_start = 756
    _globals["_MESSAGEMETADATA"]._serialized_end = 889
    _globals["_TASKMETADATA"]._serialized_start = 892
    _globals["_TASKMETADATA"]._serialized_end = 1160
    _globals["_TAGCOUNTMETA"]._serialized_start = 1162
    _globals["_TAGCOUNTMETA"]._serialized_end = 1224
    _globals["_TASKTAGMETADATA"]._serialized_start = 1226
    _globals["_TASKTAGMETADATA"]._serialized_end = 1340
    _globals["_WAREHOUSEMETADATA"]._serialized_start = 1343
    _globals["_WAREHOUSEMETADATA"]._serialized_end = 1619
    _globals["_URLMETADATA"]._serialized_start = 1621
    _globals["_URLMETADATA"]._serialized_end = 1662
# @@protoc_insertion_point(module_scope)
