# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/mail/mail.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/mail/mail.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/mail/mail.proto\x12\x0fyeying.api.mail\x1a\x1fyeying/api/common/message.proto"w\n\x0fSendMailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.mail.SendMailRequestBody"%\n\x13SendMailRequestBody\x12\x0e\n\x06toMail\x18\x01 \x01(\t"y\n\x10SendMailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.mail.SendMailResponseBody"I\n\x14SendMailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"{\n\x11VerifyMailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.mail.VerifyMailRequestBody"5\n\x15VerifyMailRequestBody\x12\x0e\n\x06toMail\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t"}\n\x12VerifyMailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.mail.VerifyMailResponseBody"K\n\x16VerifyMailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xaa\x01\n\x04Mail\x12M\n\x04Send\x12 .yeying.api.mail.SendMailRequest\x1a!.yeying.api.mail.SendMailResponse"\x00\x12S\n\x06Verify\x12".yeying.api.mail.VerifyMailRequest\x1a#.yeying.api.mail.VerifyMailResponse"\x00\x42\x11Z\x0fyeying/api/mailb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.mail.mail_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/mail"
    _globals["_SENDMAILREQUEST"]._serialized_start = 80
    _globals["_SENDMAILREQUEST"]._serialized_end = 199
    _globals["_SENDMAILREQUESTBODY"]._serialized_start = 201
    _globals["_SENDMAILREQUESTBODY"]._serialized_end = 238
    _globals["_SENDMAILRESPONSE"]._serialized_start = 240
    _globals["_SENDMAILRESPONSE"]._serialized_end = 361
    _globals["_SENDMAILRESPONSEBODY"]._serialized_start = 363
    _globals["_SENDMAILRESPONSEBODY"]._serialized_end = 436
    _globals["_VERIFYMAILREQUEST"]._serialized_start = 438
    _globals["_VERIFYMAILREQUEST"]._serialized_end = 561
    _globals["_VERIFYMAILREQUESTBODY"]._serialized_start = 563
    _globals["_VERIFYMAILREQUESTBODY"]._serialized_end = 616
    _globals["_VERIFYMAILRESPONSE"]._serialized_start = 618
    _globals["_VERIFYMAILRESPONSE"]._serialized_end = 743
    _globals["_VERIFYMAILRESPONSEBODY"]._serialized_start = 745
    _globals["_VERIFYMAILRESPONSEBODY"]._serialized_end = 820
    _globals["_MAIL"]._serialized_start = 823
    _globals["_MAIL"]._serialized_end = 993
# @@protoc_insertion_point(module_scope)
