# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/task/task.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/task/task.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/task/task.proto\x12\x0fyeying.api.task\x1a\x1fyeying/api/common/message.proto"\x13\n\x11\x43reateTaskRequest"\x14\n\x12\x43reateTaskResponse"\xa6\x01\n\x0cTaskMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12+\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x1d.yeying.api.task.TaskCodeEnum\x12\x0f\n\x07\x63reator\x18\x03 \x01(\t\x12\x13\n\x0bparticipant\x18\x04 \x01(\t\x12\x12\n\nterminator\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t"A\n\x11\x46\x65tchTaskResponse\x12,\n\x05tasks\x18\x01 \x03(\x0b\x32\x1d.yeying.api.task.TaskMetadata*>\n\x0cTaskCodeEnum\x12\x15\n\x11TASK_CODE_UNKNOWN\x10\x00\x12\x17\n\x13TASK_CODE_STATISTIC\x10\x01\x32[\n\x04Task\x12S\n\x06\x43reate\x12".yeying.api.task.CreateTaskRequest\x1a#.yeying.api.task.CreateTaskResponse"\x00\x42\x11Z\x0fyeying/api/taskb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.task.task_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/task"
    _globals["_TASKCODEENUM"]._serialized_start = 359
    _globals["_TASKCODEENUM"]._serialized_end = 421
    _globals["_CREATETASKREQUEST"]._serialized_start = 80
    _globals["_CREATETASKREQUEST"]._serialized_end = 99
    _globals["_CREATETASKRESPONSE"]._serialized_start = 101
    _globals["_CREATETASKRESPONSE"]._serialized_end = 121
    _globals["_TASKMETADATA"]._serialized_start = 124
    _globals["_TASKMETADATA"]._serialized_end = 290
    _globals["_FETCHTASKRESPONSE"]._serialized_start = 292
    _globals["_FETCHTASKRESPONSE"]._serialized_end = 357
    _globals["_TASK"]._serialized_start = 423
    _globals["_TASK"]._serialized_end = 514
# @@protoc_insertion_point(module_scope)
