# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/support/support.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/support/support.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/support/support.proto\x12\x12yeying.api.support\x1a\x1fyeying/api/common/message.proto"\x86\x01\n\x15\x43ollectSupportRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.support.CollectSupportRequestBody"\x86\x01\n\x19\x43ollectSupportRequestBody\x12\x31\n\x04\x63ode\x18\x01 \x01(\x0e\x32#.yeying.api.support.SupportCodeEnum\x12.\n\x03\x66\x61q\x18\x03 \x01(\x0b\x32\x1f.yeying.api.support.FaqMetadataH\x00\x42\x06\n\x04\x64\x61ta"r\n\x0b\x46\x61qMetadata\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\t"\x88\x01\n\x16\x43ollectSupportResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12<\n\x04\x62ody\x18\x02 \x01(\x0b\x32..yeying.api.support.CollectSupportResponseBody"O\n\x1a\x43ollectSupportResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*S\n\x0fSupportCodeEnum\x12\x14\n\x10SUPPORT_CODE_FAQ\x10\x00\x12\x14\n\x10SUPPORT_CODE_CSR\x10\x01\x12\x14\n\x10SUPPORT_CODE_IVR\x10\x02\x32m\n\x07Support\x12\x62\n\x07\x43ollect\x12).yeying.api.support.CollectSupportRequest\x1a*.yeying.api.support.CollectSupportResponse"\x00\x42\x14Z\x12yeying/api/supportb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.support.support_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/support"
    _globals["_SUPPORTCODEENUM"]._serialized_start = 699
    _globals["_SUPPORTCODEENUM"]._serialized_end = 782
    _globals["_COLLECTSUPPORTREQUEST"]._serialized_start = 90
    _globals["_COLLECTSUPPORTREQUEST"]._serialized_end = 224
    _globals["_COLLECTSUPPORTREQUESTBODY"]._serialized_start = 227
    _globals["_COLLECTSUPPORTREQUESTBODY"]._serialized_end = 361
    _globals["_FAQMETADATA"]._serialized_start = 363
    _globals["_FAQMETADATA"]._serialized_end = 477
    _globals["_COLLECTSUPPORTRESPONSE"]._serialized_start = 480
    _globals["_COLLECTSUPPORTRESPONSE"]._serialized_end = 616
    _globals["_COLLECTSUPPORTRESPONSEBODY"]._serialized_start = 618
    _globals["_COLLECTSUPPORTRESPONSEBODY"]._serialized_end = 697
    _globals["_SUPPORT"]._serialized_start = 784
    _globals["_SUPPORT"]._serialized_end = 893
# @@protoc_insertion_point(module_scope)
