# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/recycle.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/recycle.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.asset import asset_pb2 as yeying_dot_api_dot_asset_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/asset/recycle.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/asset/asset.proto"\x8c\x01\n\x19SearchDeletedAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.SearchDeletedAssetRequestBody"\x88\x01\n\x1dSearchDeletedAssetRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.asset.SearchAssetCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x8e\x01\n\x1aSearchDeletedAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.SearchDeletedAssetResponseBody"\x8b\x01\n\x1eSearchDeletedAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\x06\x61ssets\x18\x02 \x03(\x0b\x32&.yeying.api.asset.DeletedAssetMetadata"\x8e\x01\n\x1aRecoverDeletedAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.RecoverDeletedAssetRequestBody"C\n\x1eRecoverDeletedAssetRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x90\x01\n\x1bRecoverDeletedAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.asset.RecoverDeletedAssetResponseBody"T\n\x1fRecoverDeletedAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8c\x01\n\x19RemoveDeletedAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12=\n\x04\x62ody\x18\x02 \x01(\x0b\x32/.yeying.api.asset.RemoveDeletedAssetRequestBody"B\n\x1dRemoveDeletedAssetRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x8e\x01\n\x1aRemoveDeletedAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12>\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x30.yeying.api.asset.RemoveDeletedAssetResponseBody"S\n\x1eRemoveDeletedAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"Y\n\x14\x44\x65letedAssetMetadata\x12.\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata\x12\x11\n\tdeletedAt\x18\r \x01(\t2\xc1\x02\n\x07Recycle\x12\x65\n\x06Search\x12+.yeying.api.asset.SearchDeletedAssetRequest\x1a,.yeying.api.asset.SearchDeletedAssetResponse"\x00\x12h\n\x07Recover\x12,.yeying.api.asset.RecoverDeletedAssetRequest\x1a-.yeying.api.asset.RecoverDeletedAssetResponse"\x00\x12\x65\n\x06Remove\x12+.yeying.api.asset.RemoveDeletedAssetRequest\x1a,.yeying.api.asset.RemoveDeletedAssetResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.recycle_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_SEARCHDELETEDASSETREQUEST"]._serialized_start = 116
    _globals["_SEARCHDELETEDASSETREQUEST"]._serialized_end = 256
    _globals["_SEARCHDELETEDASSETREQUESTBODY"]._serialized_start = 259
    _globals["_SEARCHDELETEDASSETREQUESTBODY"]._serialized_end = 395
    _globals["_SEARCHDELETEDASSETRESPONSE"]._serialized_start = 398
    _globals["_SEARCHDELETEDASSETRESPONSE"]._serialized_end = 540
    _globals["_SEARCHDELETEDASSETRESPONSEBODY"]._serialized_start = 543
    _globals["_SEARCHDELETEDASSETRESPONSEBODY"]._serialized_end = 682
    _globals["_RECOVERDELETEDASSETREQUEST"]._serialized_start = 685
    _globals["_RECOVERDELETEDASSETREQUEST"]._serialized_end = 827
    _globals["_RECOVERDELETEDASSETREQUESTBODY"]._serialized_start = 829
    _globals["_RECOVERDELETEDASSETREQUESTBODY"]._serialized_end = 896
    _globals["_RECOVERDELETEDASSETRESPONSE"]._serialized_start = 899
    _globals["_RECOVERDELETEDASSETRESPONSE"]._serialized_end = 1043
    _globals["_RECOVERDELETEDASSETRESPONSEBODY"]._serialized_start = 1045
    _globals["_RECOVERDELETEDASSETRESPONSEBODY"]._serialized_end = 1129
    _globals["_REMOVEDELETEDASSETREQUEST"]._serialized_start = 1132
    _globals["_REMOVEDELETEDASSETREQUEST"]._serialized_end = 1272
    _globals["_REMOVEDELETEDASSETREQUESTBODY"]._serialized_start = 1274
    _globals["_REMOVEDELETEDASSETREQUESTBODY"]._serialized_end = 1340
    _globals["_REMOVEDELETEDASSETRESPONSE"]._serialized_start = 1343
    _globals["_REMOVEDELETEDASSETRESPONSE"]._serialized_end = 1485
    _globals["_REMOVEDELETEDASSETRESPONSEBODY"]._serialized_start = 1487
    _globals["_REMOVEDELETEDASSETRESPONSEBODY"]._serialized_end = 1570
    _globals["_DELETEDASSETMETADATA"]._serialized_start = 1572
    _globals["_DELETEDASSETMETADATA"]._serialized_end = 1661
    _globals["_RECYCLE"]._serialized_start = 1664
    _globals["_RECYCLE"]._serialized_end = 1985
# @@protoc_insertion_point(module_scope)
