# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/event/event.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/event/event.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/event/event.proto\x12\x10yeying.api.event\x1a\x1fyeying/api/common/message.proto"\xcc\x04\n\rEventMetadata\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x1f.yeying.api.event.EventTypeEnum\x12\x11\n\tproducers\x18\x03 \x03(\t\x12\x11\n\tconsumers\x18\x04 \x03(\t\x12\x33\n\tsignature\x18\x05 \x01(\x0b\x32 .yeying.api.event.EventSignature\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t\x12\x11\n\tcreatedAt\x18\x07 \x01(\t\x12\x13\n\x0bprocessedAt\x18\x08 \x01(\t\x12\x38\n\rnotifyContent\x18\t \x01(\x0b\x32\x1f.yeying.api.event.NotifyContentH\x00\x12\x36\n\x0c\x61pplyContent\x18\n \x01(\x0b\x32\x1e.yeying.api.event.ApplyContentH\x00\x12\x38\n\rcustomContent\x18\x0b \x01(\x0b\x32\x1f.yeying.api.event.CustomContentH\x00\x12\x38\n\rnotifyOpinion\x18\x0c \x01(\x0b\x32\x1f.yeying.api.event.NotifyOpinionH\x01\x12\x36\n\x0c\x61pplyOpinion\x18\r \x01(\x0b\x32\x1e.yeying.api.event.ApplyOpinionH\x01\x12\x38\n\rcustomOpinion\x18\x0e \x01(\x0b\x32\x1f.yeying.api.event.CustomOpinionH\x01\x42\t\n\x07\x63ontentB\t\n\x07opinion"\xe0\x01\n\x0fSignatureObject\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x1f.yeying.api.event.EventTypeEnum\x12\x11\n\tproducers\x18\x03 \x03(\t\x12\x11\n\tconsumers\x18\x04 \x03(\t\x12\x11\n\tsignature\x18\x05 \x01(\x0c\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t\x12\x11\n\tcreatedAt\x18\x07 \x01(\t\x12\x13\n\x0bprocessedAt\x18\x08 \x01(\t\x12\x0f\n\x07opinion\x18\t \x01(\x0c\x12\x0f\n\x07\x63ontent\x18\n \x01(\x0c"6\n\x0e\x45ventSignature\x12\x11\n\tproducers\x18\x01 \x03(\t\x12\x11\n\tconsumers\x18\x02 \x03(\t"-\n\rCustomContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06object\x18\x02 \x01(\t"\x1f\n\x0c\x41pplyContent\x12\x0f\n\x07\x61pplier\x18\x01 \x01(\t"J\n\rNotifyContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.yeying.api.event.NotifyItem"M\n\nNotifyItem\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x32\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32".yeying.api.event.NotifyActionEnum"v\n\x0eProduceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.event.ProduceRequestBody"D\n\x12ProduceRequestBody\x12.\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1f.yeying.api.event.EventMetadata"x\n\x0fProduceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.event.ProduceResponseBody"H\n\x13ProduceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"v\n\x0e\x43onsumeRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.event.ConsumeRequestBody"G\n\x12\x43onsumeRequestBody\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.yeying.api.event.EventMetadata""\n\rNotifyOpinion\x12\x11\n\tprocessed\x18\x01 \x01(\t"c\n\x0c\x41pplyOpinion\x12\x31\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32!.yeying.api.event.ApplyActionEnum\x12\r\n\x05\x63\x61use\x18\x02 \x01(\t\x12\x11\n\tprocessed\x18\x03 \x01(\t"-\n\rCustomOpinion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06object\x18\x02 \x01(\t"x\n\x0f\x43onsumeResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.event.ConsumeResponseBody"H\n\x13\x43onsumeResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*\x82\x01\n\rEventTypeEnum\x12\x16\n\x12\x45VENT_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11\x45VENT_TYPE_REMIND\x10\x01\x12\x15\n\x11\x45VENT_TYPE_NOTIFY\x10\x02\x12\x14\n\x10\x45VENT_TYPE_APPLY\x10\x03\x12\x15\n\x11\x45VENT_TYPE_CUSTOM\x10\x04*^\n\x0f\x41pplyActionEnum\x12\x18\n\x14\x41PPLY_ACTION_UNKNOWN\x10\x00\x12\x17\n\x13\x41PPLY_ACTION_PASSED\x10\x01\x12\x18\n\x14\x41PPLY_ACTION_REFUSED\x10\x02*r\n\x10NotifyActionEnum\x12\x19\n\x15NOTIFY_ACTION_UNKNOWN\x10\x00\x12\x15\n\x11NOTIFY_ACTION_ADD\x10\x01\x12\x15\n\x11NOTIFY_ACTION_DEL\x10\x02\x12\x15\n\x11NOTIFY_ACTION_MOD\x10\x03\x32\xab\x01\n\x05\x45vent\x12P\n\x07Produce\x12 .yeying.api.event.ProduceRequest\x1a!.yeying.api.event.ProduceResponse"\x00\x12P\n\x07\x43onsume\x12 .yeying.api.event.ConsumeRequest\x1a!.yeying.api.event.ConsumeResponse"\x00\x42\x12Z\x10yeying/api/eventb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.event.event_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/event"
    _globals["_EVENTTYPEENUM"]._serialized_start = 2152
    _globals["_EVENTTYPEENUM"]._serialized_end = 2282
    _globals["_APPLYACTIONENUM"]._serialized_start = 2284
    _globals["_APPLYACTIONENUM"]._serialized_end = 2378
    _globals["_NOTIFYACTIONENUM"]._serialized_start = 2380
    _globals["_NOTIFYACTIONENUM"]._serialized_end = 2494
    _globals["_EVENTMETADATA"]._serialized_start = 84
    _globals["_EVENTMETADATA"]._serialized_end = 672
    _globals["_SIGNATUREOBJECT"]._serialized_start = 675
    _globals["_SIGNATUREOBJECT"]._serialized_end = 899
    _globals["_EVENTSIGNATURE"]._serialized_start = 901
    _globals["_EVENTSIGNATURE"]._serialized_end = 955
    _globals["_CUSTOMCONTENT"]._serialized_start = 957
    _globals["_CUSTOMCONTENT"]._serialized_end = 1002
    _globals["_APPLYCONTENT"]._serialized_start = 1004
    _globals["_APPLYCONTENT"]._serialized_end = 1035
    _globals["_NOTIFYCONTENT"]._serialized_start = 1037
    _globals["_NOTIFYCONTENT"]._serialized_end = 1111
    _globals["_NOTIFYITEM"]._serialized_start = 1113
    _globals["_NOTIFYITEM"]._serialized_end = 1190
    _globals["_PRODUCEREQUEST"]._serialized_start = 1192
    _globals["_PRODUCEREQUEST"]._serialized_end = 1310
    _globals["_PRODUCEREQUESTBODY"]._serialized_start = 1312
    _globals["_PRODUCEREQUESTBODY"]._serialized_end = 1380
    _globals["_PRODUCERESPONSE"]._serialized_start = 1382
    _globals["_PRODUCERESPONSE"]._serialized_end = 1502
    _globals["_PRODUCERESPONSEBODY"]._serialized_start = 1504
    _globals["_PRODUCERESPONSEBODY"]._serialized_end = 1576
    _globals["_CONSUMEREQUEST"]._serialized_start = 1578
    _globals["_CONSUMEREQUEST"]._serialized_end = 1696
    _globals["_CONSUMEREQUESTBODY"]._serialized_start = 1698
    _globals["_CONSUMEREQUESTBODY"]._serialized_end = 1769
    _globals["_NOTIFYOPINION"]._serialized_start = 1771
    _globals["_NOTIFYOPINION"]._serialized_end = 1805
    _globals["_APPLYOPINION"]._serialized_start = 1807
    _globals["_APPLYOPINION"]._serialized_end = 1906
    _globals["_CUSTOMOPINION"]._serialized_start = 1908
    _globals["_CUSTOMOPINION"]._serialized_end = 1953
    _globals["_CONSUMERESPONSE"]._serialized_start = 1955
    _globals["_CONSUMERESPONSE"]._serialized_end = 2075
    _globals["_CONSUMERESPONSEBODY"]._serialized_start = 2077
    _globals["_CONSUMERESPONSEBODY"]._serialized_end = 2149
    _globals["_EVENT"]._serialized_start = 2497
    _globals["_EVENT"]._serialized_end = 2668
# @@protoc_insertion_point(module_scope)
