# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/homework.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/homework.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)yeying/api/apps/zuoyepigai/homework.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x8a\x01\n\x13HomeworkListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.HomeworkListRequestBody"&\n\x17HomeworkListRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8c\x01\n\x14HomeworkListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.HomeworkListResponseBody"\x89\x01\n\x18HomeworkListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04list\x18\x02 \x03(\x0b\x32,.yeying.api.apps.zuoyepigai.HomeworkMetadata"\x8e\x01\n\x15HomeworkDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.HomeworkDetailRequestBody"(\n\x19HomeworkDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x90\x01\n\x16HomeworkDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.HomeworkDetailResponseBody"\x8b\x01\n\x1aHomeworkDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04meta\x18\x02 \x01(\x0b\x32,.yeying.api.apps.zuoyepigai.HomeworkMetadata2\xea\x01\n\x08Homework\x12k\n\x04List\x12/.yeying.api.apps.zuoyepigai.HomeworkListRequest\x1a\x30.yeying.api.apps.zuoyepigai.HomeworkListResponse"\x00\x12q\n\x06\x44\x65tail\x12\x31.yeying.api.apps.zuoyepigai.HomeworkDetailRequest\x1a\x32.yeying.api.apps.zuoyepigai.HomeworkDetailResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.homework_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_HOMEWORKLISTREQUEST"]._serialized_start = 146
    _globals["_HOMEWORKLISTREQUEST"]._serialized_end = 284
    _globals["_HOMEWORKLISTREQUESTBODY"]._serialized_start = 286
    _globals["_HOMEWORKLISTREQUESTBODY"]._serialized_end = 324
    _globals["_HOMEWORKLISTRESPONSE"]._serialized_start = 327
    _globals["_HOMEWORKLISTRESPONSE"]._serialized_end = 467
    _globals["_HOMEWORKLISTRESPONSEBODY"]._serialized_start = 470
    _globals["_HOMEWORKLISTRESPONSEBODY"]._serialized_end = 607
    _globals["_HOMEWORKDETAILREQUEST"]._serialized_start = 610
    _globals["_HOMEWORKDETAILREQUEST"]._serialized_end = 752
    _globals["_HOMEWORKDETAILREQUESTBODY"]._serialized_start = 754
    _globals["_HOMEWORKDETAILREQUESTBODY"]._serialized_end = 794
    _globals["_HOMEWORKDETAILRESPONSE"]._serialized_start = 797
    _globals["_HOMEWORKDETAILRESPONSE"]._serialized_end = 941
    _globals["_HOMEWORKDETAILRESPONSEBODY"]._serialized_start = 944
    _globals["_HOMEWORKDETAILRESPONSEBODY"]._serialized_end = 1083
    _globals["_HOMEWORK"]._serialized_start = 1086
    _globals["_HOMEWORK"]._serialized_end = 1320
# @@protoc_insertion_point(module_scope)
