# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/contract/contract.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/contract/contract.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"yeying/api/contract/contract.proto"\x16\n\x14\x43reateAddressRequest"(\n\x15\x43reateAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t"I\n\x12TransactionRequest\x12\x11\n\ttoAddress\x18\x01 \x01(\t\x12\x0e\n\x06points\x18\x02 \x01(\x05\x12\x10\n\x08metadata\x18\x03 \x01(\t"-\n\x13TransactionResponse\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x03"!\n\x0e\x42\x61lanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t"3\n\x0f\x42\x61lanceResponse\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x11\n\tavailable\x18\x02 \x01(\x03"$\n\x11WalletInfoRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t"Z\n\x12WalletInfoResponse\x12\r\n\x05total\x18\x01 \x01(\x03\x12\x11\n\tavailable\x18\x02 \x01(\x03\x12"\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x0c.Transaction"C\n\x0bTransaction\x12\x12\n\nto_address\x18\x01 \x01(\t\x12\x0e\n\x06points\x18\x02 \x01(\x05\x12\x10\n\x08metadata\x18\x03 \x01(\t2\xe7\x01\n\x06Wallet\x12>\n\rcreateAddress\x12\x15.CreateAddressRequest\x1a\x16.CreateAddressResponse\x12\x38\n\x0btransaction\x12\x13.TransactionRequest\x1a\x14.TransactionResponse\x12,\n\x07\x62\x61lance\x12\x0f.BalanceRequest\x1a\x10.BalanceResponse\x12\x35\n\nwalletInfo\x12\x12.WalletInfoRequest\x1a\x13.WalletInfoResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.contract.contract_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_CREATEADDRESSREQUEST"]._serialized_start = 38
    _globals["_CREATEADDRESSREQUEST"]._serialized_end = 60
    _globals["_CREATEADDRESSRESPONSE"]._serialized_start = 62
    _globals["_CREATEADDRESSRESPONSE"]._serialized_end = 102
    _globals["_TRANSACTIONREQUEST"]._serialized_start = 104
    _globals["_TRANSACTIONREQUEST"]._serialized_end = 177
    _globals["_TRANSACTIONRESPONSE"]._serialized_start = 179
    _globals["_TRANSACTIONRESPONSE"]._serialized_end = 224
    _globals["_BALANCEREQUEST"]._serialized_start = 226
    _globals["_BALANCEREQUEST"]._serialized_end = 259
    _globals["_BALANCERESPONSE"]._serialized_start = 261
    _globals["_BALANCERESPONSE"]._serialized_end = 312
    _globals["_WALLETINFOREQUEST"]._serialized_start = 314
    _globals["_WALLETINFOREQUEST"]._serialized_end = 350
    _globals["_WALLETINFORESPONSE"]._serialized_start = 352
    _globals["_WALLETINFORESPONSE"]._serialized_end = 442
    _globals["_TRANSACTION"]._serialized_start = 444
    _globals["_TRANSACTION"]._serialized_end = 511
    _globals["_WALLET"]._serialized_start = 514
    _globals["_WALLET"]._serialized_end = 745
# @@protoc_insertion_point(module_scope)
