# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/spider/spider.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/spider/spider.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/spider/spider.proto\x12\x11yeying.api.plugin\x1a\x1fyeying/api/common/message.proto"S\n\rSearchRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x33\n\rconditionList\x18\x02 \x03(\x0b\x32\x1c.yeying.api.plugin.Condition"\x18\n\tCondition\x12\x0b\n\x03sql\x18\x01 \x01(\t"G\n\x0eSearchResponse\x12\x35\n\x0epluginItemList\x18\x01 \x03(\x0b\x32\x1d.yeying.api.plugin.PluginItem"a\n\nPluginItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03"q\n\x0eInstallRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x06 \x01(\t"/\n\x10UninstallRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"N\n\x11UninstallResponse\x12\x39\n\x0eresponseStatus\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"L\n\x0fInstallResponse\x12\x39\n\x0eresponseStatus\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus*!\n\nPluginType\x12\x07\n\x03WEB\x10\x00\x12\n\n\x06SPIDER\x10\x01\x32\xab\x03\n\x06Spider\x12O\n\x06Search\x12 .yeying.api.plugin.SearchRequest\x1a!.yeying.api.plugin.SearchResponse"\x00\x12R\n\x07Install\x12!.yeying.api.plugin.InstallRequest\x1a".yeying.api.plugin.InstallResponse"\x00\x12R\n\x07Upgrade\x12!.yeying.api.plugin.InstallRequest\x1a".yeying.api.plugin.InstallResponse"\x00\x12Q\n\x06\x43onfig\x12!.yeying.api.plugin.InstallRequest\x1a".yeying.api.plugin.InstallResponse"\x00\x12U\n\x06Remove\x12#.yeying.api.plugin.UninstallRequest\x1a$.yeying.api.plugin.UninstallResponse"\x00\x42\x13Z\x11yeying/api/pluginb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.spider.spider_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/plugin"
    _globals["_PLUGINTYPE"]._serialized_start = 691
    _globals["_PLUGINTYPE"]._serialized_end = 724
    _globals["_SEARCHREQUEST"]._serialized_start = 86
    _globals["_SEARCHREQUEST"]._serialized_end = 169
    _globals["_CONDITION"]._serialized_start = 171
    _globals["_CONDITION"]._serialized_end = 195
    _globals["_SEARCHRESPONSE"]._serialized_start = 197
    _globals["_SEARCHRESPONSE"]._serialized_end = 268
    _globals["_PLUGINITEM"]._serialized_start = 270
    _globals["_PLUGINITEM"]._serialized_end = 367
    _globals["_INSTALLREQUEST"]._serialized_start = 369
    _globals["_INSTALLREQUEST"]._serialized_end = 482
    _globals["_UNINSTALLREQUEST"]._serialized_start = 484
    _globals["_UNINSTALLREQUEST"]._serialized_end = 531
    _globals["_UNINSTALLRESPONSE"]._serialized_start = 533
    _globals["_UNINSTALLRESPONSE"]._serialized_end = 611
    _globals["_INSTALLRESPONSE"]._serialized_start = 613
    _globals["_INSTALLRESPONSE"]._serialized_end = 689
    _globals["_SPIDER"]._serialized_start = 727
    _globals["_SPIDER"]._serialized_end = 1154
# @@protoc_insertion_point(module_scope)
