# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/application/application.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/application/application.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2
from yeying.api.common import model_pb2 as yeying_dot_api_dot_common_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/application/application.proto\x12\x16yeying.api.application\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto\x1a\x1dyeying/api/common/model.proto"\x90\x01\n\x18SearchApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.SearchApplicationRequestBody"\x88\x01\n\x1cSearchApplicationRequestBody\x12:\n\tcondition\x18\x01 \x01(\x0b\x32\'.yeying.api.application.SearchCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\xaf\x01\n\x0fSearchCondition\x12\x34\n\x04\x63ode\x18\x01 \x01(\x0e\x32&.yeying.api.common.ApplicationCodeEnum\x12\x38\n\x06status\x18\x02 \x01(\x0e\x32(.yeying.api.common.ApplicationStatusEnum\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07keyword\x18\x05 \x01(\t"\x92\x01\n\x19SearchApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.SearchApplicationResponseBody"\xbf\x01\n\x1dSearchApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12<\n\x0c\x61pplications\x18\x02 \x03(\x0b\x32&.yeying.api.common.ApplicationMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x90\x01\n\x18\x43reateApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.CreateApplicationRequestBody"[\n\x1c\x43reateApplicationRequestBody\x12;\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32&.yeying.api.common.ApplicationMetadata"\x92\x01\n\x19\x43reateApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.CreateApplicationResponseBody"\x8f\x01\n\x1d\x43reateApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32&.yeying.api.common.ApplicationMetadata"\x90\x01\n\x18\x41pplicationDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.ApplicationDetailRequestBody"<\n\x1c\x41pplicationDetailRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x92\x01\n\x19\x41pplicationDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.ApplicationDetailResponseBody"\x8f\x01\n\x1d\x41pplicationDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12;\n\x0b\x61pplication\x18\x02 \x01(\x0b\x32&.yeying.api.common.ApplicationMetadata"\x92\x01\n\x19OfflineApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.OfflineApplicationRequestBody"=\n\x1dOfflineApplicationRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x94\x01\n\x1aOfflineApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.application.OfflineApplicationResponseBody"S\n\x1eOfflineApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x90\x01\n\x18OnlineApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.OnlineApplicationRequestBody"<\n\x1cOnlineApplicationRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x92\x01\n\x19OnlineApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.OnlineApplicationResponseBody"R\n\x1dOnlineApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"Q\n\x11\x41pplicationExtend\x12<\n\x08\x63omments\x18\x01 \x03(\x0b\x32*.yeying.api.application.ApplicationComment"Y\n\x12\x41pplicationComment\x12\x0f\n\x07\x61uditor\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x0e\n\x06passed\x18\x03 \x01(\x08\x12\x11\n\tsignature\x18\x04 \x01(\t"\x90\x01\n\x18\x44\x65leteApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.DeleteApplicationRequestBody"<\n\x1c\x44\x65leteApplicationRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\r"\x92\x01\n\x19\x44\x65leteApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.application.DeleteApplicationResponseBody"R\n\x1d\x44\x65leteApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8e\x01\n\x17\x41uditApplicationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.application.AuditApplicationRequestBody"x\n\x1b\x41uditApplicationRequestBody\x12;\n\x07\x63omment\x18\x01 \x01(\x0b\x32*.yeying.api.application.ApplicationComment\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\r"\x90\x01\n\x18\x41uditApplicationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.application.AuditApplicationResponseBody"Q\n\x1c\x41uditApplicationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xa4\x06\n\x0b\x41pplication\x12o\n\x06Search\x12\x30.yeying.api.application.SearchApplicationRequest\x1a\x31.yeying.api.application.SearchApplicationResponse"\x00\x12l\n\x05\x41udit\x12/.yeying.api.application.AuditApplicationRequest\x1a\x30.yeying.api.application.AuditApplicationResponse"\x00\x12o\n\x06\x43reate\x12\x30.yeying.api.application.CreateApplicationRequest\x1a\x31.yeying.api.application.CreateApplicationResponse"\x00\x12o\n\x06\x44\x65tail\x12\x30.yeying.api.application.ApplicationDetailRequest\x1a\x31.yeying.api.application.ApplicationDetailResponse"\x00\x12r\n\x07Offline\x12\x31.yeying.api.application.OfflineApplicationRequest\x1a\x32.yeying.api.application.OfflineApplicationResponse"\x00\x12o\n\x06Online\x12\x30.yeying.api.application.OnlineApplicationRequest\x1a\x31.yeying.api.application.OnlineApplicationResponse"\x00\x12o\n\x06\x44\x65lete\x12\x30.yeying.api.application.DeleteApplicationRequest\x1a\x31.yeying.api.application.DeleteApplicationResponse"\x00\x42\x18Z\x16yeying/api/applicationb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.application.application_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\026yeying/api/application"
    _globals["_SEARCHAPPLICATIONREQUEST"]._serialized_start = 163
    _globals["_SEARCHAPPLICATIONREQUEST"]._serialized_end = 307
    _globals["_SEARCHAPPLICATIONREQUESTBODY"]._serialized_start = 310
    _globals["_SEARCHAPPLICATIONREQUESTBODY"]._serialized_end = 446
    _globals["_SEARCHCONDITION"]._serialized_start = 449
    _globals["_SEARCHCONDITION"]._serialized_end = 624
    _globals["_SEARCHAPPLICATIONRESPONSE"]._serialized_start = 627
    _globals["_SEARCHAPPLICATIONRESPONSE"]._serialized_end = 773
    _globals["_SEARCHAPPLICATIONRESPONSEBODY"]._serialized_start = 776
    _globals["_SEARCHAPPLICATIONRESPONSEBODY"]._serialized_end = 967
    _globals["_CREATEAPPLICATIONREQUEST"]._serialized_start = 970
    _globals["_CREATEAPPLICATIONREQUEST"]._serialized_end = 1114
    _globals["_CREATEAPPLICATIONREQUESTBODY"]._serialized_start = 1116
    _globals["_CREATEAPPLICATIONREQUESTBODY"]._serialized_end = 1207
    _globals["_CREATEAPPLICATIONRESPONSE"]._serialized_start = 1210
    _globals["_CREATEAPPLICATIONRESPONSE"]._serialized_end = 1356
    _globals["_CREATEAPPLICATIONRESPONSEBODY"]._serialized_start = 1359
    _globals["_CREATEAPPLICATIONRESPONSEBODY"]._serialized_end = 1502
    _globals["_APPLICATIONDETAILREQUEST"]._serialized_start = 1505
    _globals["_APPLICATIONDETAILREQUEST"]._serialized_end = 1649
    _globals["_APPLICATIONDETAILREQUESTBODY"]._serialized_start = 1651
    _globals["_APPLICATIONDETAILREQUESTBODY"]._serialized_end = 1711
    _globals["_APPLICATIONDETAILRESPONSE"]._serialized_start = 1714
    _globals["_APPLICATIONDETAILRESPONSE"]._serialized_end = 1860
    _globals["_APPLICATIONDETAILRESPONSEBODY"]._serialized_start = 1863
    _globals["_APPLICATIONDETAILRESPONSEBODY"]._serialized_end = 2006
    _globals["_OFFLINEAPPLICATIONREQUEST"]._serialized_start = 2009
    _globals["_OFFLINEAPPLICATIONREQUEST"]._serialized_end = 2155
    _globals["_OFFLINEAPPLICATIONREQUESTBODY"]._serialized_start = 2157
    _globals["_OFFLINEAPPLICATIONREQUESTBODY"]._serialized_end = 2218
    _globals["_OFFLINEAPPLICATIONRESPONSE"]._serialized_start = 2221
    _globals["_OFFLINEAPPLICATIONRESPONSE"]._serialized_end = 2369
    _globals["_OFFLINEAPPLICATIONRESPONSEBODY"]._serialized_start = 2371
    _globals["_OFFLINEAPPLICATIONRESPONSEBODY"]._serialized_end = 2454
    _globals["_ONLINEAPPLICATIONREQUEST"]._serialized_start = 2457
    _globals["_ONLINEAPPLICATIONREQUEST"]._serialized_end = 2601
    _globals["_ONLINEAPPLICATIONREQUESTBODY"]._serialized_start = 2603
    _globals["_ONLINEAPPLICATIONREQUESTBODY"]._serialized_end = 2663
    _globals["_ONLINEAPPLICATIONRESPONSE"]._serialized_start = 2666
    _globals["_ONLINEAPPLICATIONRESPONSE"]._serialized_end = 2812
    _globals["_ONLINEAPPLICATIONRESPONSEBODY"]._serialized_start = 2814
    _globals["_ONLINEAPPLICATIONRESPONSEBODY"]._serialized_end = 2896
    _globals["_APPLICATIONEXTEND"]._serialized_start = 2898
    _globals["_APPLICATIONEXTEND"]._serialized_end = 2979
    _globals["_APPLICATIONCOMMENT"]._serialized_start = 2981
    _globals["_APPLICATIONCOMMENT"]._serialized_end = 3070
    _globals["_DELETEAPPLICATIONREQUEST"]._serialized_start = 3073
    _globals["_DELETEAPPLICATIONREQUEST"]._serialized_end = 3217
    _globals["_DELETEAPPLICATIONREQUESTBODY"]._serialized_start = 3219
    _globals["_DELETEAPPLICATIONREQUESTBODY"]._serialized_end = 3279
    _globals["_DELETEAPPLICATIONRESPONSE"]._serialized_start = 3282
    _globals["_DELETEAPPLICATIONRESPONSE"]._serialized_end = 3428
    _globals["_DELETEAPPLICATIONRESPONSEBODY"]._serialized_start = 3430
    _globals["_DELETEAPPLICATIONRESPONSEBODY"]._serialized_end = 3512
    _globals["_AUDITAPPLICATIONREQUEST"]._serialized_start = 3515
    _globals["_AUDITAPPLICATIONREQUEST"]._serialized_end = 3657
    _globals["_AUDITAPPLICATIONREQUESTBODY"]._serialized_start = 3659
    _globals["_AUDITAPPLICATIONREQUESTBODY"]._serialized_end = 3779
    _globals["_AUDITAPPLICATIONRESPONSE"]._serialized_start = 3782
    _globals["_AUDITAPPLICATIONRESPONSE"]._serialized_end = 3926
    _globals["_AUDITAPPLICATIONRESPONSEBODY"]._serialized_start = 3928
    _globals["_AUDITAPPLICATIONRESPONSEBODY"]._serialized_end = 4009
    _globals["_APPLICATION"]._serialized_start = 4012
    _globals["_APPLICATION"]._serialized_end = 4816
# @@protoc_insertion_point(module_scope)
