# Generated by protobuf_init. Do not edit manually.
from .mail_pb2 import SendMailRequest
from .mail_pb2 import SendMailRequestBody
from .mail_pb2 import SendMailResponse
from .mail_pb2 import SendMailResponseBody
from .mail_pb2 import VerifyMailRequest
from .mail_pb2 import VerifyMailRequestBody
from .mail_pb2 import VerifyMailResponse
from .mail_pb2 import VerifyMailResponseBody
from .mail_pb2_grpc import MailServicer
from .mail_pb2_grpc import MailStub
from .mail_pb2_grpc import add_MailServicer_to_server
from .mail_pb2_grpc import Mail
