# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/invitation/invitation.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/invitation/invitation.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&yeying/api/invitation/invitation.proto\x12\x15yeying.api.invitation\x1a\x1fyeying/api/common/message.proto"\xb8\x01\n\x12InvitationMetadata\x12\x39\n\x05scene\x18\x01 \x01(\x0e\x32*.yeying.api.invitation.InvitationSceneEnum\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\t\x12\x11\n\texpiredAt\x18\x04 \x01(\t\x12\x0f\n\x07inviter\x18\x05 \x01(\t\x12\x0f\n\x07invitee\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t"S\n\x12InvitationUseState\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06usedAt\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t"\x8d\x01\n\x17\x43reateInvitationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.invitation.CreateInvitationRequestBody"\\\n\x1b\x43reateInvitationRequestBody\x12=\n\ninvitation\x18\x02 \x01(\x0b\x32).yeying.api.invitation.InvitationMetadata"\x8f\x01\n\x18\x43reateInvitationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.invitation.CreateInvitationResponseBody"\x90\x01\n\x1c\x43reateInvitationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12=\n\ninvitation\x18\x02 \x01(\x0b\x32).yeying.api.invitation.InvitationMetadata"\x8d\x01\n\x17SearchInvitationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.invitation.SearchInvitationRequestBody"K\n\x1bSearchInvitationRequestBody\x12,\n\x04page\x18\x01 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x8f\x01\n\x18SearchInvitationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.invitation.SearchInvitationResponseBody"\xc0\x01\n\x1cSearchInvitationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12>\n\x0binvitations\x18\x02 \x03(\x0b\x32).yeying.api.invitation.InvitationMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x8d\x01\n\x17InvitationDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.invitation.InvitationDetailRequestBody"+\n\x1bInvitationDetailRequestBody\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x8f\x01\n\x18InvitationDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.invitation.InvitationDetailResponseBody"\xca\x01\n\x1cInvitationDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12=\n\ninvitation\x18\x02 \x01(\x0b\x32).yeying.api.invitation.InvitationMetadata\x12\x38\n\x05state\x18\x03 \x01(\x0b\x32).yeying.api.invitation.InvitationUseState*N\n\x13InvitationSceneEnum\x12\x1c\n\x18INVITATION_SCENE_UNKNOWN\x10\x00\x12\x19\n\x15INVITATION_SCENE_USER\x10\x01\x32\xd3\x02\n\nInvitation\x12k\n\x06\x43reate\x12..yeying.api.invitation.CreateInvitationRequest\x1a/.yeying.api.invitation.CreateInvitationResponse"\x00\x12k\n\x06Search\x12..yeying.api.invitation.SearchInvitationRequest\x1a/.yeying.api.invitation.SearchInvitationResponse"\x00\x12k\n\x06\x44\x65tail\x12..yeying.api.invitation.InvitationDetailRequest\x1a/.yeying.api.invitation.InvitationDetailResponse"\x00\x42\x17Z\x15yeying/api/invitationb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.invitation.invitation_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\025yeying/api/invitation"
    _globals["_INVITATIONSCENEENUM"]._serialized_start = 2003
    _globals["_INVITATIONSCENEENUM"]._serialized_end = 2081
    _globals["_INVITATIONMETADATA"]._serialized_start = 99
    _globals["_INVITATIONMETADATA"]._serialized_end = 283
    _globals["_INVITATIONUSESTATE"]._serialized_start = 285
    _globals["_INVITATIONUSESTATE"]._serialized_end = 368
    _globals["_CREATEINVITATIONREQUEST"]._serialized_start = 371
    _globals["_CREATEINVITATIONREQUEST"]._serialized_end = 512
    _globals["_CREATEINVITATIONREQUESTBODY"]._serialized_start = 514
    _globals["_CREATEINVITATIONREQUESTBODY"]._serialized_end = 606
    _globals["_CREATEINVITATIONRESPONSE"]._serialized_start = 609
    _globals["_CREATEINVITATIONRESPONSE"]._serialized_end = 752
    _globals["_CREATEINVITATIONRESPONSEBODY"]._serialized_start = 755
    _globals["_CREATEINVITATIONRESPONSEBODY"]._serialized_end = 899
    _globals["_SEARCHINVITATIONREQUEST"]._serialized_start = 902
    _globals["_SEARCHINVITATIONREQUEST"]._serialized_end = 1043
    _globals["_SEARCHINVITATIONREQUESTBODY"]._serialized_start = 1045
    _globals["_SEARCHINVITATIONREQUESTBODY"]._serialized_end = 1120
    _globals["_SEARCHINVITATIONRESPONSE"]._serialized_start = 1123
    _globals["_SEARCHINVITATIONRESPONSE"]._serialized_end = 1266
    _globals["_SEARCHINVITATIONRESPONSEBODY"]._serialized_start = 1269
    _globals["_SEARCHINVITATIONRESPONSEBODY"]._serialized_end = 1461
    _globals["_INVITATIONDETAILREQUEST"]._serialized_start = 1464
    _globals["_INVITATIONDETAILREQUEST"]._serialized_end = 1605
    _globals["_INVITATIONDETAILREQUESTBODY"]._serialized_start = 1607
    _globals["_INVITATIONDETAILREQUESTBODY"]._serialized_end = 1650
    _globals["_INVITATIONDETAILRESPONSE"]._serialized_start = 1653
    _globals["_INVITATIONDETAILRESPONSE"]._serialized_end = 1796
    _globals["_INVITATIONDETAILRESPONSEBODY"]._serialized_start = 1799
    _globals["_INVITATIONDETAILRESPONSEBODY"]._serialized_end = 2001
    _globals["_INVITATION"]._serialized_start = 2084
    _globals["_INVITATION"]._serialized_end = 2423
# @@protoc_insertion_point(module_scope)
