# Generated by protobuf_init. Do not edit manually.
from .identity_pb2 import DepositRequest
from .identity_pb2 import DepositRequestBody
from .identity_pb2 import DepositResponse
from .identity_pb2 import DepositResponseBody
from .identity_pb2 import RetrieveRequest
from .identity_pb2 import RetrieveResponse
from .identity_pb2 import ShareRequest
from .identity_pb2 import ShareResponse
from .identity_pb2 import QueryRequest
from .identity_pb2 import QueryRequestBody
from .identity_pb2 import QueryResponse
from .identity_pb2 import QueryResponseBody
from .identity_pb2 import CancelRequest
from .identity_pb2 import CancelRequestBody
from .identity_pb2 import CancelResponse
from .identity_pb2 import CancelResponseBody
from .identity_pb2_grpc import IdentityServicer
from .identity_pb2_grpc import IdentityStub
from .identity_pb2_grpc import add_IdentityServicer_to_server
from .identity_pb2_grpc import Identity
