# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/mistakes.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/mistakes.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)yeying/api/apps/zuoyepigai/mistakes.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x8a\x01\n\x13MistakesListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.MistakesListRequestBody"&\n\x17MistakesListRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8c\x01\n\x14MistakesListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.MistakesListResponseBody"\x89\x01\n\x18MistakesListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04list\x18\x02 \x03(\x0b\x32,.yeying.api.apps.zuoyepigai.MistakesMetadata"\x8e\x01\n\x15MistakesDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MistakesDetailRequestBody"(\n\x19MistakesDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x90\x01\n\x16MistakesDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.MistakesDetailResponseBody"\x8b\x01\n\x1aMistakesDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04meta\x18\x02 \x01(\x0b\x32,.yeying.api.apps.zuoyepigai.MistakesMetadata"\x92\x01\n\x17MistakesAnalysisRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x45\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x37.yeying.api.apps.zuoyepigai.MistakesAnalysisRequestBody")\n\x1bMistakesAnalysisRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x94\x01\n\x18MistakesAnalysisResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x46\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x38.yeying.api.apps.zuoyepigai.MistakesAnalysisResponseBody"Q\n\x1cMistakesAnalysisResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8e\x01\n\x15MakeCorrectionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MakeCorrectionRequestBody"\'\n\x19MakeCorrectionRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x90\x01\n\x16MakeCorrectionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.MakeCorrectionResponseBody"O\n\x1aMakeCorrectionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8c\x01\n\x14MistakesPrintRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.MistakesPrintRequestBody"&\n\x18MistakesPrintRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x8e\x01\n\x15MistakesPrintResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MistakesPrintResponseBody"N\n\x19MistakesPrintResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8e\x01\n\x15MistakesSubmitRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MistakesSubmitRequestBody"\'\n\x19MistakesSubmitRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x90\x01\n\x16MistakesSubmitResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.MistakesSubmitResponseBody"O\n\x1aMistakesSubmitResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xc1\x05\n\x08Mistakes\x12k\n\x04List\x12/.yeying.api.apps.zuoyepigai.MistakesListRequest\x1a\x30.yeying.api.apps.zuoyepigai.MistakesListResponse"\x00\x12q\n\x06\x44\x65tail\x12\x31.yeying.api.apps.zuoyepigai.MistakesDetailRequest\x1a\x32.yeying.api.apps.zuoyepigai.MistakesDetailResponse"\x00\x12w\n\x08\x41nalysis\x12\x33.yeying.api.apps.zuoyepigai.MistakesAnalysisRequest\x1a\x34.yeying.api.apps.zuoyepigai.MistakesAnalysisResponse"\x00\x12y\n\x0eMakeCorrection\x12\x31.yeying.api.apps.zuoyepigai.MakeCorrectionRequest\x1a\x32.yeying.api.apps.zuoyepigai.MakeCorrectionResponse"\x00\x12n\n\x05Print\x12\x30.yeying.api.apps.zuoyepigai.MistakesPrintRequest\x1a\x31.yeying.api.apps.zuoyepigai.MistakesPrintResponse"\x00\x12q\n\x06Submit\x12\x31.yeying.api.apps.zuoyepigai.MistakesSubmitRequest\x1a\x32.yeying.api.apps.zuoyepigai.MistakesSubmitResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.mistakes_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_MISTAKESLISTREQUEST"]._serialized_start = 146
    _globals["_MISTAKESLISTREQUEST"]._serialized_end = 284
    _globals["_MISTAKESLISTREQUESTBODY"]._serialized_start = 286
    _globals["_MISTAKESLISTREQUESTBODY"]._serialized_end = 324
    _globals["_MISTAKESLISTRESPONSE"]._serialized_start = 327
    _globals["_MISTAKESLISTRESPONSE"]._serialized_end = 467
    _globals["_MISTAKESLISTRESPONSEBODY"]._serialized_start = 470
    _globals["_MISTAKESLISTRESPONSEBODY"]._serialized_end = 607
    _globals["_MISTAKESDETAILREQUEST"]._serialized_start = 610
    _globals["_MISTAKESDETAILREQUEST"]._serialized_end = 752
    _globals["_MISTAKESDETAILREQUESTBODY"]._serialized_start = 754
    _globals["_MISTAKESDETAILREQUESTBODY"]._serialized_end = 794
    _globals["_MISTAKESDETAILRESPONSE"]._serialized_start = 797
    _globals["_MISTAKESDETAILRESPONSE"]._serialized_end = 941
    _globals["_MISTAKESDETAILRESPONSEBODY"]._serialized_start = 944
    _globals["_MISTAKESDETAILRESPONSEBODY"]._serialized_end = 1083
    _globals["_MISTAKESANALYSISREQUEST"]._serialized_start = 1086
    _globals["_MISTAKESANALYSISREQUEST"]._serialized_end = 1232
    _globals["_MISTAKESANALYSISREQUESTBODY"]._serialized_start = 1234
    _globals["_MISTAKESANALYSISREQUESTBODY"]._serialized_end = 1275
    _globals["_MISTAKESANALYSISRESPONSE"]._serialized_start = 1278
    _globals["_MISTAKESANALYSISRESPONSE"]._serialized_end = 1426
    _globals["_MISTAKESANALYSISRESPONSEBODY"]._serialized_start = 1428
    _globals["_MISTAKESANALYSISRESPONSEBODY"]._serialized_end = 1509
    _globals["_MAKECORRECTIONREQUEST"]._serialized_start = 1512
    _globals["_MAKECORRECTIONREQUEST"]._serialized_end = 1654
    _globals["_MAKECORRECTIONREQUESTBODY"]._serialized_start = 1656
    _globals["_MAKECORRECTIONREQUESTBODY"]._serialized_end = 1695
    _globals["_MAKECORRECTIONRESPONSE"]._serialized_start = 1698
    _globals["_MAKECORRECTIONRESPONSE"]._serialized_end = 1842
    _globals["_MAKECORRECTIONRESPONSEBODY"]._serialized_start = 1844
    _globals["_MAKECORRECTIONRESPONSEBODY"]._serialized_end = 1923
    _globals["_MISTAKESPRINTREQUEST"]._serialized_start = 1926
    _globals["_MISTAKESPRINTREQUEST"]._serialized_end = 2066
    _globals["_MISTAKESPRINTREQUESTBODY"]._serialized_start = 2068
    _globals["_MISTAKESPRINTREQUESTBODY"]._serialized_end = 2106
    _globals["_MISTAKESPRINTRESPONSE"]._serialized_start = 2109
    _globals["_MISTAKESPRINTRESPONSE"]._serialized_end = 2251
    _globals["_MISTAKESPRINTRESPONSEBODY"]._serialized_start = 2253
    _globals["_MISTAKESPRINTRESPONSEBODY"]._serialized_end = 2331
    _globals["_MISTAKESSUBMITREQUEST"]._serialized_start = 2334
    _globals["_MISTAKESSUBMITREQUEST"]._serialized_end = 2476
    _globals["_MISTAKESSUBMITREQUESTBODY"]._serialized_start = 2478
    _globals["_MISTAKESSUBMITREQUESTBODY"]._serialized_end = 2517
    _globals["_MISTAKESSUBMITRESPONSE"]._serialized_start = 2520
    _globals["_MISTAKESSUBMITRESPONSE"]._serialized_end = 2664
    _globals["_MISTAKESSUBMITRESPONSEBODY"]._serialized_start = 2666
    _globals["_MISTAKESSUBMITRESPONSEBODY"]._serialized_end = 2745
    _globals["_MISTAKES"]._serialized_start = 2748
    _globals["_MISTAKES"]._serialized_end = 3453
# @@protoc_insertion_point(module_scope)
