# Generated by protobuf_init. Do not edit manually.
from .web3_pb2 import Identity
from .web3_pb2 import Registry
from .web3_pb2 import IdentityMetadata
from .web3_pb2 import BlockAddress
from .web3_pb2 import Mnemonic
from .web3_pb2 import IdentityServiceExtend
from .web3_pb2 import IdentityOrganizationExtend
from .web3_pb2 import IdentityPersonalExtend
from .web3_pb2 import IdentityApplicationExtend
from .web3_pb2 import SecurityConfig
from .web3_pb2 import SecurityAlgorithm
from .web3_pb2 import IdentityCodeEnum
from .web3_pb2 import NetworkTypeEnum
