# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/llm/llm.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/llm/llm.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18yeying/api/llm/llm.proto\x12\x0eyeying.api.llm\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"v\n\x0f\x43ompleteRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.llm.CompleteRequestBody"\x98\x01\n\x13\x43ompleteRequestBody\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x10\n\x08promptId\x18\x02 \x01(\t\x12\x12\n\nproviderId\x18\x03 \x01(\t\x12\r\n\x05model\x18\x04 \x01(\t\x12\x0e\n\x06stream\x18\x05 \x01(\x08\x12)\n\x08messages\x18\x06 \x03(\x0b\x32\x17.yeying.api.llm.Message"b\n\x07Message\x12-\n\x04role\x18\x01 \x01(\x0e\x32\x1f.yeying.api.llm.MessageRoleEnum\x12(\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x17.yeying.api.llm.Content"F\n\x07\x43ontent\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.yeying.api.llm.ContentTypeEnum\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t"_\n\x06\x41nswer\x12\r\n\x05model\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\x03\x12\'\n\x07\x63hoices\x18\x04 \x03(\x0b\x32\x16.yeying.api.llm.Choice"\xbc\x01\n\x10\x43ompleteResponse\x12\x34\n\x04head\x18\x02 \x01(\x0b\x32$.yeying.api.llm.CompleteResponseHeadH\x00\x12\x34\n\x04\x62ody\x18\x03 \x01(\x0b\x32$.yeying.api.llm.CompleteResponseBodyH\x00\x12\x34\n\x04tail\x18\x04 \x01(\x0b\x32$.yeying.api.llm.CompleteResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x80\x01\n\x14\x43ompleteResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.CompleteResponseHeadBody"M\n\x18\x43ompleteResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"$\n\x14\x43ompleteResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t"\x80\x01\n\x14\x43ompleteResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.CompleteResponseTailBody"M\n\x18\x43ompleteResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"v\n\x0fGenerateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.llm.GenerateRequestBody"\xc5\x01\n\x13GenerateRequestBody\x12\r\n\x05llmId\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12\x43\n\x15responseContentFormat\x18\x04 \x01(\x0e\x32$.yeying.api.common.ContentFormatEnum\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x0c\n\x04size\x18\x06 \x01(\t\x12\x0f\n\x07quality\x18\x07 \x01(\t\x12\r\n\x05style\x18\x08 \x01(\t"\xbc\x01\n\x10GenerateResponse\x12\x34\n\x04head\x18\x02 \x01(\x0b\x32$.yeying.api.llm.GenerateResponseHeadH\x00\x12\x34\n\x04\x62ody\x18\x03 \x01(\x0b\x32$.yeying.api.llm.GenerateResponseBodyH\x00\x12\x34\n\x04tail\x18\x04 \x01(\x0b\x32$.yeying.api.llm.GenerateResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x80\x01\n\x14GenerateResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.GenerateResponseHeadBody"M\n\x18GenerateResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"$\n\x14GenerateResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t"\x80\x01\n\x14GenerateResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.GenerateResponseTailBody"M\n\x18GenerateResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x1d\n\nTextPrompt\x12\x0f\n\x07message\x18\x01 \x01(\t";\n\x0bImagePrompt\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04mask\x18\x02 \x01(\x0c\x12\r\n\x05image\x18\x03 \x01(\x0c"\x8f\x01\n\x0bImageResult\x12\x43\n\x15responseContentFormat\x18\x01 \x01(\x0e\x32$.yeying.api.common.ContentFormatEnum\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0c\n\x04size\x18\x03 \x01(\t\x12\x0f\n\x07quality\x18\x04 \x01(\t\x12\r\n\x05style\x18\x05 \x01(\t"\xd4\x02\n\x0b\x45\x64itRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05llmId\x18\x02 \x01(\t\x12\r\n\x05model\x18\x03 \x01(\t\x12\x35\n\x07srcType\x18\x05 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x35\n\x07\x64\x65sType\x18\x06 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x30\n\ntextPrompt\x18\x07 \x01(\x0b\x32\x1a.yeying.api.llm.TextPromptH\x00\x12\x32\n\x0bimagePrompt\x18\x08 \x01(\x0b\x32\x1b.yeying.api.llm.ImagePromptH\x00\x12\x32\n\x0bimageResult\x18\t \x01(\x0b\x32\x1b.yeying.api.llm.ImageResultH\x01\x42\x08\n\x06promptB\x08\n\x06result"l\n\x0c\x45\x64itResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x10\n\x06\x62\x61se64\x18\x02 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x03 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta"@\n\x10TranslateRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05llmId\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t"F\n\x11TranslateResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus">\n\x0e\x43onvertRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05llmId\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t"D\n\x0f\x43onvertResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x86\x01\n\x06\x43hoice\x12\r\n\x05index\x18\x01 \x01(\x05\x12-\n\x04role\x18\x02 \x01(\x0e\x32\x1f.yeying.api.llm.MessageRoleEnum\x12(\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x17.yeying.api.llm.Content\x12\x14\n\x0c\x66inishReason\x18\x04 \x01(\t"\x0f\n\rSpeechRequest"\x10\n\x0eSpeechResponse*w\n\x0fMessageRoleEnum\x12\x18\n\x14MESSAGE_ROLE_UNKNOWN\x10\x00\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x03*\xa5\x01\n\x0f\x43ontentTypeEnum\x12\x18\n\x14\x43ONTENT_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11\x43ONTENT_TYPE_TEXT\x10\x01\x12\x16\n\x12\x43ONTENT_TYPE_IMAGE\x10\x02\x12\x16\n\x12\x43ONTENT_TYPE_AUDIO\x10\x03\x12\x16\n\x12\x43ONTENT_TYPE_VIDEO\x10\x04\x12\x19\n\x15\x43ONTENT_TYPE_DOCUMENT\x10\x05\x32\x91\x03\n\x03Llm\x12R\n\tTranslate\x12 .yeying.api.llm.TranslateRequest\x1a!.yeying.api.llm.TranslateResponse"\x00\x12Q\n\x08\x43omplete\x12\x1f.yeying.api.llm.CompleteRequest\x1a .yeying.api.llm.CompleteResponse"\x00\x30\x01\x12\x45\n\x04\x45\x64it\x12\x1b.yeying.api.llm.EditRequest\x1a\x1c.yeying.api.llm.EditResponse"\x00\x30\x01\x12Q\n\x08Generate\x12\x1f.yeying.api.llm.GenerateRequest\x1a .yeying.api.llm.GenerateResponse"\x00\x30\x01\x12I\n\x06Speech\x12\x1d.yeying.api.llm.SpeechRequest\x1a\x1e.yeying.api.llm.SpeechResponse"\x00\x42\x10Z\x0eyeying/api/llmb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.llm.llm_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\016yeying/api/llm"
    _globals["_MESSAGEROLEENUM"]._serialized_start = 3404
    _globals["_MESSAGEROLEENUM"]._serialized_end = 3523
    _globals["_CONTENTTYPEENUM"]._serialized_start = 3526
    _globals["_CONTENTTYPEENUM"]._serialized_end = 3691
    _globals["_COMPLETEREQUEST"]._serialized_start = 107
    _globals["_COMPLETEREQUEST"]._serialized_end = 225
    _globals["_COMPLETEREQUESTBODY"]._serialized_start = 228
    _globals["_COMPLETEREQUESTBODY"]._serialized_end = 380
    _globals["_MESSAGE"]._serialized_start = 382
    _globals["_MESSAGE"]._serialized_end = 480
    _globals["_CONTENT"]._serialized_start = 482
    _globals["_CONTENT"]._serialized_end = 552
    _globals["_ANSWER"]._serialized_start = 554
    _globals["_ANSWER"]._serialized_end = 649
    _globals["_COMPLETERESPONSE"]._serialized_start = 652
    _globals["_COMPLETERESPONSE"]._serialized_end = 840
    _globals["_COMPLETERESPONSEHEAD"]._serialized_start = 843
    _globals["_COMPLETERESPONSEHEAD"]._serialized_end = 971
    _globals["_COMPLETERESPONSEHEADBODY"]._serialized_start = 973
    _globals["_COMPLETERESPONSEHEADBODY"]._serialized_end = 1050
    _globals["_COMPLETERESPONSEBODY"]._serialized_start = 1052
    _globals["_COMPLETERESPONSEBODY"]._serialized_end = 1088
    _globals["_COMPLETERESPONSETAIL"]._serialized_start = 1091
    _globals["_COMPLETERESPONSETAIL"]._serialized_end = 1219
    _globals["_COMPLETERESPONSETAILBODY"]._serialized_start = 1221
    _globals["_COMPLETERESPONSETAILBODY"]._serialized_end = 1298
    _globals["_GENERATEREQUEST"]._serialized_start = 1300
    _globals["_GENERATEREQUEST"]._serialized_end = 1418
    _globals["_GENERATEREQUESTBODY"]._serialized_start = 1421
    _globals["_GENERATEREQUESTBODY"]._serialized_end = 1618
    _globals["_GENERATERESPONSE"]._serialized_start = 1621
    _globals["_GENERATERESPONSE"]._serialized_end = 1809
    _globals["_GENERATERESPONSEHEAD"]._serialized_start = 1812
    _globals["_GENERATERESPONSEHEAD"]._serialized_end = 1940
    _globals["_GENERATERESPONSEHEADBODY"]._serialized_start = 1942
    _globals["_GENERATERESPONSEHEADBODY"]._serialized_end = 2019
    _globals["_GENERATERESPONSEBODY"]._serialized_start = 2021
    _globals["_GENERATERESPONSEBODY"]._serialized_end = 2057
    _globals["_GENERATERESPONSETAIL"]._serialized_start = 2060
    _globals["_GENERATERESPONSETAIL"]._serialized_end = 2188
    _globals["_GENERATERESPONSETAILBODY"]._serialized_start = 2190
    _globals["_GENERATERESPONSETAILBODY"]._serialized_end = 2267
    _globals["_TEXTPROMPT"]._serialized_start = 2269
    _globals["_TEXTPROMPT"]._serialized_end = 2298
    _globals["_IMAGEPROMPT"]._serialized_start = 2300
    _globals["_IMAGEPROMPT"]._serialized_end = 2359
    _globals["_IMAGERESULT"]._serialized_start = 2362
    _globals["_IMAGERESULT"]._serialized_end = 2505
    _globals["_EDITREQUEST"]._serialized_start = 2508
    _globals["_EDITREQUEST"]._serialized_end = 2848
    _globals["_EDITRESPONSE"]._serialized_start = 2850
    _globals["_EDITRESPONSE"]._serialized_end = 2958
    _globals["_TRANSLATEREQUEST"]._serialized_start = 2960
    _globals["_TRANSLATEREQUEST"]._serialized_end = 3024
    _globals["_TRANSLATERESPONSE"]._serialized_start = 3026
    _globals["_TRANSLATERESPONSE"]._serialized_end = 3096
    _globals["_CONVERTREQUEST"]._serialized_start = 3098
    _globals["_CONVERTREQUEST"]._serialized_end = 3160
    _globals["_CONVERTRESPONSE"]._serialized_start = 3162
    _globals["_CONVERTRESPONSE"]._serialized_end = 3230
    _globals["_CHOICE"]._serialized_start = 3233
    _globals["_CHOICE"]._serialized_end = 3367
    _globals["_SPEECHREQUEST"]._serialized_start = 3369
    _globals["_SPEECHREQUEST"]._serialized_end = 3384
    _globals["_SPEECHRESPONSE"]._serialized_start = 3386
    _globals["_SPEECHRESPONSE"]._serialized_end = 3402
    _globals["_LLM"]._serialized_start = 3694
    _globals["_LLM"]._serialized_end = 4095
# @@protoc_insertion_point(module_scope)
