# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/network/registry.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/network/registry.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!yeying/api/network/registry.proto\x12\x0eyeying.network\x1a\x1cyeying/api/common/code.proto"\r\n\x0bListRequest":\n\x0cListResponse\x12*\n\x08\x63ontract\x18\x01 \x03(\x0b\x32\x18.yeying.network.Contract"j\n\x0b\x45xitRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12"\n\x04peer\x18\x02 \x01(\x0b\x32\x14.yeying.network.Peer\x12*\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x18.yeying.network.Contract"\x12\n\x04Peer\x12\n\n\x02id\x18\x01 \x01(\t"\x1e\n\x0c\x45xitResponse\x12\x0e\n\x06status\x18\x01 \x01(\t"j\n\x0bJoinRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12"\n\x04peer\x18\x02 \x01(\x0b\x32\x14.yeying.network.Peer\x12*\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x18.yeying.network.Contract"j\n\x0cJoinResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.yeying.network.RegisterStatus\x12*\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x18.yeying.network.Contract"\x1b\n\x08\x43ontract\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t*-\n\x0eRegisterStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nREGISTERED\x10\x01\x32\xd8\x01\n\x07Network\x12\x43\n\x04List\x12\x1b.yeying.network.ListRequest\x1a\x1c.yeying.network.ListResponse"\x00\x12\x43\n\x04Join\x12\x1b.yeying.network.JoinRequest\x1a\x1c.yeying.network.JoinResponse"\x00\x12\x43\n\x04\x45xit\x12\x1b.yeying.network.ExitRequest\x1a\x1c.yeying.network.ExitResponse"\x00\x42\x14Z\x12yeying/api/networkb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.network.registry_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/network"
    _globals["_REGISTERSTATUS"]._serialized_start = 563
    _globals["_REGISTERSTATUS"]._serialized_end = 608
    _globals["_LISTREQUEST"]._serialized_start = 83
    _globals["_LISTREQUEST"]._serialized_end = 96
    _globals["_LISTRESPONSE"]._serialized_start = 98
    _globals["_LISTRESPONSE"]._serialized_end = 156
    _globals["_EXITREQUEST"]._serialized_start = 158
    _globals["_EXITREQUEST"]._serialized_end = 264
    _globals["_PEER"]._serialized_start = 266
    _globals["_PEER"]._serialized_end = 284
    _globals["_EXITRESPONSE"]._serialized_start = 286
    _globals["_EXITRESPONSE"]._serialized_end = 316
    _globals["_JOINREQUEST"]._serialized_start = 318
    _globals["_JOINREQUEST"]._serialized_end = 424
    _globals["_JOINRESPONSE"]._serialized_start = 426
    _globals["_JOINRESPONSE"]._serialized_end = 532
    _globals["_CONTRACT"]._serialized_start = 534
    _globals["_CONTRACT"]._serialized_end = 561
    _globals["_NETWORK"]._serialized_start = 611
    _globals["_NETWORK"]._serialized_end = 827
# @@protoc_insertion_point(module_scope)
