# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/warehouse/warehouse.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/warehouse/warehouse.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$yeying/api/warehouse/warehouse.proto\x12\x10yeying.api.store\x1a\x1fyeying/api/common/message.proto"1\n\x0fGetStateRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x11\n\tcondition\x18\x02 \x01(\t"E\n\x10GetStateResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x1e\n\x0fTransferRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"E\n\x10TransferResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xb5\x01\n\tWarehouse\x12S\n\x08GetState\x12!.yeying.api.store.GetStateRequest\x1a".yeying.api.store.GetStateResponse"\x00\x12S\n\x08Transfer\x12!.yeying.api.store.TransferRequest\x1a".yeying.api.store.GetStateResponse"\x00\x42\x12Z\x10yeying/api/storeb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.warehouse.warehouse_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/store"
    _globals["_GETSTATEREQUEST"]._serialized_start = 91
    _globals["_GETSTATEREQUEST"]._serialized_end = 140
    _globals["_GETSTATERESPONSE"]._serialized_start = 142
    _globals["_GETSTATERESPONSE"]._serialized_end = 211
    _globals["_TRANSFERREQUEST"]._serialized_start = 213
    _globals["_TRANSFERREQUEST"]._serialized_end = 243
    _globals["_TRANSFERRESPONSE"]._serialized_start = 245
    _globals["_TRANSFERRESPONSE"]._serialized_end = 314
    _globals["_WAREHOUSE"]._serialized_start = 317
    _globals["_WAREHOUSE"]._serialized_end = 498
# @@protoc_insertion_point(module_scope)
