# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/vector/vector.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/vector/vector.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/vector/vector.proto\x12\x11yeying.api.vector\x1a\x1fyeying/api/common/message.proto"\x1c\n\rVectorRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"C\n\x0eVectorResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2X\n\x06Vector\x12N\n\x05Query\x12 .yeying.api.vector.VectorRequest\x1a!.yeying.api.vector.VectorResponse"\x00\x42\x13Z\x11yeying/api/vectorb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.vector.vector_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/vector"
    _globals["_VECTORREQUEST"]._serialized_start = 86
    _globals["_VECTORREQUEST"]._serialized_end = 114
    _globals["_VECTORRESPONSE"]._serialized_start = 116
    _globals["_VECTORRESPONSE"]._serialized_end = 183
    _globals["_VECTOR"]._serialized_start = 185
    _globals["_VECTOR"]._serialized_end = 273
# @@protoc_insertion_point(module_scope)
