# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/web3/web3.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/web3/web3.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/web3/web3.proto\x12\x0fyeying.api.web3"\xf0\x03\n\x08Identity\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32!.yeying.api.web3.IdentityMetadata\x12\x14\n\x0c\x62lockAddress\x18\x02 \x01(\t\x12\x37\n\x0esecurityConfig\x18\x03 \x01(\x0b\x32\x1f.yeying.api.web3.SecurityConfig\x12+\n\x08registry\x18\x04 \x01(\x0b\x32\x19.yeying.api.web3.Registry\x12\x11\n\tsignature\x18\x05 \x01(\t\x12\x41\n\x0epersonalExtend\x18\x06 \x01(\x0b\x32\'.yeying.api.web3.IdentityPersonalExtendH\x00\x12?\n\rserviceExtend\x18\x07 \x01(\x0b\x32&.yeying.api.web3.IdentityServiceExtendH\x00\x12I\n\x12organizationExtend\x18\x08 \x01(\x0b\x32+.yeying.api.web3.IdentityOrganizationExtendH\x00\x12G\n\x11\x61pplicationExtend\x18\t \x01(\x0b\x32*.yeying.api.web3.IdentityApplicationExtendH\x00\x42\x08\n\x06\x65xtend"\x19\n\x08Registry\x12\r\n\x05nodes\x18\x01 \x03(\t"\x8e\x02\n\x10IdentityMetadata\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x31\n\x07network\x18\x02 \x01(\x0e\x32 .yeying.api.web3.NetworkTypeEnum\x12\x0b\n\x03\x64id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12/\n\x04\x63ode\x18\x08 \x01(\x0e\x32!.yeying.api.web3.IdentityCodeEnum\x12\x0e\n\x06\x61vatar\x18\t \x01(\t\x12\x11\n\tcreatedAt\x18\n \x01(\t\x12\x11\n\tupdatedAt\x18\x0b \x01(\t"\x87\x01\n\x0c\x42lockAddress\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x12\n\nprivateKey\x18\x03 \x01(\t\x12\x11\n\tpublicKey\x18\x04 \x01(\t\x12+\n\x08mnemonic\x18\x05 \x01(\x0b\x32\x19.yeying.api.web3.Mnemonic"J\n\x08Mnemonic\x12\x0e\n\x06phrase\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t"d\n\x15IdentityServiceExtend\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x10\n\x08\x61piCodes\x18\x02 \x01(\t\x12\r\n\x05proxy\x18\x03 \x01(\t\x12\x0c\n\x04grpc\x18\x04 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x05 \x01(\t"K\n\x1aIdentityOrganizationExtend\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x03 \x01(\t"J\n\x16IdentityPersonalExtend\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x11\n\ttelephone\x18\x02 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x03 \x01(\t"o\n\x19IdentityApplicationExtend\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x14\n\x0cserviceCodes\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0e\n\x06\x65xtend\x18\x05 \x01(\t"G\n\x0eSecurityConfig\x12\x35\n\talgorithm\x18\x01 \x01(\x0b\x32".yeying.api.web3.SecurityAlgorithm"-\n\x11SecurityAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02iv\x18\x02 \x01(\t*\xbc\x01\n\x10IdentityCodeEnum\x12\x19\n\x15IDENTITY_CODE_UNKNOWN\x10\x00\x12\x1a\n\x16IDENTITY_CODE_PERSONAL\x10\x01\x12\x1e\n\x1aIDENTITY_CODE_ORGANIZATION\x10\x02\x12\x19\n\x15IDENTITY_CODE_SERVICE\x10\x03\x12\x1d\n\x19IDENTITY_CODE_APPLICATION\x10\x04\x12\x17\n\x13IDENTITY_CODE_ASSET\x10\x05*E\n\x0fNetworkTypeEnum\x12\x18\n\x14NETWORK_TYPE_UNKNOWN\x10\x00\x12\x18\n\x13NETWORK_TYPE_YEYING\x10\xe4\x0f\x42\x11Z\x0fyeying/api/web3b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.web3.web3_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/web3"
    _globals["_IDENTITYCODEENUM"]._serialized_start = 1549
    _globals["_IDENTITYCODEENUM"]._serialized_end = 1737
    _globals["_NETWORKTYPEENUM"]._serialized_start = 1739
    _globals["_NETWORKTYPEENUM"]._serialized_end = 1808
    _globals["_IDENTITY"]._serialized_start = 48
    _globals["_IDENTITY"]._serialized_end = 544
    _globals["_REGISTRY"]._serialized_start = 546
    _globals["_REGISTRY"]._serialized_end = 571
    _globals["_IDENTITYMETADATA"]._serialized_start = 574
    _globals["_IDENTITYMETADATA"]._serialized_end = 844
    _globals["_BLOCKADDRESS"]._serialized_start = 847
    _globals["_BLOCKADDRESS"]._serialized_end = 982
    _globals["_MNEMONIC"]._serialized_start = 984
    _globals["_MNEMONIC"]._serialized_end = 1058
    _globals["_IDENTITYSERVICEEXTEND"]._serialized_start = 1060
    _globals["_IDENTITYSERVICEEXTEND"]._serialized_end = 1160
    _globals["_IDENTITYORGANIZATIONEXTEND"]._serialized_start = 1162
    _globals["_IDENTITYORGANIZATIONEXTEND"]._serialized_end = 1237
    _globals["_IDENTITYPERSONALEXTEND"]._serialized_start = 1239
    _globals["_IDENTITYPERSONALEXTEND"]._serialized_end = 1313
    _globals["_IDENTITYAPPLICATIONEXTEND"]._serialized_start = 1315
    _globals["_IDENTITYAPPLICATIONEXTEND"]._serialized_end = 1426
    _globals["_SECURITYCONFIG"]._serialized_start = 1428
    _globals["_SECURITYCONFIG"]._serialized_end = 1499
    _globals["_SECURITYALGORITHM"]._serialized_start = 1501
    _globals["_SECURITYALGORITHM"]._serialized_end = 1546
# @@protoc_insertion_point(module_scope)
