# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/user/user.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/user/user.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ayeying/api/user/user.proto\x12\x0fyeying.api.user\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fyeying/api/common/message.proto"\x7f\n\x13UpdateStatusRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.user.UpdateStatusRequestBody"W\n\x17UpdateStatusRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.yeying.api.user.UserStatusEnum"\x81\x01\n\x14UpdateStatusResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.user.UpdateStatusResponseBody"M\n\x18UpdateStatusResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"w\n\x0fUserListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.user.UserListRequestBody"t\n\x13UserListRequestBody\x12.\n\tpageIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"y\n\x10UserListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.user.UserListResponseBody"\x83\x01\n\x14UserListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12)\n\x04list\x18\x02 \x03(\x0b\x32\x1b.yeying.api.user.UserDetail\x12\r\n\x05total\x18\x03 \x01(\x04"\x94\x01\n\x0cUserMetadata\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t\x12\x11\n\tcreatedAt\x18\x04 \x01(\t\x12\x11\n\tupdatedAt\x18\x05 \x01(\t\x12\x11\n\tsignature\x18\x06 \x01(\t\x12\x11\n\ttelephone\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x08 \x01(\t"\xbe\x01\n\tUserState\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0b\n\x03\x64id\x18\x02 \x01(\t\x12+\n\x04role\x18\x03 \x01(\x0e\x32\x1d.yeying.api.user.UserRoleEnum\x12/\n\x06status\x18\x04 \x01(\x0e\x32\x1f.yeying.api.user.UserStatusEnum\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t"u\n\x0e\x41\x64\x64UserRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.user.AddUserRequestBody"A\n\x12\x41\x64\x64UserRequestBody\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"w\n\x0f\x41\x64\x64UserResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x32\n\x04\x62ody\x18\x02 \x01(\x0b\x32$.yeying.api.user.AddUserResponseBody"u\n\x13\x41\x64\x64UserResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12+\n\x04user\x18\x02 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"{\n\x11UpdateUserRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.user.UpdateUserRequestBody"D\n\x15UpdateUserRequestBody\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"}\n\x12UpdateUserResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.user.UpdateUserResponseBody"x\n\x16UpdateUserResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12+\n\x04user\x18\x02 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata"E\n\x11\x44\x65leteUserRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"}\n\x12\x44\x65leteUserResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.user.DeleteUserResponseBody"K\n\x16\x44\x65leteUserResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"E\n\x11UserDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader"}\n\x12UserDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.user.UserDetailResponseBody"x\n\x16UserDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12+\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32\x1b.yeying.api.user.UserDetail"d\n\nUserDetail\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x1d.yeying.api.user.UserMetadata\x12)\n\x05state\x18\x02 \x01(\x0b\x32\x1a.yeying.api.user.UserState*\x9f\x02\n\x0eUserStatusEnum\x12\x17\n\x13USER_STATUS_UNKNOWN\x10\x00\x12\x16\n\x12USER_STATUS_ACTIVE\x10\x01\x12\x17\n\x13USER_STATUS_OFFLINE\x10\x02\x12\x17\n\x13USER_STATUS_DISABLE\x10\x03\x12\x14\n\x10USER_STATUS_LOCK\x10\x04\x12\x1a\n\x16USER_STATUS_UNVERIFIED\x10\x05\x12\x17\n\x13USER_STATUS_DELETED\x10\x06\x12\x17\n\x13USER_STATUS_DORMANT\x10\x07\x12\x16\n\x12USER_STATUS_FREEZE\x10\x08\x12\x15\n\x11USER_STATUS_AUDIT\x10\t\x12\x17\n\x13USER_STATUS_REFUSED\x10\n*P\n\x0cUserRoleEnum\x12\x15\n\x11USER_ROLE_UNKNOWN\x10\x00\x12\x13\n\x0fUSER_ROLE_OWNER\x10\x01\x12\x14\n\x10USER_ROLE_NORMAL\x10\x02\x32\xff\x03\n\x04User\x12J\n\x03\x41\x64\x64\x12\x1f.yeying.api.user.AddUserRequest\x1a .yeying.api.user.AddUserResponse"\x00\x12S\n\x06\x44\x65tail\x12".yeying.api.user.UserDetailRequest\x1a#.yeying.api.user.UserDetailResponse"\x00\x12M\n\x04List\x12 .yeying.api.user.UserListRequest\x1a!.yeying.api.user.UserListResponse"\x00\x12S\n\x06\x44\x65lete\x12".yeying.api.user.DeleteUserRequest\x1a#.yeying.api.user.DeleteUserResponse"\x00\x12S\n\x06Update\x12".yeying.api.user.UpdateUserRequest\x1a#.yeying.api.user.UpdateUserResponse"\x00\x12]\n\x0cUpdateStatus\x12$.yeying.api.user.UpdateStatusRequest\x1a%.yeying.api.user.UpdateStatusResponse"\x00\x42\x11Z\x0fyeying/api/userb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.user.user_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\017yeying/api/user"
    _globals["_USERSTATUSENUM"]._serialized_start = 2949
    _globals["_USERSTATUSENUM"]._serialized_end = 3236
    _globals["_USERROLEENUM"]._serialized_start = 3238
    _globals["_USERROLEENUM"]._serialized_end = 3318
    _globals["_UPDATESTATUSREQUEST"]._serialized_start = 112
    _globals["_UPDATESTATUSREQUEST"]._serialized_end = 239
    _globals["_UPDATESTATUSREQUESTBODY"]._serialized_start = 241
    _globals["_UPDATESTATUSREQUESTBODY"]._serialized_end = 328
    _globals["_UPDATESTATUSRESPONSE"]._serialized_start = 331
    _globals["_UPDATESTATUSRESPONSE"]._serialized_end = 460
    _globals["_UPDATESTATUSRESPONSEBODY"]._serialized_start = 462
    _globals["_UPDATESTATUSRESPONSEBODY"]._serialized_end = 539
    _globals["_USERLISTREQUEST"]._serialized_start = 541
    _globals["_USERLISTREQUEST"]._serialized_end = 660
    _globals["_USERLISTREQUESTBODY"]._serialized_start = 662
    _globals["_USERLISTREQUESTBODY"]._serialized_end = 778
    _globals["_USERLISTRESPONSE"]._serialized_start = 780
    _globals["_USERLISTRESPONSE"]._serialized_end = 901
    _globals["_USERLISTRESPONSEBODY"]._serialized_start = 904
    _globals["_USERLISTRESPONSEBODY"]._serialized_end = 1035
    _globals["_USERMETADATA"]._serialized_start = 1038
    _globals["_USERMETADATA"]._serialized_end = 1186
    _globals["_USERSTATE"]._serialized_start = 1189
    _globals["_USERSTATE"]._serialized_end = 1379
    _globals["_ADDUSERREQUEST"]._serialized_start = 1381
    _globals["_ADDUSERREQUEST"]._serialized_end = 1498
    _globals["_ADDUSERREQUESTBODY"]._serialized_start = 1500
    _globals["_ADDUSERREQUESTBODY"]._serialized_end = 1565
    _globals["_ADDUSERRESPONSE"]._serialized_start = 1567
    _globals["_ADDUSERRESPONSE"]._serialized_end = 1686
    _globals["_ADDUSERRESPONSEBODY"]._serialized_start = 1688
    _globals["_ADDUSERRESPONSEBODY"]._serialized_end = 1805
    _globals["_UPDATEUSERREQUEST"]._serialized_start = 1807
    _globals["_UPDATEUSERREQUEST"]._serialized_end = 1930
    _globals["_UPDATEUSERREQUESTBODY"]._serialized_start = 1932
    _globals["_UPDATEUSERREQUESTBODY"]._serialized_end = 2000
    _globals["_UPDATEUSERRESPONSE"]._serialized_start = 2002
    _globals["_UPDATEUSERRESPONSE"]._serialized_end = 2127
    _globals["_UPDATEUSERRESPONSEBODY"]._serialized_start = 2129
    _globals["_UPDATEUSERRESPONSEBODY"]._serialized_end = 2249
    _globals["_DELETEUSERREQUEST"]._serialized_start = 2251
    _globals["_DELETEUSERREQUEST"]._serialized_end = 2320
    _globals["_DELETEUSERRESPONSE"]._serialized_start = 2322
    _globals["_DELETEUSERRESPONSE"]._serialized_end = 2447
    _globals["_DELETEUSERRESPONSEBODY"]._serialized_start = 2449
    _globals["_DELETEUSERRESPONSEBODY"]._serialized_end = 2524
    _globals["_USERDETAILREQUEST"]._serialized_start = 2526
    _globals["_USERDETAILREQUEST"]._serialized_end = 2595
    _globals["_USERDETAILRESPONSE"]._serialized_start = 2597
    _globals["_USERDETAILRESPONSE"]._serialized_end = 2722
    _globals["_USERDETAILRESPONSEBODY"]._serialized_start = 2724
    _globals["_USERDETAILRESPONSEBODY"]._serialized_end = 2844
    _globals["_USERDETAIL"]._serialized_start = 2846
    _globals["_USERDETAIL"]._serialized_end = 2946
    _globals["_USER"]._serialized_start = 3321
    _globals["_USER"]._serialized_end = 3832
# @@protoc_insertion_point(module_scope)
