# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/social/social.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/social/social.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eyeying/api/social/social.proto\x12\x11yeying.api.social\x1a\x1fyeying/api/common/message.proto"\x14\n\x12MakeFriendsRequest"\x15\n\x13MakeFriendsResponse"\x13\n\x11GetFriendsRequest"\x13\n\x11GetFriendResponse2\xc4\x01\n\x06Social\x12^\n\x0bMakeFriends\x12%.yeying.api.social.MakeFriendsRequest\x1a&.yeying.api.social.MakeFriendsResponse"\x00\x12Z\n\nGetFriends\x12$.yeying.api.social.GetFriendsRequest\x1a$.yeying.api.social.GetFriendResponse"\x00\x42\x13Z\x11yeying/api/socialb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.social.social_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/social"
    _globals["_MAKEFRIENDSREQUEST"]._serialized_start = 86
    _globals["_MAKEFRIENDSREQUEST"]._serialized_end = 106
    _globals["_MAKEFRIENDSRESPONSE"]._serialized_start = 108
    _globals["_MAKEFRIENDSRESPONSE"]._serialized_end = 129
    _globals["_GETFRIENDSREQUEST"]._serialized_start = 131
    _globals["_GETFRIENDSREQUEST"]._serialized_end = 150
    _globals["_GETFRIENDRESPONSE"]._serialized_start = 152
    _globals["_GETFRIENDRESPONSE"]._serialized_end = 171
    _globals["_SOCIAL"]._serialized_start = 174
    _globals["_SOCIAL"]._serialized_end = 370
# @@protoc_insertion_point(module_scope)
