# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/asset.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/asset.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cyeying/api/asset/asset.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"~\n\x12SearchAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.SearchAssetRequestBody"\x81\x01\n\x16SearchAssetRequestBody\x12\x39\n\tcondition\x18\x01 \x01(\x0b\x32&.yeying.api.asset.SearchAssetCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"}\n\x14SearchAssetCondition\x12\x34\n\x06\x66ormat\x18\x01 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t"\x80\x01\n\x13SearchAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.SearchAssetResponseBody"}\n\x17SearchAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12/\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"z\n\x10SignAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.asset.SignAssetRequestBody"F\n\x14SignAssetRequestBody\x12.\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"|\n\x11SignAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.yeying.api.asset.SignAssetResponseBody"z\n\x15SignAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x61sset\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"~\n\x12UpdateAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.UpdateAssetRequestBody"H\n\x16UpdateAssetRequestBody\x12.\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"\x80\x01\n\x13UpdateAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.UpdateAssetResponseBody"|\n\x17UpdateAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x61sset\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"~\n\x12\x41ssetDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.AssetDetailRequestBody";\n\x16\x41ssetDetailRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x80\x01\n\x13\x41ssetDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.AssetDetailResponseBody"|\n\x17\x41ssetDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12.\n\x05\x61sset\x18\x02 \x01(\x0b\x32\x1f.yeying.api.asset.AssetMetadata"~\n\x12\x44\x65leteAssetRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.asset.DeleteAssetRequestBody";\n\x16\x44\x65leteAssetRequestBody\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x13\n\x0bnamespaceId\x18\x02 \x01(\t"\x80\x01\n\x13\x44\x65leteAssetResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.asset.DeleteAssetResponseBody"L\n\x17\x44\x65leteAssetResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\xd2\x02\n\rAssetMetadata\x12\x13\n\x0bnamespaceId\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x12\n\nparentHash\x18\x03 \x01(\t\x12\x0c\n\x04hash\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06\x63hunks\x18\x07 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x34\n\x06\x66ormat\x18\t \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x0c\n\x04size\x18\n \x01(\x04\x12\x11\n\tcreatedAt\x18\x0b \x01(\t\x12\x11\n\tupdatedAt\x18\x0c \x01(\t\x12\x12\n\nchunkCount\x18\r \x01(\r\x12\x11\n\tchunkSize\x18\x0e \x01(\r\x12\x13\n\x0bisEncrypted\x18\x0f \x01(\x08\x12\x11\n\tsignature\x18\x10 \x01(\t2\xbe\x03\n\x05\x41sset\x12W\n\x06Search\x12$.yeying.api.asset.SearchAssetRequest\x1a%.yeying.api.asset.SearchAssetResponse"\x00\x12Q\n\x04Sign\x12".yeying.api.asset.SignAssetRequest\x1a#.yeying.api.asset.SignAssetResponse"\x00\x12W\n\x06Update\x12$.yeying.api.asset.UpdateAssetRequest\x1a%.yeying.api.asset.UpdateAssetResponse"\x00\x12W\n\x06\x44\x65tail\x12$.yeying.api.asset.AssetDetailRequest\x1a%.yeying.api.asset.AssetDetailResponse"\x00\x12W\n\x06\x44\x65lete\x12$.yeying.api.asset.DeleteAssetRequest\x1a%.yeying.api.asset.DeleteAssetResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.asset_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_SEARCHASSETREQUEST"]._serialized_start = 113
    _globals["_SEARCHASSETREQUEST"]._serialized_end = 239
    _globals["_SEARCHASSETREQUESTBODY"]._serialized_start = 242
    _globals["_SEARCHASSETREQUESTBODY"]._serialized_end = 371
    _globals["_SEARCHASSETCONDITION"]._serialized_start = 373
    _globals["_SEARCHASSETCONDITION"]._serialized_end = 498
    _globals["_SEARCHASSETRESPONSE"]._serialized_start = 501
    _globals["_SEARCHASSETRESPONSE"]._serialized_end = 629
    _globals["_SEARCHASSETRESPONSEBODY"]._serialized_start = 631
    _globals["_SEARCHASSETRESPONSEBODY"]._serialized_end = 756
    _globals["_SIGNASSETREQUEST"]._serialized_start = 758
    _globals["_SIGNASSETREQUEST"]._serialized_end = 880
    _globals["_SIGNASSETREQUESTBODY"]._serialized_start = 882
    _globals["_SIGNASSETREQUESTBODY"]._serialized_end = 952
    _globals["_SIGNASSETRESPONSE"]._serialized_start = 954
    _globals["_SIGNASSETRESPONSE"]._serialized_end = 1078
    _globals["_SIGNASSETRESPONSEBODY"]._serialized_start = 1080
    _globals["_SIGNASSETRESPONSEBODY"]._serialized_end = 1202
    _globals["_UPDATEASSETREQUEST"]._serialized_start = 1204
    _globals["_UPDATEASSETREQUEST"]._serialized_end = 1330
    _globals["_UPDATEASSETREQUESTBODY"]._serialized_start = 1332
    _globals["_UPDATEASSETREQUESTBODY"]._serialized_end = 1404
    _globals["_UPDATEASSETRESPONSE"]._serialized_start = 1407
    _globals["_UPDATEASSETRESPONSE"]._serialized_end = 1535
    _globals["_UPDATEASSETRESPONSEBODY"]._serialized_start = 1537
    _globals["_UPDATEASSETRESPONSEBODY"]._serialized_end = 1661
    _globals["_ASSETDETAILREQUEST"]._serialized_start = 1663
    _globals["_ASSETDETAILREQUEST"]._serialized_end = 1789
    _globals["_ASSETDETAILREQUESTBODY"]._serialized_start = 1791
    _globals["_ASSETDETAILREQUESTBODY"]._serialized_end = 1850
    _globals["_ASSETDETAILRESPONSE"]._serialized_start = 1853
    _globals["_ASSETDETAILRESPONSE"]._serialized_end = 1981
    _globals["_ASSETDETAILRESPONSEBODY"]._serialized_start = 1983
    _globals["_ASSETDETAILRESPONSEBODY"]._serialized_end = 2107
    _globals["_DELETEASSETREQUEST"]._serialized_start = 2109
    _globals["_DELETEASSETREQUEST"]._serialized_end = 2235
    _globals["_DELETEASSETREQUESTBODY"]._serialized_start = 2237
    _globals["_DELETEASSETREQUESTBODY"]._serialized_end = 2296
    _globals["_DELETEASSETRESPONSE"]._serialized_start = 2299
    _globals["_DELETEASSETRESPONSE"]._serialized_end = 2427
    _globals["_DELETEASSETRESPONSEBODY"]._serialized_start = 2429
    _globals["_DELETEASSETRESPONSEBODY"]._serialized_end = 2505
    _globals["_ASSETMETADATA"]._serialized_start = 2508
    _globals["_ASSETMETADATA"]._serialized_end = 2846
    _globals["_ASSET"]._serialized_start = 2849
    _globals["_ASSET"]._serialized_end = 3295
# @@protoc_insertion_point(module_scope)
