# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/archive.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/archive.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(yeying/api/apps/zuoyepigai/archive.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x88\x01\n\x12\x41rchiveListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.ArchiveListRequestBody"\x99\x01\n\x16\x41rchiveListRequestBody\x12\x12\n\nteacherDid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\tpageIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08pageSize\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value"\x8a\x01\n\x13\x41rchiveListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.ArchiveListResponseBody"\x96\x01\n\x17\x41rchiveListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04list\x18\x02 \x03(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata\x12\r\n\x05total\x18\x03 \x01(\x04"\x8c\x01\n\x14\x41rchiveDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ArchiveDetailRequestBody"\'\n\x18\x41rchiveDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x41rchiveDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ArchiveDetailResponseBody"\x89\x01\n\x19\x41rchiveDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x9a\x01\n\x1b\x41rchiveDetailStudentRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12I\n\x04\x62ody\x18\x02 \x01(\x0b\x32;.yeying.api.apps.zuoyepigai.ArchiveDetailStudentRequestBody"5\n\x1f\x41rchiveDetailStudentRequestBody\x12\x12\n\nstudentDid\x18\x01 \x01(\t"\x9c\x01\n\x1c\x41rchiveDetailStudentResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12J\n\x04\x62ody\x18\x02 \x01(\x0b\x32<.yeying.api.apps.zuoyepigai.ArchiveDetailStudentResponseBody"\x90\x01\n ArchiveDetailStudentResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x86\x01\n\x11\x41rchiveAddRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12?\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x31.yeying.api.apps.zuoyepigai.ArchiveAddRequestBody"R\n\x15\x41rchiveAddRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x88\x01\n\x12\x41rchiveAddResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.apps.zuoyepigai.ArchiveAddResponseBody"\x86\x01\n\x16\x41rchiveAddResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x8c\x01\n\x14\x41rchiveDeleteRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ArchiveDeleteRequestBody"\'\n\x18\x41rchiveDeleteRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x8e\x01\n\x15\x41rchiveDeleteResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ArchiveDeleteResponseBody"\x89\x01\n\x19\x41rchiveDeleteResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x8c\x01\n\x14\x41rchiveUpdateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.ArchiveUpdateRequestBody"U\n\x18\x41rchiveUpdateRequestBody\x12\x39\n\x04meta\x18\x01 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata"\x8e\x01\n\x15\x41rchiveUpdateResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.ArchiveUpdateResponseBody"\x89\x01\n\x19\x41rchiveUpdateResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x39\n\x04meta\x18\x02 \x01(\x0b\x32+.yeying.api.apps.zuoyepigai.ArchiveMetadata2\xbb\x05\n\x07\x41rchive\x12i\n\x04List\x12..yeying.api.apps.zuoyepigai.ArchiveListRequest\x1a/.yeying.api.apps.zuoyepigai.ArchiveListResponse"\x00\x12o\n\x06\x44\x65tail\x12\x30.yeying.api.apps.zuoyepigai.ArchiveDetailRequest\x1a\x31.yeying.api.apps.zuoyepigai.ArchiveDetailResponse"\x00\x12\x89\x01\n\x12\x44\x65tailByStudentDid\x12\x37.yeying.api.apps.zuoyepigai.ArchiveDetailStudentRequest\x1a\x38.yeying.api.apps.zuoyepigai.ArchiveDetailStudentResponse"\x00\x12\x66\n\x03\x41\x64\x64\x12-.yeying.api.apps.zuoyepigai.ArchiveAddRequest\x1a..yeying.api.apps.zuoyepigai.ArchiveAddResponse"\x00\x12o\n\x06\x44\x65lete\x12\x30.yeying.api.apps.zuoyepigai.ArchiveDeleteRequest\x1a\x31.yeying.api.apps.zuoyepigai.ArchiveDeleteResponse"\x00\x12o\n\x06Update\x12\x30.yeying.api.apps.zuoyepigai.ArchiveUpdateRequest\x1a\x31.yeying.api.apps.zuoyepigai.ArchiveUpdateResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.archive_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_ARCHIVELISTREQUEST"]._serialized_start = 177
    _globals["_ARCHIVELISTREQUEST"]._serialized_end = 313
    _globals["_ARCHIVELISTREQUESTBODY"]._serialized_start = 316
    _globals["_ARCHIVELISTREQUESTBODY"]._serialized_end = 469
    _globals["_ARCHIVELISTRESPONSE"]._serialized_start = 472
    _globals["_ARCHIVELISTRESPONSE"]._serialized_end = 610
    _globals["_ARCHIVELISTRESPONSEBODY"]._serialized_start = 613
    _globals["_ARCHIVELISTRESPONSEBODY"]._serialized_end = 763
    _globals["_ARCHIVEDETAILREQUEST"]._serialized_start = 766
    _globals["_ARCHIVEDETAILREQUEST"]._serialized_end = 906
    _globals["_ARCHIVEDETAILREQUESTBODY"]._serialized_start = 908
    _globals["_ARCHIVEDETAILREQUESTBODY"]._serialized_end = 947
    _globals["_ARCHIVEDETAILRESPONSE"]._serialized_start = 950
    _globals["_ARCHIVEDETAILRESPONSE"]._serialized_end = 1092
    _globals["_ARCHIVEDETAILRESPONSEBODY"]._serialized_start = 1095
    _globals["_ARCHIVEDETAILRESPONSEBODY"]._serialized_end = 1232
    _globals["_ARCHIVEDETAILSTUDENTREQUEST"]._serialized_start = 1235
    _globals["_ARCHIVEDETAILSTUDENTREQUEST"]._serialized_end = 1389
    _globals["_ARCHIVEDETAILSTUDENTREQUESTBODY"]._serialized_start = 1391
    _globals["_ARCHIVEDETAILSTUDENTREQUESTBODY"]._serialized_end = 1444
    _globals["_ARCHIVEDETAILSTUDENTRESPONSE"]._serialized_start = 1447
    _globals["_ARCHIVEDETAILSTUDENTRESPONSE"]._serialized_end = 1603
    _globals["_ARCHIVEDETAILSTUDENTRESPONSEBODY"]._serialized_start = 1606
    _globals["_ARCHIVEDETAILSTUDENTRESPONSEBODY"]._serialized_end = 1750
    _globals["_ARCHIVEADDREQUEST"]._serialized_start = 1753
    _globals["_ARCHIVEADDREQUEST"]._serialized_end = 1887
    _globals["_ARCHIVEADDREQUESTBODY"]._serialized_start = 1889
    _globals["_ARCHIVEADDREQUESTBODY"]._serialized_end = 1971
    _globals["_ARCHIVEADDRESPONSE"]._serialized_start = 1974
    _globals["_ARCHIVEADDRESPONSE"]._serialized_end = 2110
    _globals["_ARCHIVEADDRESPONSEBODY"]._serialized_start = 2113
    _globals["_ARCHIVEADDRESPONSEBODY"]._serialized_end = 2247
    _globals["_ARCHIVEDELETEREQUEST"]._serialized_start = 2250
    _globals["_ARCHIVEDELETEREQUEST"]._serialized_end = 2390
    _globals["_ARCHIVEDELETEREQUESTBODY"]._serialized_start = 2392
    _globals["_ARCHIVEDELETEREQUESTBODY"]._serialized_end = 2431
    _globals["_ARCHIVEDELETERESPONSE"]._serialized_start = 2434
    _globals["_ARCHIVEDELETERESPONSE"]._serialized_end = 2576
    _globals["_ARCHIVEDELETERESPONSEBODY"]._serialized_start = 2579
    _globals["_ARCHIVEDELETERESPONSEBODY"]._serialized_end = 2716
    _globals["_ARCHIVEUPDATEREQUEST"]._serialized_start = 2719
    _globals["_ARCHIVEUPDATEREQUEST"]._serialized_end = 2859
    _globals["_ARCHIVEUPDATEREQUESTBODY"]._serialized_start = 2861
    _globals["_ARCHIVEUPDATEREQUESTBODY"]._serialized_end = 2946
    _globals["_ARCHIVEUPDATERESPONSE"]._serialized_start = 2949
    _globals["_ARCHIVEUPDATERESPONSE"]._serialized_end = 3091
    _globals["_ARCHIVEUPDATERESPONSEBODY"]._serialized_start = 3094
    _globals["_ARCHIVEUPDATERESPONSEBODY"]._serialized_end = 3231
    _globals["_ARCHIVE"]._serialized_start = 3234
    _globals["_ARCHIVE"]._serialized_end = 3933
# @@protoc_insertion_point(module_scope)
