# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/common/code.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/common/code.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x1cyeying/api/common/code.proto\x12\x11yeying.api.common*\x9e\x02\n\x10ResponseCodeEnum\x12\x19\n\x15RESPONSE_CODE_UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x13\n\x0fUNAUTHENTICATED\x10\x03\x12\x15\n\x11PERMISSION_DENIED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x12\n\x0eLIMIT_EXCEEDED\x10\x07\x12\x0f\n\x0bUNAVAILABLE\x10\x08\x12\x11\n\rUNKNOWN_ERROR\x10\t\x12\x11\n\rNETWORK_ERROR\x10\n\x12\x10\n\x0cINVALID_CERT\x10\x0b\x12\x11\n\rNOT_SUPPORTED\x10\x0c\x12\x12\n\x0e\x44\x41TA_CORRUPTED\x10\r*\xac\x01\n\x12\x43ontractStatusEnum\x12\x1b\n\x17\x43ONTRACT_STATUS_UNKNOWN\x10\x00\x12\x1f\n\x1b\x43ONTRACT_STATUS_INACTIVATED\x10\x01\x12\x1d\n\x19\x43ONTRACT_STATUS_ACTIVATED\x10\x02\x12\x1b\n\x17\x43ONTRACT_STATUS_EXPIRED\x10\x03\x12\x1c\n\x18\x43ONTRACT_STATUS_CANCELED\x10\x04*_\n\x10LanguageCodeEnum\x12\x19\n\x15LANGUAGE_CODE_UNKNOWN\x10\x00\x12\x17\n\x13LANGUAGE_CODE_ZH_CH\x10\x01\x12\x17\n\x13LANGUAGE_CODE_EN_US\x10\x02*\xe6\x01\n\x13\x41pplicationCodeEnum\x12\x1c\n\x18\x41PPLICATION_CODE_UNKNOWN\x10\x00\x12\x1b\n\x17\x41PPLICATION_CODE_MARKET\x10\x01\x12\x1a\n\x16\x41PPLICATION_CODE_ASSET\x10\x02\x12\x1e\n\x1a\x41PPLICATION_CODE_KNOWLEDGE\x10\x03\x12\x1b\n\x17\x41PPLICATION_CODE_KEEPER\x10\x04\x12\x1b\n\x17\x41PPLICATION_CODE_SOCIAL\x10\x05\x12\x1e\n\x1a\x41PPLICATION_CODE_WORKBENCH\x10\x06*\xa1\x01\n\x0fServiceCodeEnum\x12\x18\n\x14SERVICE_CODE_UNKNOWN\x10\x00\x12\x15\n\x11SERVICE_CODE_NODE\x10\x01\x12\x1a\n\x16SERVICE_CODE_WAREHOUSE\x10\x02\x12\x16\n\x12SERVICE_CODE_AGENT\x10\x03\x12\x14\n\x10SERVICE_CODE_MCP\x10\x04\x12\x13\n\x0fSERVICE_CODE_AI\x10\x05*\x98\x03\n\x0b\x41piCodeEnum\x12\x14\n\x10\x41PI_CODE_UNKNOWN\x10\x00\x12\x11\n\rAPI_CODE_USER\x10\x01\x12\x15\n\x11\x41PI_CODE_IDENTITY\x10\x02\x12\x18\n\x14\x41PI_CODE_LLM_SERVICE\x10\x03\x12\x19\n\x15\x41PI_CODE_LLM_PROVIDER\x10\x04\x12\x1a\n\x16\x41PI_CODE_ASSET_SERVICE\x10\x05\x12\x18\n\x14\x41PI_CODE_ASSET_BLOCK\x10\x06\x12\x17\n\x13\x41PI_CODE_ASSET_LINK\x10\x07\x12\x1c\n\x18\x41PI_CODE_ASSET_NAMESPACE\x10\x08\x12\x1a\n\x16\x41PI_CODE_ASSET_RECYCLE\x10\t\x12\x18\n\x14\x41PI_CODE_CERTIFICATE\x10\n\x12\x14\n\x10\x41PI_CODE_STORAGE\x10\x0b\x12\x18\n\x14\x41PI_CODE_APPLICATION\x10\x0c\x12\x12\n\x0e\x41PI_CODE_EVENT\x10\r\x12\x17\n\x13\x41PI_CODE_INVITATION\x10\x0e\x12\x14\n\x10\x41PI_CODE_SERVICE\x10\x0f*A\n\x0fImageFormatEnum\x12\x18\n\x14IMAGE_FORMAT_UNKNOWN\x10\x00\x12\x14\n\x10IMAGE_FORMAT_PNG\x10\x01*\xc9\x01\n\x11\x44igitalFormatEnum\x12\x1a\n\x16\x44IGITAL_FORMAT_UNKNOWN\x10\x00\x12\x17\n\x13\x44IGITAL_FORMAT_TEXT\x10\x01\x12\x18\n\x14\x44IGITAL_FORMAT_IMAGE\x10\x02\x12\x18\n\x14\x44IGITAL_FORMAT_VIDEO\x10\x03\x12\x18\n\x14\x44IGITAL_FORMAT_AUDIO\x10\x04\x12\x16\n\x12\x44IGITAL_FORMAT_APP\x10\x05\x12\x19\n\x14\x44IGITAL_FORMAT_OTHER\x10\x90N*b\n\x11\x43ontentFormatEnum\x12\x1a\n\x16\x43ONTENT_FORMAT_UNKNOWN\x10\x00\x12\x16\n\x12\x43ONTENT_FORMAT_URL\x10\x01\x12\x19\n\x15\x43ONTENT_FORMAT_BASE64\x10\x02*\x83\x01\n\x10SessionSceneEnum\x12\x19\n\x15SESSION_SCENE_UNKNOWN\x10\x00\x12\x1a\n\x16SESSION_SCENE_DIALOGUE\x10\x01\x12\x19\n\x15SESSION_SCENE_DRAWING\x10\x02\x12\x1d\n\x19SESSION_SCENE_TRANSLATION\x10\x03*a\n\x0fSessionRoleEnum\x12\x18\n\x14SESSION_ROLE_UNKNOWN\x10\x00\x12\x1c\n\x18SESSION_ROLE_PARTICIPANT\x10\x01\x12\x16\n\x12SESSION_ROLE_ADMIN\x10\x02*n\n\x13ParticipantTypeEnum\x12\x1c\n\x18PARTICIPANT_TYPE_UNKNOWN\x10\x00\x12\x1c\n\x18PARTICIPANT_TYPE_SERVICE\x10\x01\x12\x1b\n\x17PARTICIPANT_TYPE_PEOPLE\x10\x02*[\n\rAuditTypeEnum\x12\x1a\n\x16\x41UDIT_TYPE_APPLICATION\x10\x00\x12\x16\n\x12\x41UDIT_TYPE_SERVICE\x10\x01\x12\x16\n\x12\x41UDIT_TYPE_UNKNOWN\x10\x02*\xd6\x01\n\x15\x41pplicationStatusEnum\x12\x1e\n\x1a\x41PPLICATION_STATUS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x41PPLICATION_STATUS_CREATED\x10\x01\x12\x1e\n\x1a\x41PPLICATION_STATUS_AUDITED\x10\x02\x12\x1e\n\x1a\x41PPLICATION_STATUS_REFUSED\x10\x03\x12\x1e\n\x1a\x41PPLICATION_STATUS_OFFLINE\x10\x04\x12\x1d\n\x19\x41PPLICATION_STATUS_ONLINE\x10\x05*F\n\x0e\x43ipherTypeEnum\x12\x17\n\x13\x43IPHER_TYPE_UNKNOWN\x10\x00\x12\x1b\n\x17\x43IPHER_TYPE_AES_GCM_256\x10\x01*n\n\x14\x41uthenticateTypeEnum\x12\x1d\n\x19\x41UTHENTICATE_TYPE_UNKNOWN\x10\x00\x12\x1a\n\x16\x41UTHENTICATE_TYPE_CERT\x10\x01\x12\x1b\n\x17\x41UTHENTICATE_TYPE_TOKEN\x10\x02\x42\x13Z\x11yeying/api/commonb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.common.code_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\021yeying/api/common"
    _globals["_RESPONSECODEENUM"]._serialized_start = 52
    _globals["_RESPONSECODEENUM"]._serialized_end = 338
    _globals["_CONTRACTSTATUSENUM"]._serialized_start = 341
    _globals["_CONTRACTSTATUSENUM"]._serialized_end = 513
    _globals["_LANGUAGECODEENUM"]._serialized_start = 515
    _globals["_LANGUAGECODEENUM"]._serialized_end = 610
    _globals["_APPLICATIONCODEENUM"]._serialized_start = 613
    _globals["_APPLICATIONCODEENUM"]._serialized_end = 843
    _globals["_SERVICECODEENUM"]._serialized_start = 846
    _globals["_SERVICECODEENUM"]._serialized_end = 1007
    _globals["_APICODEENUM"]._serialized_start = 1010
    _globals["_APICODEENUM"]._serialized_end = 1418
    _globals["_IMAGEFORMATENUM"]._serialized_start = 1420
    _globals["_IMAGEFORMATENUM"]._serialized_end = 1485
    _globals["_DIGITALFORMATENUM"]._serialized_start = 1488
    _globals["_DIGITALFORMATENUM"]._serialized_end = 1689
    _globals["_CONTENTFORMATENUM"]._serialized_start = 1691
    _globals["_CONTENTFORMATENUM"]._serialized_end = 1789
    _globals["_SESSIONSCENEENUM"]._serialized_start = 1792
    _globals["_SESSIONSCENEENUM"]._serialized_end = 1923
    _globals["_SESSIONROLEENUM"]._serialized_start = 1925
    _globals["_SESSIONROLEENUM"]._serialized_end = 2022
    _globals["_PARTICIPANTTYPEENUM"]._serialized_start = 2024
    _globals["_PARTICIPANTTYPEENUM"]._serialized_end = 2134
    _globals["_AUDITTYPEENUM"]._serialized_start = 2136
    _globals["_AUDITTYPEENUM"]._serialized_end = 2227
    _globals["_APPLICATIONSTATUSENUM"]._serialized_start = 2230
    _globals["_APPLICATIONSTATUSENUM"]._serialized_end = 2444
    _globals["_CIPHERTYPEENUM"]._serialized_start = 2446
    _globals["_CIPHERTYPEENUM"]._serialized_end = 2516
    _globals["_AUTHENTICATETYPEENUM"]._serialized_start = 2518
    _globals["_AUTHENTICATETYPEENUM"]._serialized_end = 2628
# @@protoc_insertion_point(module_scope)
