# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.social import social_pb2 as yeying_dot_api_dot_social_dot_social__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/social/social_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class SocialStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MakeFriends = channel.unary_unary(
            "/yeying.api.social.Social/MakeFriends",
            request_serializer=yeying_dot_api_dot_social_dot_social__pb2.MakeFriendsRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_social_dot_social__pb2.MakeFriendsResponse.FromString,
            _registered_method=True,
        )
        self.GetFriends = channel.unary_unary(
            "/yeying.api.social.Social/GetFriends",
            request_serializer=yeying_dot_api_dot_social_dot_social__pb2.GetFriendsRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_social_dot_social__pb2.GetFriendResponse.FromString,
            _registered_method=True,
        )


class SocialServicer(object):
    """Missing associated documentation comment in .proto file."""

    def MakeFriends(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetFriends(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_SocialServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "MakeFriends": grpc.unary_unary_rpc_method_handler(
            servicer.MakeFriends,
            request_deserializer=yeying_dot_api_dot_social_dot_social__pb2.MakeFriendsRequest.FromString,
            response_serializer=yeying_dot_api_dot_social_dot_social__pb2.MakeFriendsResponse.SerializeToString,
        ),
        "GetFriends": grpc.unary_unary_rpc_method_handler(
            servicer.GetFriends,
            request_deserializer=yeying_dot_api_dot_social_dot_social__pb2.GetFriendsRequest.FromString,
            response_serializer=yeying_dot_api_dot_social_dot_social__pb2.GetFriendResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.social.Social", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.social.Social", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Social(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def MakeFriends(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.social.Social/MakeFriends",
            yeying_dot_api_dot_social_dot_social__pb2.MakeFriendsRequest.SerializeToString,
            yeying_dot_api_dot_social_dot_social__pb2.MakeFriendsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetFriends(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.social.Social/GetFriends",
            yeying_dot_api_dot_social_dot_social__pb2.GetFriendsRequest.SerializeToString,
            yeying_dot_api_dot_social_dot_social__pb2.GetFriendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
