# Generated by protobuf_init. Do not edit manually.
from .warehouse_pb2 import GetStateRequest
from .warehouse_pb2 import GetStateResponse
from .warehouse_pb2 import TransferRequest
from .warehouse_pb2 import TransferResponse
from .warehouse_pb2_grpc import WarehouseServicer
from .warehouse_pb2_grpc import WarehouseStub
from .warehouse_pb2_grpc import add_WarehouseServicer_to_server
from .warehouse_pb2_grpc import Warehouse
