# Generated by protobuf_init. Do not edit manually.
from .vector_pb2 import VectorRequest
from .vector_pb2 import VectorResponse
from .vector_pb2_grpc import VectorServicer
from .vector_pb2_grpc import VectorStub
from .vector_pb2_grpc import add_VectorServicer_to_server
from .vector_pb2_grpc import Vector
