# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/rag/rag.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'yeying/api/rag/rag.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18yeying/api/rag/rag.proto\x12\x0eyeying.api.rag\x1a\x1fyeying/api/common/message.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x80\x01\n\x14\x43reateSessionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.rag.CreateSessionRequestBody\"\x1a\n\x18\x43reateSessionRequestBody\"\x82\x01\n\x15\x43reateSessionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.rag.CreateSessionResponseBody\"a\n\x19\x43reateSessionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x11\n\tmemoryKey\x18\x02 \x01(\t\"z\n\x11\x41\x64\x64MessageRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x33\n\x04\x62ody\x18\x02 \x01(\x0b\x32%.yeying.api.rag.AddMessageRequestBody\"K\n\x15\x41\x64\x64MessageRequestBody\x12\x11\n\tmemoryKey\x18\x01 \x01(\t\x12\x0c\n\x04urls\x18\x02 \x03(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\"|\n\x12\x41\x64\x64MessageResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x34\n\x04\x62ody\x18\x02 \x01(\x0b\x32&.yeying.api.rag.AddMessageResponseBody\"a\n\x16\x41\x64\x64MessageResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\"\x80\x01\n\x14\x44\x65leteMessageRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.rag.DeleteMessageRequestBody\";\n\x18\x44\x65leteMessageRequestBody\x12\x11\n\tmemoryKey\x18\x01 \x01(\t\x12\x0c\n\x04urls\x18\x02 \x03(\t\"\x82\x01\n\x15\x44\x65leteMessageResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32).yeying.api.rag.DeleteMessageResponseBody\"d\n\x19\x44\x65leteMessageResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\"t\n\x13InteractionMetadata\x12\x11\n\tmemoryKey\x18\x01 \x01(\t\x12\x0c\n\x04urls\x18\x02 \x03(\t\x12\x14\n\x0curlTimestamp\x18\x03 \x01(\x03\x12&\n\x06status\x18\x04 \x01(\x0e\x32\x16.yeying.api.rag.Status\"\xe8\x01\n\x13MainHistoryMetaData\x12\x11\n\tmemoryKey\x18\x01 \x01(\t\x12\x11\n\tmessageId\x18\x02 \x01(\x05\x12\x16\n\x0emessageContent\x18\x03 \x01(\t\x12\x17\n\x0fvectorEmbedding\x18\x04 \x01(\x0c\x12\x11\n\tcreatedAt\x18\x05 \x01(\x03\x12\x11\n\tupdatedAt\x18\x06 \x01(\x03\x12\x11\n\tisDeleted\x18\x07 \x01(\x08\x12\x11\n\tisSummary\x18\x08 \x01(\x08\x12.\n\nsenderType\x18\t \x01(\x0e\x32\x1a.yeying.api.rag.SenderType\"i\n\x0bVectorIndex\x12\x11\n\tmemoryKey\x18\x01 \x01(\t\x12\x11\n\tmessageId\x18\x02 \x01(\x05\x12\x0e\n\x06vector\x18\x03 \x01(\x0c\x12\x11\n\tcreatedAt\x18\x04 \x01(\x03\x12\x11\n\tupdatedAt\x18\x05 \x01(\x03*0\n\x06Status\x12\x0b\n\x07PENDING\x10\x00\x12\r\n\tPROCESSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02*\"\n\nSenderType\x12\x08\n\x04USER\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x32\x9c\x02\n\x03RAG\x12^\n\rCreateSession\x12$.yeying.api.rag.CreateSessionRequest\x1a%.yeying.api.rag.CreateSessionResponse\"\x00\x12U\n\nAddMessage\x12!.yeying.api.rag.AddMessageRequest\x1a\".yeying.api.rag.AddMessageResponse\"\x00\x12^\n\rDeleteMessage\x12$.yeying.api.rag.DeleteMessageRequest\x1a%.yeying.api.rag.DeleteMessageResponse\"\x00\x42\x11Z\x0fyeying/api/rag/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yeying.api.rag.rag_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\017yeying/api/rag/'
  _globals['_STATUS']._serialized_start=1813
  _globals['_STATUS']._serialized_end=1861
  _globals['_SENDERTYPE']._serialized_start=1863
  _globals['_SENDERTYPE']._serialized_end=1897
  _globals['_CREATESESSIONREQUEST']._serialized_start=110
  _globals['_CREATESESSIONREQUEST']._serialized_end=238
  _globals['_CREATESESSIONREQUESTBODY']._serialized_start=240
  _globals['_CREATESESSIONREQUESTBODY']._serialized_end=266
  _globals['_CREATESESSIONRESPONSE']._serialized_start=269
  _globals['_CREATESESSIONRESPONSE']._serialized_end=399
  _globals['_CREATESESSIONRESPONSEBODY']._serialized_start=401
  _globals['_CREATESESSIONRESPONSEBODY']._serialized_end=498
  _globals['_ADDMESSAGEREQUEST']._serialized_start=500
  _globals['_ADDMESSAGEREQUEST']._serialized_end=622
  _globals['_ADDMESSAGEREQUESTBODY']._serialized_start=624
  _globals['_ADDMESSAGEREQUESTBODY']._serialized_end=699
  _globals['_ADDMESSAGERESPONSE']._serialized_start=701
  _globals['_ADDMESSAGERESPONSE']._serialized_end=825
  _globals['_ADDMESSAGERESPONSEBODY']._serialized_start=827
  _globals['_ADDMESSAGERESPONSEBODY']._serialized_end=924
  _globals['_DELETEMESSAGEREQUEST']._serialized_start=927
  _globals['_DELETEMESSAGEREQUEST']._serialized_end=1055
  _globals['_DELETEMESSAGEREQUESTBODY']._serialized_start=1057
  _globals['_DELETEMESSAGEREQUESTBODY']._serialized_end=1116
  _globals['_DELETEMESSAGERESPONSE']._serialized_start=1119
  _globals['_DELETEMESSAGERESPONSE']._serialized_end=1249
  _globals['_DELETEMESSAGERESPONSEBODY']._serialized_start=1251
  _globals['_DELETEMESSAGERESPONSEBODY']._serialized_end=1351
  _globals['_INTERACTIONMETADATA']._serialized_start=1353
  _globals['_INTERACTIONMETADATA']._serialized_end=1469
  _globals['_MAINHISTORYMETADATA']._serialized_start=1472
  _globals['_MAINHISTORYMETADATA']._serialized_end=1704
  _globals['_VECTORINDEX']._serialized_start=1706
  _globals['_VECTORINDEX']._serialized_end=1811
  _globals['_RAG']._serialized_start=1900
  _globals['_RAG']._serialized_end=2184
# @@protoc_insertion_point(module_scope)
